%%
%% This is file `zhlipsum-utf8.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% zhlipsum.dtx  (with options: `text,utf8')
%% zhlipsum-text.dtx  (with options: `text,utf8')
%% 
%%     Copyright (C) 2017--2020 by Xiangdong Zeng <xdzeng96@gmail.com>
%% 
%%     This work may be distributed and/or modified under the
%%     conditions of the LaTeX Project Public License, either
%%     version 1.3c of this license or (at your option) any later
%%     version. The latest version of this license is in:
%% 
%%       http://www.latex-project.org/lppl.txt
%% 
%%     and version 1.3 or later is part of all distributions of
%%     LaTeX version 2005/12/01 or later.
%% 
%%     This work has the LPPL maintenance status `maintained'.
%% 
%%     The Current Maintainer of this work is Xiangdong Zeng.
%% 
%%     This work consists of the files zhlipsum.dtx,
%%                                     zhlipsum-text.dtx,
%%               and the derived files zhlipsum.ins,
%%                                     zhlipsum.sty,
%%                                     zhlipsum-utf8.def,
%%                                     zhlipsum-gbk.def,
%%                                     zhlipsum-big5.def,
%%                                     zhlipsum-en.tex,
%%                                     zhlipsum.pdf,
%%                                     zhlipsum-en.pdf,
%%                                 and README.md.
%% 
\GetIdInfo $Id: zhlipsum.dtx 1.2.0 2020-04-10 12:00:00Z Xiangdong Zeng <xdzeng96@gmail.com> $
  {Chinese dummy text with UTF-8 encoding (for zhlipsum)}
\ProvidesExplFile{\ExplFileName-utf8.def}
  {\ExplFileDate}{\ExplFileVersion}{\ExplFileDescription}
\cs_new_protected:Npn \__zhlipsum_set_special_catcode:
  {
    \char_set_catcode_escape:N      \+
    \char_set_catcode_group_begin:N \<
    \char_set_catcode_group_end:N   \>
    \char_set_catcode_space:N       \*
    \char_set_catcode_other:N \\
    \char_set_catcode_other:N \{
    \char_set_catcode_other:N \}
    \char_set_catcode_other:N \~
  }
\group_begin:
\__zhlipsum_set_special_catcode:
+newzhlipsum < simp >
  <
    <劳仑衣普桑，认至将指点效则机，最你更枝。想极整月正进好志次回总般，段然取向使张规军证回，世市总李率英茄持伴。用阶千样响领交出，器程办管据家元写，名其直金团。化达书据始价算每百青，金低给天济办作照明，取路豆学丽适市确。如提单各样备再成农各政，设头律走克美技说没，体交才路此在杠。响育油命转处他住有，一须通给对非交矿今该，花象更面据压来。与花断第然调，很处己队音，程承明邮。常系单要外史按机速引也书，个此少管品务美直管战，子大标蠢主盯写族般本。农现离门亲事以响规，局观先示从开示，动和导便命复机李，办队呆等需杯。见何细线名必子适取米制近，内信时型系节新候节好当我，队农否志杏空适花。又我具料划每地，对算由那基高放，育天孝。派则指细流金义月无采列，走压看计和眼提问接，作半极水红素支花。果都济素各半走，意红接器长标，等杏近乱共。层题提万任号，信来查段格，农张雨。省着素科程建持色被什，所界走置派农难取眼，并细杆至志本。>,
    <水厂共当而面三张，白家决空给意层般，单重总歼者新。每建马先口住月大，究平克满现易手，省否何安苏京。两今此叫证程事元七调联派业你，全它精据间属医拒严力步青。厂江内立拉清义边指，况半严回和得话，状整度易芬列。再根心应得信飞住清增，至例联集采家同严热，地手蠢持查受立询。统定发几满斯究后参边增消与内关，解系之展习历李还也村酸。制周心值示前她志长步反，和果使标电再主它这，即务解旱八战根交。是中文之象万影报头，与劳工许格主部确，受经更奇小极准。形程记持件志各质天因时，据据极清总命所风式，气太束书家秀低坟也。期之才引战对已公派及济，间究办儿转情革统将，周类弦具调除声坑。两了济素料切要压，光采用级数本形，管县任其坚。切易表候完铁今断土马他，领先往样拉口重把处千，把证建后苍交码院眼。较片的集节片合构进，入化发形机已斯我候，解肃飞口严。技时长次土员况属写，器始维期质离色，个至村单原否易。重铁看年程第则于去，且它后基格并下，每收感石形步而。>,
    <她己道按收面学上全始，形万然许压己金史好，力住记赤则引秧。处高方据近学级素专，者往构支明系状委起查，增子束孤不般前。相斗真它增备听片思三，听花连次志平品书消情，清市五积群面县开价现准此省持给，争式身在南决就集般，地力秧众团计。日车治政技便角想持中，厂期平及半干速区白土，观合村究研称始这少。验商眼件容果经风中，质江革再的采心年专，光制单万手斗光就，报却蹦杯材。内同数速果报做，属马市参至，入极将管医。但强质交上能只拉，据特光农无五计据，来步孤平葡院。江养水图再难气，做林因列行消特段，就解届罐盛。定她识决听人自打验，快思月断细面便，事定什呀传。边力心层下等共命每，厂五交型车想利，直下报亲积速。元前很地传气领权节，求反立全各市状，新上所走值上。明统多表过变物每区广，会王问西听观生真林，二决定助议苏。格节基全却及飞口悉，难之规利争白观，证查李却调代动斗形放数委同领，内从但五身。当了美话也步京边但容代认，放非边建按划近些派民越，更具建火法住收保步连。>,
    <术厂美义据那张别安响物，县交极长选行值深专质，眼心段极型新。格形连候眼王本加还题但，流但作基白具地机系，总严录件杰报前易。际取通主农题议需之从业少，江以受断件扮伴自。不度传间品全，青层自内治子，其询体员种。领角速院术计目化每具，体这常住更实记，在应争却根陕员。自传不展持心方约厂，济件过所转特济，外达才部至局。习例件气保候府社它，算际小毛相角方车次场马，难切龙弦制形界办。感头两华交务毛林回都节业点，两群月具受们即积生。调直给这着风火能圆商一，知易众美布会亲军千，件声坑志支较学。农六斯南何记子机量各然，快写线信权间越部色，象照屈型部物治地长。难要技第对老共达质标压心，才种日自针豆助养。政快下正型究条东话加争行整便，些改民流花按低重伸你。院心没离则收称革局，七件小收月通示布，导外员林村增。革电认速志海再事满传海，京深二百明家打开识连，林备转刷位体置进义。治风理年构族业酸整要第，认取历难丽园变队。>,
    <太研认发影们毛消义飞，传立观极思工观查反，响八露加杨适克励受布例子东适进式数，连生片很门都说响今，领该术护家老支。许半相部加最都力只段，石半增热议务断天，布传孟青水足办认定。提加听置即明听报，达表那革连极型列局，社磨百处备的。做表果育改干里管张完，九听取便常则建。书改压马米本强，确已起今或，很扯呈。中化品况声人收和土又，成据便先花儿结先，身法材不组雨马。治方二没那始按知点，安住强际林维识整，转体医京型期。片需周油省育角式叫，么专光自青状维月者，老满形百清局刷，都要往严同从义。求候较件声之问条算，海识层用样油习，林布。京安时治千照议权走热那，地置基员据更些板杨。车能权大率与，用建须称外角造，情陕求领华。论精七度得员程划小，前必领定包次世，位出届打系杰出。团矿该面而山石红收收时外在安商，过率但体划励半根斯却清。来青回引何有起统断统外，何它性都辰些茄。设合当她要近地事才少音，而他路或引件打识说原入，土个车图命辆该。>,
    <争身节布从选铁称后把表，业装约往始议界机整，便青盯之利圆你。们院查众达能存者响住，根子历里大里土先，定千弦丽批程之情位干数保马感里应，种毛联非养张作实全习，眼组材实我且具。结米次系议及者个在，能复林世第质其计色装按，相矿些抖极千运。因格学七根外群这，省着济今次影对，询族按但。深手活老系现最维，江特完适革海干，值用目间报。最发格使干处级，林起红信看，中火形。技委标点解除正，基特所院争法，建豆造呆结。最现便非矿组决就，步己度性平之指回，由员求克清院记。调世持被话据花及，线日易习陕她花。克采样都相使证写，音王市提王况，可争今满。西南办而花没，务过所立，团板部。政式角体果放值打且，上要领低机林下阶我，格报束届千老什。等张长品验受位今利族实子，统十技成林世容深利百头，农们团在构运况露步东。变水史品适农上，步表带已门三，没做高一业。候消能管边政飞等气，更心办要养任除并，者述水带称白。>,
    <新领决其名一有里按老进，没局省回识工然式式，斯照园位连联杜。等并众度表儿他战为值装切系，压走完清派快写提较何量，处号露论豆前详门选。石手教金做石酸如，还金白常什变新，长杨关邮。越都积满眼生管五六，战经压时厂分七火解，示结过蠢示直。军可市老选革办变，三原使说学叫标传天，接支传适如验。论府南油般日识被选，群带受行断土是色再，严传北周小伯必。山团压据头业年何例关，断清展马必建引为各。地是民斯斯实适车习调，文整史么知争回该理，千车存劳详管酸。价求通面必位员，光石电主别，后承将出磨。办四计问细委器几较，后与民器影回何车革，战力清被现。美风类支队式受思养土，复标特这最四根没，学图重时属。线她满非选强要相社，保及六水后派传团你，信露五直的件。社因受十权开百权即，列合参律对证受精心革，七现孟于扯两性易单用目流指学美，习员年传出根，叫建装共。土象石亲支内小，增信酸消至里，群孟质标茎。经资质小斯济民根无，西立全受由始音，什日学术等次。>,
    <铁进称规例本百型支，色战红元话质应，保反易投今联。适光自气布见么务西，准感办省林罐。难展料验见东真力样，身出阶容合片造重，极速约董色行。员走关特都高果委空，办合品八了阶手，商者着园值。采想节线热许且拉法，织也按属们单我，易新王海住用，构事集敌至。主合广说铁年人劳最，只千果六数可完速，形你克身任。车日派将无做只管易，于样看历置重确量，加时院码眼眼克说程白族花她被线到造称，增看段孟象声和医。到调族红准维直，入证外信育花，自头葡所。门转满平用口以矿去，开况万分族型响他，直村样居院面圆。七并想利务之光听其次证公，引确际节录见从规。目生称规门市管上该还消装单为运里响，周片县民所切霸张无抢明个抛。化化题专上，青县研月由，平极千壳。影极四加育效提际感以，政使自新例发目到部，适消该物矿系区海心。支收书下议现集题，革和员走年面广权养，没弦等统村矿商。把工住主，候我七油，市陕制。光于度指制争小商段个少小称志此，效周件多如届两列性严拉。>,
    <维则话它制，好较气资军，界小主。这成料值元元从都况集周他都局，级按方办今但丽装伶皂式明。我包表照花白理好斯器，青应其即干方花战，始委意址去走算。点件内压至证南况资，眼流使离作部质，间积你抖对业。式还得白细石红设于部体，片他音感七长没水非，提众却作屈院。特根把下除主小加解，织思技样又是近关它家今属且孤。于务社使改深量完改，政必易节查志必资增，统林单听。确究收能为数增口及，建得精他当以往京不，角构民少建束。家达照当导步容才必，眼象养条自代里过克，品道建对包过石。维两也常矿相争量，风至农界进边队口阶，风杨呀文询标。片这无多消支上头克际，达包世受被电须技林，油群李活极路调壳村。形义设地型社于们，证道矿张标她声历，制切孟求思石。实土把将办法示，近律来王后物品题，元热围天任。样米家转机展着应或，往军能联直那增，且些届孝该消育。府属记东自照并先酸无用，人十引一院却阶候，组准李年美坟林共值。>,
    <铁引容一飞团江十计，革大事习世约人在养，社头岗连究眼。养率都到精在代子，深或新王界部标，新指屈半针即般。研容龙片几转度天提，被研样及候式复外，况张克带皂分知。公一器后化员，感三导快目，并否各往军。里马素百亲它亲为新解斯，提质连毛东展口团气，区劳两书使董南或完。过他规向解什，可速没及布会，共办。四反使习展段号计，百而规可日习，合重该斯。统发口行样毛先政，很马器指图头光才，反声于目争兵。果称论治活门正于时，还成飞张一红报育，被明己什投走。中毛己部书今然量现，确空值非儿从热，才北面应抛积。特克解候级严南式研得江，南表断先格资分连，要革屈层时资进家批。律四各人取局情划形军响界查小反大采是天育声南足时安画清。传其关律种它听之标，江治带法外由前京，许更形重系认卖。院矿布作新万北应些适际，传县明展员据工每真机，规满扯扮照从材孤。制商下大标世么，各化高代划林，型伯列。领条看的低细，南月这专处，济李我原。>,
    <资边形外压他术器头政月名，断向或高反程达义数可，非争准快太新苏。题对始目风的八律，条者原需易白，放豆太济雪听。象于社技安场育节，民在而下车把速处，者研弦杏对农鹰。难周飞说者重劳，她员六里阶切知，相弦者确江单。响可越存二青了角位织了，的别相因装老，一目全豆专万。等前精毛长采目毛许少严数明各正史内始过界光隶以围伴美斗。我矿受很必元自院达金维，按厂县支所劳命酸，增合医枪路辰于员农。单包县热例眼市意消时，七厂原育打里如复色至，件且弦围日布想间束。声他声在特思质我次养府地大理带亲际求转向求出，少按苏克更矿满。更最所社边米流系，立进形心照思导，族杨址总必样。度应织之太这门我精验气，况周工名团许受极个，看治更风院历丽海机。革记量面反需备特示是内，准住单元动使只音如往层，江车陕员马私在卧拒半。长规积第品石，金想方制性局段，代蠢陕皂围。共共严对你名高政部得外最声，支取并权去询没动消家须。酸军可在局造究单，拉了导据天白研，程束步伸过音。>,
    <海带观全定事空往议，义构口角划上往义酸，就劫队做反压。经军期问全小约程，证因术志里度资，各示丧盛卧学。厂速热走治住车员调七支细式难确列，展人口列所中眼称歼每育他选李。海却分复点织教边满，但育由总革据员当论却，主式求过坊府盯兵。厂备种就公习定广期热两色数级，的全况群斯特红苏老则整。已准解王水提战，子为会构重林法干她，问蠢习体团把。究广金照回总以后收引存八将集联她行复，状越生串。事白亲何派求件任反法入技，北只种主算立照很厂阶，维详告片述还盯走。工情人美统许走意，生物合包本统气，周办极伸布。斗布省应离展装院事斯着派她，大新才构否吼坑改建。格四回验委金样合越政期，油必工和所九常到与每办丽芳积扮无辆杠。今声始力细根美按，资准下所西务新要，计束办观。式却相劳部更内，取问集研亲会应，划否力。消各已近小安手高去最增边，极满周常该还机杨。因界认确是酸被，保北指包青，管品联便。>,
    <车反用西只例则队话，相组干层九育制要，存和革豆八下。以共质立一电联低，出同四原际劳王，个除养长信就。准里农化老斯化育，龙约严数常料识行由用，到打详的为又织。节使图每来合养意千写，院构样何王门最眼究，科利越外亲杏住。报红家者无口张感小把装放公己，很可海清历。心处验道照前前不需表三，作即海把再时该马，道法性老极然所使。上议政本政道治西，率她使制农着，没吼列身细。过新叫容工证重住你力，据史更从来记积眼报，众屈呀事来板但。属实公元县真近层中，活车风个领图日少电，小理增材秤。备方很组细拉又流气素，资必们府全酸更志实，公就霸及辆号。很过油斗例表队住，始调且接率领它，声达命松基。气南把据向无及，天复革达周因代，般装详道吧位束。周眼应当江角习争，马山使五内。红如真有龙林飞入队往，平是矿动育眼主却张，力和听者值按。事般改社物引制，选素展。据斯书它过商如型究身油的物力队济持且量，县都两码表杰隶。>,
    <直做万开将各然她斗，今除还技常往所设性，别坚你秩询还。革却回反维养安立同定，现提入划育且图反气西南，那度声回保问内呈作路确根利原农流得，这二者养该结影，里导孤运变要。年不着个图布速史通这必，阶属我指如码位。准深件回七学路南共青入传及非，计其团利题布长们周但将杨。极写严中权长决江技作期，际格还第强内改革置，家因孤使身奇严此。都几林然效包除被，么采般处照色，层录克近先安。适下具图要面关派为存，又养领实然因林铁那刷已圆较贡。油才消八的存接争消格程，前二要为方肃数系今做许一八己导华日争带，该反化她文非四民，受四陕会该图足行。米证通你清十路，名建年题实，及响承反去豆。角能根好写体口先设民，组主近发开但技县等长第，边太把每其岗区养。提更又级问建难素，了最米象志华程，那员否管详何村。则去关持打人主期，常年拉别所，传医么按间。族或便指从还热改出完，广九科必值活通断，电候蠢盯提李列利。今格共标革所听观包阶任务展，商热管型压规么把整器候，义白各议万次伶到济支。>,
    <展中传加其转业，质百科确何明，满热红使。三许阶般近众还口，深很步满例天，学杏南日豆。如置号儿要元话难者一，生除种土杨区劳。决省机法引百第总做准包，取又使整肃详话装。年规问队同少天法到，回只角米飞感少越，权劳枣联效为角。完里立平土则知子反量包品，议村码劫。据问况那据被速王，严构际询我。育况海按报统，该就至大，特积杏型。然果什持设用争商海至专则，求族路六已为状要状动，写成流凝识样析全王复。军眼文进七象料下它且，们层管史与引除查观，半五丧革与面采。细关维素无管众些，规儿对要示自，发丽速材治两。整速不场总内毛非物图更圆该，连响半个极盛解他历。完体适调所果千研带现工，清般路六院列计带，海只点千极场论达。确住快较走去然认边，矿毛据量取被今，质弦励方折积。我你科图算统果约，下老才式别制，律变满油局。就本市听连件种规习适马主，议般儿活京北直得积动土小二，并本利何说基明针。民确说些风感元无统七条速感我家每，员山住商始水材蹦杏束码每利。>,
    <目论大流多整多车千，算处往规料器机后，九美屈算敌伶杜。如流门矿回也林口自强上历，东取长争领局自英斯。安消育能变用你领还办，转却行定图安下而如，上白孟正镰投低连建。手织便院行七，着眼济千近，思针园改。存代世二满容大只，标领越音生线军则枣织赤别。文思见根型是动给油油，实别争则教族至现天，族路批住越政干。转县东太集整此究义消约如，金整何类些届京飞作。却克新连联省影不已更，自期而立分他马铁传，周所杨步些伶器定。世市又府提看指属圆亲么么广形断角把，习用确专向保过列低反建大。音活市外治看外务严业完和传系，指引后音教杨址镰段究且其王向示事度效况，强政也四至。群过天此风状整角起石名处五，很分几现线决将土种向。立整行单米利成信，大列效由两构，克霸验来枪。收七当三斯委西至，属形西省求便油道，收共布时壳海级论月西作原，很般金不区很，重劫存。之运离农组代到由适向院，个存何片水按传头风育多，更第弦代造必斗了但军。>,
    <也及带展土达交步写海式，什果亲她没情律但高五解，那满孟五更属贡。其参土构平社局，理文下持地况制，青少厂利革届，豆头所本。千们之最安流已低，支八七术方，越万意政杨。成长当亲候六素者任，务很红始到率长位，满后隶惹美孝鹰。带门养结用看至你压二名世家也何，转住体去。农无前素个口步意目起，外调中很例阶作火你斯达局物，识值角安求千区使，可苏材于。热料命始指情变这质群，等指者放生革候农干，济情详织那群可选六。易着六史工干院，之千好此新再压市，中询投始反学。前已存县名将式资识书或路光全去，几并型五可李。文受率矿采期决权政，劳间性个决时，单至露治片用串。外军育而才养活外，数那马组族金话容，如院群完。领习会林强县改什问，省边叫明地验见论，局上李容至作。政内参十下支点层，话基回统克省，类找应极布。阶专计今算酸正，影重子节教，技定度扮你。动圆亲资经建候查性收，西按天毛众或。美装外状切保西金基，清中意很提队已，可式束型飞十科。>,
    <往展除线到深京布万，调任区组矿此再进，育引将须物直。料山育还给造造组关在，路圆该杯届扮。四议院多代标该民么，酸各单理队象专院，情详内毛技外连。与飞南报养队地何八意华使，必石包的辰非和根进。划被格须相传六当根确的发展消，决县切但众变通种芦。细知内济组程说委才，南中深听际王北，量度劳的想又。新数教确片老斗非现律，理不治面华常是结会还期，行但杨装求听杰。入集往斗多水消管调，白每机程万基本应非，区该低连求励串但人压共过影研三自儿精，加名立利验京油些力强知，用步飞效更只京。实物热油很县进见没，段该生化题交效况属，其前铁民旱葡成向定素管五不般六三名离由办展，中商量多研法通展月山间。影段好你查团始业平，被成些细看有。其选王原元院生行花但但变种，阶调油或议束亲联部抢。主较术度具深已进，毛上半医石覆。厂活问理或看论，格方体其会书个，北度承江况扮克。回号百南西层同已声张同建建，权这深斯制张处区直水。>,
    <写心们况型队飞已划处，便自什军专带又治经，参的杨断八低现步称认克强记问生精证，家金低达山热把态。向特验水报及又，然土照见技，始和利满。命专人组支入书条行，复代非孟往录。成石决部制周形义被难对，便中建心社型革子装合，半队目式困除县直伶准深级长真具什领片，教米近数写用完报，收他者战扮六。老那反引查严们，始期细二张老在个，眼蠢响还目。形化家务酸东约七，思油往六此想，须准心么看精之两，展改新抗济过。头基高还命族我，万查片构般领还，很也码及却。式法没来气口做造指基，目油没着商装前，济商刷助干数枝。省规能备并维到动府，然军些话律交道它，月佣处辅矿向。将更位率管反做听还标量一作，角后议义内第解离有北，光看省江斯肃将住园开。条近布圆住机军拉参角标过争青济入除光水革，新看林斯把易些。备济象半品地是些六部了实没众争造完土飞花农在满，到眼肃名去身满光广。思低华使保目他风北地酸好，例程直格己查立史究层层，地且张李验命它别并住。>,
    <红看圆权术如号办即，有所角七论新重，生青共酸打旷。际直地派后百南期，们律没杏量因建。门适引方劳制面运适体，亲县动革门层设办同，积满布意它深画。需持社电团水长太除越性，阶主龙算记对置或，做统共态针马呀抄。今深达机采起标低看年，列要义基战我估。己千维回二军标亲海建长写，半着住那安深但江。写决术养维局路料感和展极，美计千斯流织询秧走。带起七世我花变，等二不天观什，为非茎族。计青方深劳必给些与示研三入位安组，义快报前张建她件秩想越术。际委论值县厂难，江与华主增传，置声须。识书原统则能例电号养历，论律号决圆较海商上调开，她八建给要着子。信听拉观什别从代可，周到而委无处音，元划隶团实厕六得多县安没包美民由思，员己意地员实少现什果，术把线员眼色育。当革值样约关江取年，叫务之但非区日结成，参详因光秩史关速到界品约流军阶，办列领看家革提业，历弦之李农除。经具飞好目报然属系，众历军出上外求究，回或葬精芽部。>,
    <叫到铁即接品种般不法，正现方根话说消林，价三陕内眼议地民。况马些青山外律队，级世过规白飞容务，片打学影律不济。机年音把管因过书等手，没重育化你张样气团，立面承研报点奔抢豆。受理利民近打在了象，采律间支丽外江入。除些本技转现规通，那海路光化边，起盯低将重。相与照容转员克军报话局步生规到，生第往取满出边气感取成组，作电接奋格豆该包记四头。厂压命保专色平中，人没般受豆否里。连要克往引格级什联区受支世主或，级子周一半刷使或丽蠢。反本周布影的万运求群心己展节，统了几们山却低题动战派，住本所届状豆利枝品询届。人性制可原族府都机日色代公离究响即然命，年记属积均茎。级内统间以调当品众只斯，科圆业增完十连统，团复电方乱百活。照事动里林阶研毛酸油，生向建成及内革才，意济陕值易之详作。心按应活最车便接你导，动区应二细器军，标效辅员雨丧详。型商为这选就那小约步期山，马到型详歼选放最。>,
    <后完图都飞接社节切，节展斯则支期方又，部府育管扯孤。角求适直集石今按，议类事理拉派规高，治社许号八约。持快除安林身才行色酸现证电，场杨精改利。对务状联又感消战能值王，斗明空流造有意般放，力器村做程元看次。连都日上志传每，花本构维论商，带更陕林么。小府状条低西又，作给手料广看个，然议数越进豆周器满弦。自然北常要共集又用，问会业管明支战术，这取杨省该但。在十低王命千角形好，酸图总条率十计，说史蠢须南奔励。声示电是求张须热体，信图里类儿员放马成当，流把询吼战吹改。代边华林军厂度，眼条由后交素系，光露更业调它。证即受点容各例进入类，计有部无克实离管一解易，更复可并改后就统之，呆业贡性否算。江出儿圆低权，六交化都对特，接全豆。开县指市格铁热起火导内命斯美，再选克体必先他届我建斗路林。然须象则矿电，行强华克参厂，海医活利雪。月去住着照京是件指，强求识素劳决，型复角克验扯。结这日府火其月果，日取济入图。>,
    <目队段成细器了马型，目机史无从种过圆，下式陕群茄卖了。构打政清带技他标采然段音科，头规南京总常越卖豆。题效大文管养，王路西全史，得认园。工族动做集验现共转我，交满已意二长例置铁，但气动太论听且。离关着备长求次劳图开低，政确收传间约着原连心，周切歼别霸董杏伸。七细北因料除料改华传，般第连志常必省算，深查教办况吨活。却示增主了主习然，示度出区内也身，束扭己歼。空斯内因线将张活好群认包，华阶至济大居投秩但十。东第知线自非响书，林着门文半很叫常非，认集他励土。最拉需族交心音影常速，市思体共别点片前从，片许刷部束业话画五。县矿建先教己或求很总转，将色市离品孟拉东低况。与军还般龙者三即复，几运验束水刺事。属音下来科面式段教属，响京出战只场使。能原了府气名周直造状，确后号当由又军也马争习，始这丽霸号更器。么计教除利公十书，强委气求分克，约眼打装报。指面设达满业究己现派当运却着，却飞照进大极更面可细图又。>,
    <法热低红局指南江地，条后红断中加圆究，型往杯是军男。集它老方正型领器，需她越外意第己观件，住霸立林县这农。向起还什院细离平，思已联持地是县厂，可文求无团新高。处等石较满生见也，心技技代少起率，理即活才志。共保什间将保解进类，律前该往为战正，求电型北能盯。己一务过角示直机毛合们斗压拉观，展三相效变根器强难积如。利些采人京教几属正片，非科五区已提天业意，例引况伶列可松。维文状选明何正法先由，式适及样被交设身，向改领满山均吵。九解信受命专务影许义下，总事观为里话各更，任列辰两号住七思极。识出关习矿取又今，必过集音眼年，那到层放。但事约选维调参任，再生般展数量，明历否况却伶。据相间节准使等，则的人物着持便美，位数材该说五。完来约机办向法和县，成想照问没展光社，满中励箩十价皂要。有划省利车地它增发，越八亲带准南主目，过离镰百置保苗。再地是声率民二同团，学响西计六观人影，斯除更放委族率克。>,
    <标你力石线战价张回单子同立调，保青月重本反进区抛。她米东育组青二，里认人以计往想情值，周板扯两。速家命具层完把想七林思，次美济回条准解再造社进，展美辰豆海江联兵。土院我总学维光议看难，二表你压叫届求放却全。证被间来许学却后，处干二该交求气，引青还同断。题共标术较属准求例看出，设布分更石果识增则素，运类建矿事图或茄资。高里新参严张在数，气做量养程装压自孟代元研。该口但部米住看决形相只，族八矿图报治拉石除约土位否记从直将届列。调层经导议道几器到，增然更导关六空，样奇维飞乱。式采县派作原打系，十族他及本场，断更经受该。战正各传上第二，要速极音商带家以点，不蠢壳深述存由。正代打社明须子，家列八代式维，周格时克太。政么当基几张办管形使领，度老丽辰吵卖。完往及业发老省定非相，看据合变知话观法，在过李机但省素。知律也位张毛最况主，五再众所老非经，象速村性苗来。观等反公消委回切，元织增义物只象火，每建型豆你需。>,
    <前许属电加合细，多开认此社育众，般询军回束。性而该前油路及声高计表马人将，当屈反世详。及府九阶住日场山式根东，何养即而装验式务面，海米肃声详建里劳特。个及后量干空采或复市住，公间把对直研着科美但，和际直李告论声。社非实务构她老，农易此日，离角重要。再件战本值下工花引由，得放定等方头们构带，商连辆断报。象织也社再更性看相维，求体新要量变特回，业专承见查调杰。题局那养算保真红江阶界照没飞，观处最题统隶些抓隶。观适状会法准图量道给例海斯它两，压解高难习力点派亲自步带叫音称内内书流干道，照先亲目际分然发因界，观装霸消系始海。亲般如率高，音号难备深结，长足律。信主的联极全己石八该到，律记新型回相为给府拉今，长组该算七和工众建的。可增却往格持织四无交各日周，格给这边南方想土片月正类。论图论构量处行统且下领见，包五所团战传，发毛杏秩辅算。织展流方约与济规约，资己深但给值数制，农型隶只声六前。>,
    <快济计题基火花红些老毛，程史太金外王开白指七许，究些届相需收。头学族花认增，南见议与小候，严太什。采交术战们达建机海当展支义容住也他，示府求率旷听箩。度直个格造解放断，治具由对效今花，内治困板队。手九两多观家记公，或大数起群别支学，李体岗际。马两八你划少规，造无强难热，利询葛罐矿。段认者反段报，且做酸候。内儿角军料山身设且具何影日，实之红二家明力得前工应究，速省建展也信长隶克居。如西完些毛变社家由对，切设出儿门收满是，有命手代军员少。运传器技志了王作资，分适明区界多采，七形而相等立林人，杨要金集村非规。证总学至家利车员八队，许政布例物九图制工结，采等杏名东采接把卧。在亲最类观打实，路天任程速分权，则弦伴董半。着证发直长铁没西，成图集问设要，五豆杜近老。名新军在部期采无认，目己细化切质者酸图联上门详。看知文法记亲算同形放定住领，又府义带加中备备代花，这报期两级与各识节杏化。问志长积义，调里包响声，详医励。>,
    <快线石去时级六程们，支应她县色基展这小，些隶此芳丽体而。最习低步中火族引，易流如都青况会文所，院弦难受照习什。子热过或门器决常正，身须种志争识亲设题，型转连料详内东。头红情般广细备电，斯流活劳情八转调向，海杏求始与听。才个状天进边细些连叫样步，才利提两分出了具心导的，直与第陕蹦打保些求该块际方老会火按况角派己观，须结指西类松联。二但样认率两但于加，且听清回军要值相，计外抛奔等层。事现相达现老压该料了积，确组片图验花按满具养格，也同号生程辰务叫。这意事么表题教油，回根了也斗命克，门再隶多批满求。先水更在周利已象，局支才天的，查三孟也流克。状二集律际光社法式，省你参造族着应日，展束王指你或。角治布认车声年所，海龙面农形你下，么府二证罐。相定容管于克革里，物门低习交关，报万两力儿军。回于做在维类规多规程三，火等书它选找严住。术七南活专养今如路，和问包阶极，证入再西每步。想引想加已例养消再，克三满始义放回，计为听芦贡。>,
    <量作务白无天走群地会已，干主列部深步估个。向华所提声如速律，院科于题学除石原了，情他京吨折科前。料车家进段最段线点业达些手接生何，省派两思找届。你区流线则真别，命利所空农根命均着群。边果高离这点商身今正此意，把由声它界周总做八把，它为业当满周数成点，段色间豆段律医村告。起到论石色群样，口求会专主林，最本被界。称即件效除情须复做回的，式关眼题着励酸通。江标东许集质所面分们机，族指全身名线然即，究解相针件认员。除一们选口历美克，快织导断专场组应，较真就质织。引可义类会建手议走把风间点路，分济生厂多点约公按呈那批。为地被原相积便思压知越十业作，当作更回图利肃参求志。才进特该内须精，才各点米查复县，容心山除行运，复接路选村。色家及马反道华高情，阶后学指询厕进发。当参团般积教程眼，民即劳业照明回采但杨领能。音他次王东导向还者业，此联需严转先调基，织形清照第。走一委理长流团，书议交林斯，内京需在。>,
    <度严何的会山，规识无化，文蠢能石。加容队传市府使象少须状，观油列型派先通后，革毛种边投战求们。查基它子量么团属义第必，走什林反养枝身素果。此展参场几中委农油口，老记革断队变三，社动建式露该使院。会性按非中团口动，接海图与达感组数，豆满米。好受着联里位，报家造么，万主段。太元本意四值叫华，没角象算张间，求镰折壳书。律局经使书划社期治质，土拉电给各铁识，结明里期查中劳。约干准但正观将群压，二商世队真件所团，划队僚杯吼。教带明下任布大对都内，说算青省布全习们她根数细求点保两霸花业。将角定再信该器还报，报深命百算属资应，系品儿龙后。阶委公名日规置织声，近去只加战间家务，也型合确布。结林习该计毛应持其持，反难得省应品亲土极，使大杨报岗数难。样七对气阶干般林界转完，律手斯思增包务它完力定，带示届个则里大。本好按质想共西设转但众维工，相白果明见定论算该之只，红元类两究消时声询身出。千反置入积分内因水又件家出因，保持加利必蠢没罐织三那。>,
    <来分各天类速经华界格，水光使住心效得原政置，天老束务惹府露。元团情他布合也济如总西说，至强九系极录敌农领。活指划选选受少红，先史经水上心又，题过录励村消矿。别果查果收着别，直意带县，然丽财更般。条老四京非化证号北干，万影看记流电其结，调族孤连孟报助秀。华质长在求细知说得，太红回速接分律记收位霸战金完集。林体起江形前而加，定王验力决了，机交结就实。般广目厂两阶声置信叫原，理外家置备实也先区可，算期形员管素。流没任又空史五相由与造个术没，重如此都识路矿红矿针。家导龙对边装求往约，不力离全业地工多，与型增期易西重。常历以般况变书步基查，六风或中起万南点么水清，府织励准霸造我时。技局矿非则细过节见联目深心半车，反持做想查存带即隶器办。低低联增今维华个还，性件义二度两外满，保证励要步动。几由能单法查从，所技理资指成，料军杏向格男。受多加别月世原速包从话，历林接照满飞处广验设达，组取理把些改别空。>,
    <用拉流年热精维许多共，整级就造素来示不此经，至所孟奋民两贡。过米王最验事了果得强，工气阶务张人采路，平美毛相苏卖求经化我流住教属以及科克，那色表效支老面中细，半要肃青质月抛天。其置决部体京完太习军处然，的知及王细度气资头太并，米然被向医始盯料他。区候色引平际斗海效原专，那示给拉反导和主，经农克平把现。派论亲地老收决半导，明运毛出己身工三报，科枕上例。太酸矿火确数他等院长，战东否屈带百。满深级化做位确光世而己军即运新，类看建严道节联录至断收物写。认证清属事义际式，研海定位走几反声，效则孟接书私当。作感组有各表空流百县例半出来改斗向门，位条蠢利芽程么政。个然样用感清线儿她样，南文问什广下次织以，发设飞名文例一。件方于四主是或便，角她机太点花，素该吹议。六向传习导照界，九车类备火争，土承积自。传非保受长亲科六，但深度技合工广部，须辰省旱花。争工济解后决细关，更龙争极学电各器资，再才求五众候。>,
    <根近家线严识行飞样一，节片气及议万打打几，业手否常气多画何亲厂会少都水着了象花因，断争油名见今条里，相马杨葡相候及该。一满始程都积济同，多并风再制，程次石酸过。矿面将验活期更，好又论据王为这，消会增声得。先整眼断段该等了法片，因育便众术建先按，以相村扮板军大。物照着每写解么算，能流走维建型，证传拉抗芬酸。龙儿识变道问提解包，进候代与实各此流，子利据管岗。此养什好市局水空，性公律取法广改，火屈最点及群。该听消民直，品这命提传派，长己呈。高向议自手青务观会身，机或空量状多白用业向，变单适命办根响高。书机步进建商公意，率阶从七识，列表隶身长群。要取知着更查次天，及变际度后所利，受露询更。要少商来标证主段决需基水做名，称观西结干众弦辅率两导。点民果更信位增例市就九作式，北专劳运元按地间效类外，走水记如几该低露八。书那三传变风积阶规，步装相放可专美，可弦示走在系。区大布进划民率能美标带，展美段究听杨上才月。>,
    <经化心理众术身精外验地世设复，又我重专的间他实王现想金事，习影求总利圆本史委详。层年求毛统八新意定，造状展速开才干科委几求析经做析。查到们车几道构市立少装，按气约内制指间改易，接全告带丧惹扭交。经规解什民八值四会或，争除存选并东设五，里部两须水意杨织。太历适反工好使好时，认始月清上参政，内外先将导王露，立佣惹你料材。速导布省青单利三，心同每放律则，然省白多辆。方机正每利易格之例，空决造斯部得状增才，军但劫内根。断九事水法路类性很，身及进新心至直七月，青算深通是容，音秤杯歼或受。集持增社研花改世，活身话员四因据，今收南。别身真时个斯共争，内影济集极江就开，业医兵易热。需老金低样可商法立还切，现广统验还族其教算家，半育己杏磨作容批花。使观布商次确际众布，构总很你展。生列形特员县入分低自先布转更求组上手前适活京，新照秧装红八难秧。己品或象布利军地低持，选公东联完结际思飞划，切华弦治员扯路下斯。>,
    <以线则厂来此，影色子消心它，热李响业。快派周受金风更白确都，能拉派层电从把好者严，张建刷提枣过离隶学。基去流须值两增生委，具气据好表命基非或，它复也中格此色葡。支价细调维山根构非，真证素其两无给习置照，至又即品本光商。传领入必单火门外类度，将称工满打观流带放包打，法工几通罐口子录。力况数器县争快精值，八类市感完问活调电极，更地车响分带束。现存但么山识用段用电品，非道片格高如住化千处，带已录旱候中积完用类放圆土统从果备海精空道，没管什即太是还此华格建，万包辰其史技传管。须原几影在般展，有报束适。看变情农始至权少都，设但空四动状，称长杏估化达豆。系本料叫非因派全部，整受发越装头，素低极性克位给。回除队易统切建资，划类今些最入众，器露越质折。门般革流团科场可不值务电，它和阶关层山化强特美，质山所别厂到承更。标看立路农计能多书前物，场般车圆导步两支作强南届决象江并海听。进况验形要想至研然量，才省出展制出值北位，标取材呈束奋低公。>,
    <和种位天低委石色好，正等百海书在部所管，快屈听时完吨转。设选具解列九际，广历何江毛其，行影励两门针。圆热由许音级己近，万越华书很选下，话格调们机时者，圆矿芦医枕。易七半论完清，内术消主拉油，白详相就象。动能团华史音代民速层质，装运制院更土。只花本状装技办决示合置书，场如北业好参新土日白眼期划边坑光翻飞然。流记层及办结规委说反，便石象进但战会这，全始少民葡助。两劳达当你关千结集议，物生力查土许正用成人，色村理等劳深。特队它部场题单关飞八建查，除历收由器号李极取图。术价行说地经少化代走算，法效流千都按是织形，目展很立备亲。算调很基信与共性在，情口片存主号研持期，你经历展王样。最律清下口合断又据，每照关果多外议确，全火弦话识代受习。外南老见织就之划，平没流原争状主个，些意织即芽杨。家格须选加统区才委得整上易，领亲空中对该录按运同农。酸引装眼向科效该，也计热五难上名加造，情海精造采。>,
    <片元水作飞白制开平，离准者增受象划东见，现孤苍及号针做。结当类该空况量需必包干放细府，同增风引公军励陕给全在再。学细化别组，革之值军提装，道八消。水验北共养二身经应离，有酸真心采张成，当广录吵工志集非。便历中马有或率分满市开维，须它相图丽呀器。自论通场阶来决越至米话并，织专需为反观走们机来，都格真劳军听能京扯。走厂我土称并地收运状报中有，从公效按美什壳。照主统区点点即变引派节口，什革器角志医京造领只。起每住查，质人线红究，吹。加根采正事张先开厂图，究更安农着众越，类同们于部这杨。识最油开精为且加元文长千方物求历她，却制难原影影决建经奇任近此。工里件政口得西业从将经起真约加，些选地金正现反响万好否军。政区个变其就联，至子持己其，或新合。是常织可厂议几等经界，规有军间点放何，东军两难电人向。却我并包号状县律，开可基写从质器，观要葛蹦习。处通期同史次员断，情政无转商区成其，明世屈芽置观高。>,
    <越使持儿出种记各十动及办，名米变斗位结取究必实往，角主录过里中务西其。月团据满放政志去思段，实相总性理因人治，件技车经想见。劳细化红明保向不解，主达往决了须感，教老蠢复奋雨声今响族务强酸色和厂查年得大公劳最，最力过与向种李主断伴身院。老处明质今段那矿规，多新门研群影或石，想战向最即置。究院斯易适传成路斯力，常边的生型四作去空价，非记市陕该领证还。节立层西下热状学明，离斗白报型山示报特，后村立雪照们。立属理系些水用复离，保法每样他队确论，极整际那能斯识。报改两育理小其代准，低七话放中入七非至，取造极特起秀现料。好属制保型厂的位军，部东住想动道口按向，者会此从表京连。向七打段感元实调，还时论至状论近非，除目露思内才刷。识育作期元难集拉情入内体口，门世只验步权入要行。又义开度层平务和任，按他自相下少复动，角求例凝三委定。分委却技从场制群拉，院快议张结平但，决满把私块届持。市称重更多无思响，眼改军便办利线，片贡再罐为。>,
    <查因构美满保规不术，音矿难却体里治片影，它利果科坟刺。期正打部单油类商分，得民军革流日风众定族，消里标承呆样。易精全北走部式东群通每则，一我织美给整品资困。义发安基才表铁年里究作连约三，太至上很不划月观美目门。节然着领积下工么张就军文层军多常龙构格形主，大光张大族动克陕。物此等划何示而计林区更织一和小想，去龙询影业般书。毛高所常间米它，统白外验电，真话钉该。路入支也带养利反般任非重，光形率强类段和格运，观他专美命家单届生。除准收万专写解感养本，达共适情业府基，本道建教己习该。变且行王观身复铁理，西阶图肃霸茄。自说张格导适院布，大意则音八种你，我单更护学。算容面维器规处准定数，因采先群电调位查文拉，入广丽报但最整克。组为林流越工下响众，他想消阶器族场是最度，百级材极当虚事抗。个名活由统他还解体，美易住资才众应到亲，政是村杰眼何抗秧。声易究南代族，速知增界验关据，而辰抓次敌。>,
    <标小何林性美，议空何力月走，许秧态。本回型毛可第斯本自，眼取见开身来心，消更村告次导。关用因按划这类用质，矿江声置容了直重，之码总芦子肃。着会边她民重间经千，式张值及情平更率队长，市点蹦此根只届。打声理始真史引七提给，型心己类提不织，太行细引当我品到。保历活红速更运报具果，往车布茅基提。分何命具民使发头议使派没，会划自们思明极出当南给省，么所她赤间坊雨共团。为统领量化较被准也办道，议石区易况外范苍。二计计根头具，增其走书议，存己史亲。王关达节选效大求委改则，安一同形上又设那题，连自该十果间和效原。以事生民可省中克众才住造，导铁想公定南可划运和热，利活省眼住苗流使定枣。教十器战段厂快得连入然斗质加，当表色此离时批呀导改芦。队将强收队六你参术，的积然很员装五铁，史安束钉时询在适。大次间相政类安何，面意两究件包京，标速单之元松。要会命办金两指义期在回照织由走政可美至，走毛极更英专。>,
    <程天目性记它加，体部因个你，但肃告建美。将性亲因决具共查，接一离带研电，速克动芽内。义那度强打际级研，过与制型情难，眼豆吧音。进成过机今改被矿化，拉军内大象而院，众采辰西装新。被给属好它是线或，过给山相连以式，非弦音改可满。要达数先派自却新解具，用五院段什备研体与入气，研入材求支他质调。门须王集提或化因，她些已长学。影农般命展离始音，复特金学。学山铁年七斯离路，调化传能拉对海统，常把村严立住斗。此有不点用山拉一眼，飞广小步约特七对，本合孤制半划。济高又情族同识，之联议议么构心活，不杏邮要折里。器八目正广民济结北资，路先场示就切开四式，阶联材又位数表歼。使为成除看子明间空报物安公有部领断意期马，还根集世任军建。众变易具上放问走老，清现本为战各听，时次辰录意枪扯。置消易水了军京，也张完此别合，酸候呈率。权划存较没金如结劳老快，千属满设火所西因月物，对济弦围该查风心验要。报工酸展长法接公，报导光特目什布中还当辅半。>,
    <压才特变算准系意两报长，空适三标形而条候千别，者分极法太何或。空装圆法我积，计医身。酸劳准局保又开市又，走斗深适什并选，参强肃长定财却。较须边周度清体保织市，儿石元把相经运会，声要平需旷应儿。总结两却南己场命，论或土难然运较五受书干员使头就队。角及量过持装圆强年布，北么马题西层如山般变，斯弦历吼。参前约单来型化包整百，求克在西该私面五。生青市条争清统例此向表每地，百革它后度群万收芽态。段速眼说与对但并算样，意斯受干青本却清。花从设间院完动社山，太院况便治名文打法段事外每完隶，刷听就看听。理元之必此图并可制所家，没维半为及形级九，后根详听雨头治这然。外并题建体京增联从格原，第给际难带证进见，总改阶能什须完。本知亲都化美没信老管种，标度而肃程规的。酸个义周实号广容给没火布，约头也素其越县就型，效置料承翻那攻动伯极。太时完历美术水，作选都且确决到论本刷写究间覆。积品很市火线的个，识写深步龙都，质村约折果片。>,
    <率非关极照自九，名号细十根行革，委坟土。元使强石非来受该少，干研铁那响于式个，声系蠢奇式更通覆。从所联后后效话拉，身查天用体阶王民，领建飞研自拉易。回地整没确基响体将集，保复生力号米常土素，传干省细届二级。达整活交观命易教，象共却义取到须给，清需多导葡如。办白代使打水连存难算九器场，元过干些主所葡。样严断据育住满白条布断界其容，速才空理民史九豆丽那。性置者无些维写组先位场拉建身，老也军很关肃否发打保。回六及里成着话区解，列增点火织毛人属，油运霸书它反习局。九发较打象组油江加，至马基车把起快达，两运询基局设斗时。火存果直从调研构方被，千况越积程法争基各适音，更南近改更僚困型后再进速给来象东料，义资律声团交军文方，布县秧验苗旷。习达离断拉点飞他，消张来直更强同矿强也，该该旷时没划争。三样参计片至感难科白权亲算，深经华支价下报道采传打。可油清式家满家，如那酸龙现石工，即丽位型主军。>,
    <上约保平体代周或起不，众话大格层研里江，单各肃茎式医严辰。运了须实太权度么，月关地保来科强技斯，几支高声秩第。色养细领号这内林山，面果机委开列元满，世较豆丽边坝苗。气一群以料格此历，定世至压照利场是深候，种见辰极露越亲箩。话难感证领办称，场会队展格金白，西求是乱布局。公物心被导团最影，安石广较儿，直单斗器革。观外干好不文究例，律生西多每时化，认建利皂李。断离气装社准越前历，起事关始加收多，消如材论吧传查机八下用没身表过间文，压米义多员家争严记道，集这详极茄伴。适近才这相电型每无，些机单所与色们解量，始关对务任装罐。改种解事对马天具么参育，原口办放识属金研外可，太马对询求提规板家。做县都必条而开间速你，报他技和量其情主便，两列屈置五直。列非达同原段一存什引直所还层，都被开法片酸子接强火物容，论群相隶论越手医惹相能孟。着用区往何二提又提式，把定查军林土方，听内或肃兵近动。五报严调得满月京被局交，率角车安属不内济正四，过层孟计杨起里连身。>,
    <马高类林什片深铁根，白计命标持命专一，许小蠢是专做。者少亲角文受格动，证际品业着千处却，流也杨兵秃秀消。新格却复例交级根，深前从安究更门，目工指业单。话我习置按存说所西格都议家务派下清选点并任组，约决术豆录该分址卖吵。便角系观命调些，原十重性总改联土，分蠢困肃热旷。明路研论感常进被先，矿级光日做市类，放石只始团已。手步算率色率思实法压身运，治样最铁详基在听想。办法马业转开现成口民向，同空文议将经切特众该布励件据点的酸。眼种问种车并流儿意，程代等线快把知严子，杏过者除养安。同代设他高备原直示约花，求观者工来教好节己积可后弦县圆对道丧雨。状收器道布县拉用活次候二，育段此形少便与被商，几身后村电称知题雨音。取文则中元带越八权花，白住正织常性。算必和建建安样时很进，深年专品子本式议，装消详心走连。细革多识称易接具约长民南与，设非只少例之李参统市月。厂理说转角段万，具即明流压实先，向鹰识刷。>,
    <议之使类价反团众又包社改整统，响题见组群眼机整二水。路完科花精音做到东同，例子着眼消义去基规做，权向弦励规常斯管。地青团和快物者，大世好文眼过光，机列电旷这。没社种放发事可直要着半保管个，争引先科酸。应领设由近十下明局后，青府火元京支持，号调刷写见更实全。等民同亲给示进记技开，石基去村保义统片高拉军白专程边市效算院，带元适精近度支个样质。往物厂关带直米色政地周，加经收率每报强更外争，月所届光抖酸近赤我。命七易起日，装话速过，行手听。发那验单合路采精，如及商任称意，面霸告了个米。展人期族办点青美经他动与，速育火权存象选争片中人，且处往积个领局析。各以准院六土类确，内住打名青至，县确呀或。积见业看放十次今张，京对置开前程放，质果该块钉材。他和是百过王打速，干须身况中万类志，养亲鹰本箩。说持成专省称，严响斯把七，达孟性与凝。离除利被美带任，平界面月少干，和材何商在。式基能京定民都科，受去复品对等，之志蠢坑态。>,
    <部算么红越价始去车重打，办历府就却路需原给，达数杨按界扭样方。周接看积路易质利，件型压出县各共正，除最每包我。物花三提中备细除质中，安东片新证型度科点满，北太规步租例住来。新增斯什科线要单中，第着金但合有酸它，整准该场出人医严。月本调点断界正上提办应号，织同常价置孟覆葛容力。省飞装身和工再格月，部准点候原他各段算展，必共两算话历林西。造儿气口原则来，准具去造相布，引求告土听奇。去象革因自提整把东商，而被重书头也织，将该提议己清隶。量龙来为具其圆意切级利干元型代，文权认马力各呀估但取。万即将集构造求变又到备度响，教格天候单几这新。什队行想又发方，领们完而么公压，不弦角你观。律展分利专除统设，写战回查证还龙感，装共雨约月进。出严很农知一示，成重必受传五高命，候铁心心厂门居，人露般做意。酸月例化县中光克以年二，五织给半精枣建代。界办回什组三分把土太极九从精极素少到，斗常装求矿求重。>,
    <深便做素极育在划几得严才，查按七教列居两奇本然。门品我被千话表深，及近报以图再上，府价者记雪呈。什相满何资据间少传，线根力接布多，程酸励把卧百。听大军为对因此容问政铁并东理，生金月你肃吼第造与豆。根工每业价想流主声响，治体成算部计特地，上空丽最价八行点。照养极矿给不看速常治矿次集院电型，交争线术开金难极辆劫收打十屈。领给现太平量连，口用得众，三最石。社动为拉少太别体求意精把成部气明，接不质对热什李枪王律义。间切系有定心新土使存，天着间作打群基无始见，越公承派民三劳。各式直下子去与选发，定结团展书热类，安于如管却规。子专装争指应入个青，将样离肃管给往。南型准省自议政成儿，酸象往最多感断五，设材金陕义去办。压面矿小一世同说才算口，平对确提安长制科领时，种五坚七住种直满。总节深八持住些段线重，斗得话完现积存别，什拉录串行做万。京被这格条周百样结习，并拉表拉少本总报，多多为特内村林。>,
    <建群而图省必料备土海数价，本设团东全那般实低指矿选，程己建交消二承便两。何接装何红能北们作复，们直加们象省便织具，头方材老心。意半必支红制百节高形，记为人际历代青克，提白性值给单。太几美老先能设千关体效给格工，没文年争级林来图又音。界照必每许集步，决路民听。太工易或计等满拉，想种规府的越酸，个手话本体。则论受清她从却式置，复准支特表派便，热矿劫私则。术际代打华基论难物相，并间断也院这历已压增，斗无存带京第。世这西据度它县义，学自见广下放电也，例观蹦积历。市日又新矿治流存广现，样市后任头新史象全到，般段备方析员理。确族场点她人可，厂容极位具火问，积离传西调往，杨陕性们加告。科万当往南色引深起，格着多做京组据对酸，光清束抖飞积。从相业张真办组头治，收实制定反文议查除，办形建第可僚呈呜。北基行内标样治状土之，马约称影万罐王抓。据际化地果具许，地查式细水，满霸护料快。全型适参身只音做将者，着被据长着身见都，市承足助秩使赤。>,
    <是与油才认养联出系号，北观运市思装别存高，非金林更连界农。金基话则华集，团加争么样群市，律承状军取。广四管间电期些习究，时能中平路打做酸，需数建材更豆两新。府劳者头规而满同期，之容八了才东车，组弦第确知李度。人年民所任它可接，住料在选切较气，千结加现发。酸厂中路存连基群拉或，利存路工采石先都，下米义以度土求。得酸标现料族往次精，要样采节向斯集，多隶告果苍。实第学回办保由许且化，系龙近分提南果安采，至行只酸们。空通利时到之选叫记经加，采那风理带干集色们，铁达将济无助伴。图难十位经府所里做，期用发政名基育做，省他承一文。统思种速越老于，时例线厂式，心院声均。取作等角提车是全际次，方石以见代越给按。老光水清龙来众列平消，领力面称说家改，转农小金盛除维。家百那了近统领心科，写小从区海般反满，想入矿调。过深该联感六算地员，克二已金处究信较，光然居相被。状头置亲只没集达周面，火号定受适意力须素严，决场辰众板葡己。>
  >
+newzhlipsum < trad >
  <
    <勞侖衣普桑，認至將指點效則機，最你更枝。想極整月正進好志次回總般，段然取向使張規軍證回，世市總李率英茄持伴。用階千樣響領交出，器程辦管據家元寫，名其直金團。化達書據始價算每百青，金低給天濟辦作照明，取路豆學麗適市確。如提單各樣備再成農各政，設頭律走克美技說沒，體交才路此在杠。響育油命轉處他住有，一須通給對非交礦今該，花象更面據壓來。與花斷第然調，很處己隊音，程承明郵。常系單要外史按機速引也書，個此少管品務美直管戰，子大標蠢主盯寫族般本。農現離門親事以響規，局觀先示從開示，動和導便命複機李，辦隊呆等需杯。見何細線名必子適取米制近，內信時型系節新候節好當我，隊農否志杏空適花。又我具料劃每地，對算由那基高放，育天孝。派則指細流金義月無采列，走壓看計和眼提問接，作半極水紅素支花。果都濟素各半走，意紅接器長標，等杏近亂共。層題提萬任號，信來查段格，農張雨。省著素科程建持色被什，所界走置派農難取眼，並細杆至志本。>,
    <水廠共當而面三張，白家決空給意層般，單重總殲者新。每建馬先口住月大，究平克滿現易手，省否何安蘇京。兩今此叫證程事元七調聯派業你，全它精據間屬醫拒嚴力步青。廠江內立拉清義邊指，況半嚴回和得話，狀整度易芬列。再根心應得信飛住清增，至例聯集采家同嚴熱，地手蠢持查受立詢。統定發幾滿斯究後參邊增消與內關，解系之展習曆李還也村酸。制周心值示前她志長步反，和果使標電再主它這，即務解旱八戰根交。是中文之象萬影報頭，與勞工許格主部確，受經更奇小極准。形程記持件志各質天因時，據據極清總命所風式，氣太束書家秀低墳也。期之才引戰對已公派及濟，間究辦兒轉情革統將，周類弦具調除聲坑。兩了濟素料切要壓，光採用級數本形，管縣任其堅。切易表候完鐵今斷土馬他，領先往樣拉口重把處千，把證建後蒼交碼院眼。較片的集節片合構進，入化發形機已斯我候，解肅飛口嚴。技時長次土員況屬寫，器始維期質離色，個至村單原否易。重鐵看年程第則於去，且它後基格並下，每收感石形步而。>,
    <她己道按收面學上全始，形萬然許壓己金史好，力住記赤則引秧。處高方據近學級素專，者往構支明系狀委起查，增子束孤不般前。相鬥真它增備聽片思三，聽花連次志平品書消情，清市五積群面縣開價現准此省持給，爭式身在南決就集般，地力秧眾團計。日車治政技便角想持中，廠期平及半幹速區白土，觀合村究研稱始這少。驗商眼件容果經風中，質江革再的采心年專，光制單萬手鬥光就，報卻蹦杯材。內同數速果報做，屬馬市參至，入極將管醫。但強質交上能只拉，據特光農無五計據，來步孤平葡院。江養水圖再難氣，做林因列行消特段，就解屆罐盛。定她識決聽人自打驗，快思月斷細面便，事定什呀傳。邊力心層下等共命每，廠五交型車想利，直下報親積速。元前很地傳氣領權節，求反立全各市狀，新上所走值上。明統多表過變物每區廣，會王問西聽觀生真林，二決定助議蘇。格節基全卻及飛口悉，難之規利爭白觀，證查李卻調代動鬥形放數委同領，內從但五身。當了美話也步京邊但容代認，放非邊建按劃近些派民越，更具建火法住收保步連。>,
    <術廠美義據那張別安響物，縣交極長選行值深專質，眼心段極型新。格形連候眼王本加還題但，流但作基白具地機系，總嚴錄件傑報前易。際取通主農題議需之從業少，江以受斷件扮伴自。不度傳間品全，青層自內治子，其詢體員種。領角速院術計目化每具，體這常住更實記，在應爭卻根陝員。自傳不展持心方約廠，濟件過所轉特濟，外達才部至局。習例件氣保候府社它，算際小毛相角方車次場馬，難切龍弦制形界辦。感頭兩華交務毛林回都節業點，兩群月具受們即積生。調直給這著風火能圓商一，知易眾美布會親軍千，件聲坑志支較學。農六斯南何記子機量各然，快寫線信權間越部色，象照屈型部物治地長。難要技第對老共達質標壓心，才種日自針豆助養。政快下正型究條東話加爭行整便，些改民流花按低重伸你。院心沒離則收稱革局，七件小收月通示布，導外員林村增。革電認速志海再事滿傳海，京深二百明家打開識連，林備轉刷位體置進義。治風理年構族業酸整要第，認取曆難麗園變隊。>,
    <太研認發影們毛消義飛，傳立觀極思工觀查反，響八露加楊適克勵受布例子東適進式數，連生片很門都說響今，領該術護家老支。許半相部加最都力只段，石半增熱議務斷天，布傳孟青水足辦認定。提加聽置即明聽報，達表那革連極型列局，社磨百處備的。做表果育改幹裡管張完，九聽取便常則建。書改壓馬米本強，確已起今或，很扯呈。中化品況聲人收和土又，成據便先花兒結先，身法材不組雨馬。治方二沒那始按知點，安住強際林維識整，轉體醫京型期。片需周油省育角式叫，麼專光自青狀維月者，老滿形百清局刷，都要往嚴同從義。求候較件聲之問條算，海識層用樣油習，林布。京安時治千照議權走熱那，地置基員據更些板楊。車能權大率與，用建須稱外角造，情陝求領華。論精七度得員程劃小，前必領定包次世，位出屆打系傑出。團礦該面而山石紅收收時外在安商，過率但體劃勵半根斯卻清。來青回引何有起統斷統外，何它性都辰些茄。設合當她要近地事才少音，而他路或引件打識說原入，土個車圖命輛該。>,
    <爭身節布從選鐵稱後把表，業裝約往始議界機整，便青盯之利圓你。們院查眾達能存者響住，根子曆裡大裡土先，定千弦麗批程之情位幹數保馬感裡應，種毛聯非養張作實全習，眼組材實我且具。結米次系議及者個在，能複林世第質其計色裝按，相礦些抖極千運。因格學七根外群這，省著濟今次影對，詢族按但。深手活老系現最維，江特完適革海幹，值用目間報。最發格使幹處級，林起紅信看，中火形。技委標點解除正，基特所院爭法，建豆造呆結。最現便非礦組決就，步己度性平之指回，由員求克清院記。調世持被話據花及，線日易習陝她花。克採樣都相使證寫，音王市提王況，可爭今滿。西南辦而花沒，務過所立，團板部。政式角體果放值打且，上要領低機林下階我，格報束屆千老什。等張長品驗受位今利族實子，統十技成林世容深利百頭，農們團在構運況露步東。變水史品適農上，步錶帶已門三，沒做高一業。候消能管邊政飛等氣，更心辦要養任除並，者述水帶稱白。>,
    <新領決其名一有裡按老進，沒局省回識工然式式，斯照園位連聯杜。等並眾度表兒他戰為值裝切系，壓走完清派快寫提較何量，處號露論豆前詳門選。石手教金做石酸如，還金白常什變新，長楊關郵。越都積滿眼生管五六，戰經壓時廠分七火解，示結過蠢示直。軍可市老選革辦變，三原使說學叫標傳天，接支傳適如驗。論府南油般日識被選，群帶受行斷土是色再，嚴傳北周小伯必。山團壓據頭業年何例關，斷清展馬必建引為各。地是民斯斯實適車習調，文整史麼知爭回該理，千車存勞詳管酸。價求通面必位員，光石電主別，後承將出磨。辦四計問細委器幾較，後與民器影回何車革，戰力清被現。美風類支隊式受思養土，複標特這最四根沒，學圖重時屬。線她滿非選強要相社，保及六水後派傳團你，信露五直的件。社因受十權開百權即，列合參律對證受精心革，七現孟于扯兩性易單用目流指學美，習員年傳出根，叫建裝共。土象石親支內小，增信酸消至裡，群孟質標莖。經資質小斯濟民根無，西立全受由始音，什日學術等次。>,
    <鐵進稱規例本百型支，色戰紅元話質應，保反易投今聯。適光自氣布見麼務西，准感辦省林罐。難展料驗見東真力樣，身出階容合片造重，極速約董色行。員走關特都高果委空，辦合品八了階手，商者著園值。采想節線熱許且拉法，織也按屬們單我，易新王海住用，構事集敵至。主合廣說鐵年人勞最，只千果六數可完速，形你克身任。車日派將無做只管易，於樣看曆置重確量，加時院碼眼眼克說程白族花她被線到造稱，增看段孟象聲和醫。到調族紅准維直，入證外信育花，自頭葡所。門轉滿平用口以礦去，開況萬分族型響他，直村樣居院面圓。七並想利務之光聽其次證公，引確際節錄見從規。目生稱規門市管上該還消裝單為運裡響，周片縣民所切霸張無搶明個拋。化化題專上，青縣研月由，平極千殼。影極四加育效提際感以，政使自新例發目到部，適消該物礦系區海心。支收書下議現集題，革和員走年面廣權養，沒弦等統村礦商。把工住主，候我七油，市陝制。光於度指制爭小商段個少小稱志此，效周件多如屆兩列性嚴拉。>,
    <維則話它制，好較氣資軍，界小主。這成料值元元從都況集周他都局，級按方辦今但麗裝伶皂式明。我包表照花白理好斯器，青應其即幹方花戰，始委意址去走算。點件內壓至證南況資，眼流使離作部質，間積你抖對業。式還得白細石紅設於部體，片他音感七長沒水非，提眾卻作屈院。特根把下除主小加解，織思技樣又是近關它家今屬且孤。於務社使改深量完改，政必易節查志必資增，統林單聽。確究收能為數增口及，建得精他當以往京不，角構民少建束。家達照當導步容才必，眼象養條自代裡過克，品道建對包過石。維兩也常礦相爭量，風至農界進邊隊口階，風楊呀文詢標。片這無多消支上頭克際，達包世受被電須技林，油群李活極路調殼村。形義設地型社於們，證道礦張標她聲曆，制切孟求思石。實土把將辦法示，近律來王后物品題，元熱圍天任。樣米家轉機展著應或，往軍能聯直那增，且些屆孝該消育。府屬記東自照並先酸無用，人十引一院卻階候，組准李年美墳林共值。>,
    <鐵引容一飛團江十計，革大事習世約人在養，社頭崗連究眼。養率都到精在代子，深或新王界部標，新指屈半針即般。研容龍片幾轉度天提，被研樣及候式複外，況張克帶皂分知。公一器後化員，感三導快目，並否各往軍。裡馬素百親它親為新解斯，提質連毛東展口團氣，區勞兩書使董南或完。過他規向解什，可速沒及布會，共辦。四反使習展段號計，百而規可日習，合重該斯。統發口行樣毛先政，很馬器指圖頭光才，反聲於目爭兵。果稱論治活門正于時，還成飛張一紅報育，被明己什投走。中毛己部書今然量現，確空值非兒從熱，才北面應拋積。特克解候級嚴南式研得江，南表斷先格資分連，要革屈層時資進家批。律四各人取局情劃形軍響界查小反大采是天育聲南足時安畫清。傳其關律種它聽之標，江治帶法外由前京，許更形重系認賣。院礦布作新萬北應些適際，傳縣明展員據工每真機，規滿扯扮照從材孤。制商下大標世麼，各化高代劃林，型伯列。領條看的低細，南月這專處，濟李我原。>,
    <資邊形外壓他術器頭政月名，斷向或高反程達義數可，非爭准快太新蘇。題對始目風的八律，條者原需易白，放豆太濟雪聽。象于社技安場育節，民在而下車把速處，者研弦杏對農鷹。難周飛說者重勞，她員六裡階切知，相弦者確江單。響可越存二青了角位織了，的別相因裝老，一目全豆專萬。等前精毛長采目毛許少嚴數明各正史內始過界光隸以圍伴美鬥。我礦受很必元自院達金維，按廠縣支所勞命酸，增合醫槍路辰于員農。單包縣熱例眼市意消時，七廠原育打裡如複色至，件且弦圍日布想間束。聲他聲在特思質我次養府地大理帶親際求轉向求出，少按蘇克更礦滿。更最所社邊米流系，立進形心照思導，族楊址總必樣。度應織之太這門我精驗氣，況周工名團許受極個，看治更風院曆麗海機。革記量面反需備特示是內，准住單元動使只音如往層，江車陝員馬私在臥拒半。長規積第品石，金想方制性局段，代蠢陝皂圍。共共嚴對你名高政部得外最聲，支取並權去詢沒動消家須。酸軍可在局造究單，拉了導據天白研，程束步伸過音。>,
    <海帶觀全定事空往議，義構口角劃上往義酸，就劫隊做反壓。經軍期問全小約程，證因術志裡度資，各示喪盛臥學。廠速熱走治住車員調七支細式難確列，展人口列所中眼稱殲每育他選李。海卻分複點織教邊滿，但育由總革據員當論卻，主式求過坊府盯兵。廠備種就公習定廣期熱兩色數級，的全況群斯特紅蘇老則整。已准解王水提戰，子為會構重林法幹她，問蠢習體團把。究廣金照回總以後收引存八將集聯她行複，狀越生串。事白親何派求件任反法入技，北只種主算立照很廠階，維詳告片述還盯走。工情人美統許走意，生物合包本統氣，周辦極伸布。鬥布省應離展裝院事斯著派她，大新才構否吼坑改建。格四回驗委金樣合越政期，油必工和所九常到與每辦麗芳積扮無輛杠。今聲始力細根美按，資准下所西務新要，計束辦觀。式卻相勞部更內，取問集研親會應，劃否力。消各已近小安手高去最增邊，極滿周常該還機楊。因界認確是酸被，保北指包青，管品聯便。>,
    <車反用西只例則隊話，相組幹層九育制要，存和革豆八下。以共質立一電聯低，出同四原際勞王，個除養長信就。准裡農化老斯化育，龍約嚴數常料識行由用，到打詳的為又織。節使圖每來合養意千寫，院構樣何王門最眼究，科利越外親杏住。報紅家者無口張感小把裝放公己，很可海清曆。心處驗道照前前不需表三，作即海把再時該馬，道法性老極然所使。上議政本政道治西，率她使制農著，沒吼列身細。過新叫容工證重住你力，據史更從來記積眼報，眾屈呀事來板但。屬實西元縣真近層中，活車風個領圖日少電，小理增材秤。備方很組細拉又流氣素，資必們府全酸更志實，公就霸及輛號。很過油鬥例表隊住，始調且接率領它，聲達命松基。氣南把據向無及，天複革達周因代，般裝詳道吧位束。周眼應當江角習爭，馬山使五內。紅如真有龍林飛入隊往，平是礦動育眼主卻張，力和聽者值按。事般改社物引制，選素展。據斯書它過商如型究身油的物力隊濟持且量，縣都兩碼表傑隸。>,
    <直做萬開將各然她鬥，今除還技常往所設性，別堅你秩詢還。革卻回反維養安立同定，現提入劃育且圖反氣西南，那度聲回保問內呈作路確根利原農流得，這二者養該結影，裡導孤運變要。年不著個圖布速史通這必，階屬我指如碼位。准深件回七學路南共青入傳及非，計其團利題布長們周但將楊。極寫嚴中權長決江技作期，際格還第強內改革置，家因孤使身奇嚴此。都幾林然效包除被，麼采般處照色，層錄克近先安。適下具圖要面關派為存，又養領實然因林鐵那刷已圓較貢。油才消八的存接爭消格程，前二要為方肅數系今做許一八己導華日爭帶，該反化她文非四民，受四陝會該圖足行。米證通你清十路，名建年題實，及響承反去豆。角能根好寫體口先設民，組主近發開但技縣等長第，邊太把每其崗區養。提更又級問建難素，了最米象志華程，那員否管詳何村。則去關持打人主期，常年拉別所，傳醫麼按間。族或便指從還熱改出完，廣九科必值活通斷，電候蠢盯提李列利。今格共標革所聽觀包階任務展，商熱管型壓規麼把整器候，義白各議萬次伶到濟支。>,
    <展中傳加其轉業，質百科確何明，滿熱紅使。三許階般近眾還口，深很步滿例天，學杏南日豆。如置號兒要元話難者一，生除種土楊區勞。決省機法引百第總做准包，取又使整肅詳話裝。年規問隊同少天法到，回只角米飛感少越，權勞棗聯效為角。完裡立平土則知子反量包品，議村碼劫。據問況那據被速王，嚴構際詢我。育況海按報統，該就至大，特積杏型。然果什持設用爭商海至專則，求族路六已為狀要狀動，寫成流凝識樣析全王複。軍眼文進七象料下它且，們層管史與引除查觀，半五喪革與面采。細關維素無管眾些，規兒對要示自，發麗速材治兩。整速不場總內毛非物圖更圓該，連響半個極盛解他曆。完體適調所果千研帶現工，清般路六院列計帶，海只點千極場論達。確住快較走去然認邊，礦毛據量取被今，質弦勵方折積。我你科圖算統果約，下老才式別制，律變滿油局。就本市聽連件種規習適馬主，議般兒活京北直得積動土小二，並本利何說基明針。民確說些風感元無統七條速感我家每，員山住商始水材蹦杏束碼每利。>,
    <目論大流多整多車千，算處往規料器機後，九美屈算敵伶杜。如流門礦回也林口自強上曆，東取長爭領局自英斯。安消育能變用你領還辦，轉卻行定圖安下而如，上白孟正鐮投低連建。手織便院行七，著眼濟千近，思針園改。存代世二滿容大只，標領越音生線軍則棗織赤別。文思見根型是動給油油，實別爭則教族至現天，族路批住越政幹。轉縣東太集整此究義消約如，金整何類些屆京飛作。卻克新連聯省影不已更，自期而立分他馬鐵傳，周所楊步些伶器定。世市又府提看指屬圓親麼麼廣形斷角把，慣用確專向保過列低反建大。音活市外治看外務嚴業完和傳系，指引後音教楊址鐮段究且其王向示事度效況，強政也四至。群過天此風狀整角起石名處五，很分幾現線決將土種向。立整行單米利成信，大列效由兩構，克霸驗來槍。收七當三斯委西至，屬形西省求便油道，收共布時殼海級論月西作原，很般金不區很，重劫存。之運離農組代到由適向院，個存何片水按傳頭風育多，更第弦代造必鬥了但軍。>,
    <也及帶展土達交步寫海式，什果親她沒情律但高五解，那滿孟五更屬貢。其參土構平社局，理文下持地況制，青少廠利革屆，豆頭所本。千們之最安流已低，支八七術方，越萬意政楊。成長當親候六素者任，務很紅始到率長位，滿後隸惹美孝鷹。帶門養結用看至你壓二名世家也何，轉住體去。農無前素個口步意目起，外調中很例階作火你斯達局物，識值角安求千區使，可蘇材於。熱料命始指情變這質群，等指者放生革候農幹，濟情詳織那群可選六。易著六史工幹院，之千好此新再壓市，中詢投始反學。前已存縣名將式資識書或路光全去，幾並型五可李。文受率礦采期決權政，勞間性個決時，單至露治片用串。外軍育而才養活外，數那馬組族金話容，如院群完。領習會林強縣改什問，省邊叫明地驗見論，局上李容至作。政內參十下支點層，話基回統克省，類找應極布。階專計今算酸正，影重子節教，技定度扮你。動圓親資經建候查性收，西按天毛眾或。美裝外狀切保西金基，清中意很提隊已，可式束型飛十科。>,
    <往展除線到深京布萬，調任區組礦此再進，育引將須物直。料山育還給造造組關在，路圓該杯屆扮。四議院多代標該民麼，酸各單理隊象專院，情詳內毛技外連。與飛南報養隊地何八意華使，必石包的辰非和根進。劃被格須相傳六當根確的發展消，決縣切但眾變通種蘆。細知內濟組程說委才，南中深聽際王北，量度勞的想又。新數教確片老鬥非現律，理不治面華常是結會還期，行但楊裝求聽傑。入集往鬥多水消管調，白每機程萬基本應非，區該低連求勵串但人壓共過影研三自兒精，加名立利驗京油些力強知，用步飛效更只京。實物熱油很縣進見沒，段該生化題交效況屬，其前鐵民旱葡成向定素管五不般六三名離由辦展，中商量多研法通展月山間。影段好你查團始業平，被成些細看有。其選王原元院生行花但但變種，階調油或議束親聯部搶。主較術度具深已進，毛上半醫石覆。廠活問理或看論，格方體其會書個，北度承江況扮克。回號百南西層同已聲張同建建，權這深斯制張處區直水。>,
    <寫心們況型隊飛已劃處，便自什軍專帶又治經，參的楊斷八低現步稱認克強記問生精證，家金低達山熱把態。向特驗水報及又，然土照見技，始和利滿。命專人組支入書條行，複代非孟往錄。成石決部制周形義被難對，便中建心社型革子裝合，半隊目式困除縣直伶准深級長真具什領片，教米近數寫用完報，收他者戰扮六。老那反引查嚴們，始期細二張老在個，眼蠢響還目。形化家務酸東約七，思油往六此想，須准心麼看精之兩，展改新抗濟過。頭基高還命族我，萬查片構般領還，很也碼及卻。式法沒來氣口做造指基，目油沒著商裝前，濟商刷助幹數枝。省規能備並維到動府，然軍些話律交道它，月傭處輔礦向。將更位率管反做聽還標量一作，角後議義內第解離有北，光看省江斯肅將住園開。條近布圓住機軍拉參角標過爭青濟入除光水革，新看林斯把易些。備濟象半品地是些六部了實沒眾爭造完土飛花農在滿，到眼肅名去身滿光廣。思低華使保目他風北地酸好，常式直格己查立史究層層，地且張李驗命它別並住。>,
    <紅看圓權術如號辦即，有所角七論新重，生青共酸打曠。際直地派後百南期，們律沒杏量因建。門適引方勞制面運適體，親縣動革門層設辦同，積滿布意它深畫。需持社電團水長太除越性，階主龍算記對置或，做統共態針馬呀抄。今深達機采起標低看年，列要義基戰我估。己千維回二軍標親海建長寫，半著住那安深但江。寫決術養維局路料感和展極，美計千斯流織詢秧走。帶起七世我花變，等二不天觀什，為非莖族。計青方深勞必給些與示研三入位安組，義快報前張建她件秩想越術。際委論值縣廠難，江與華主增傳，置聲須。識書原統則能例電號養曆，論律號決圓較海商上調開，她八建給要著子。信聽拉觀什別從代可，周到而委無處音，元劃隸團實廁六得多縣安沒包美民由思，員己意地員實少現什果，術把線員眼色育。當革值樣約關江取年，叫務之但非區日結成，參詳因光秩史關速到界品約流軍階，辦列領看家革提業，曆弦之李農除。經具飛好目報然屬系，眾曆軍出上外求究，回或葬精芽部。>,
    <叫到鐵即接品種般不法，正現方根話說消林，價三陝內眼議地民。況馬些青山外律隊，級世過規白飛容務，片打學影律不濟。機年音把管因過書等手，沒重育化你張樣氣團，立面承研報點奔搶豆。受理利民近打在了象，采律間支麗外江入。除些本技轉現規通，那海路光化邊，起盯低將重。相與照容轉員克軍報話局步生規到，生第往取滿出邊氣感取成組，作電接奮格豆該包記四頭。廠壓命保專色平中，人沒般受豆否裡。連要克往引格級什聯區受支世主或，級子周一半刷使或麗蠢。反本周布影的萬運求群心己展節，統了幾們山卻低題動戰派，住本所屆狀豆利枝品詢屆。人性制可原族府都機日色代公離究響即然命，年記屬積均莖。級內統間以調當品眾只斯，科圓業增完十連統，團複電方亂百活。照事動裡林階研毛酸油，生向建成及內革才，意濟陝值易之詳作。心按應活最車便接你導，動區應二細器軍，標效輔員雨喪詳。型商為這選就那小約步期山，馬到型詳殲選放最。>,
    <後完圖都飛接社節切，節展斯則支期方又，部府育管扯孤。角求適直集石今按，議類事理拉派規高，治社許號八約。持快除安林身才行色酸現證電，場楊精改利。對務狀聯又感消戰能值王，鬥明空流造有意般放，力器村做程元看次。連都日上志傳每，花本構維論商，帶更陝林麼。小府狀條低西又，作給手料廣看個，然議數越進豆周器滿弦。自然北常要共集又用，問會業管明支戰術，這取楊省該但。在十低王命千角形好，酸圖總條率十計，說史蠢須南奔勵。聲示電是求張須熱體，信圖裡類兒員放馬成當，流把詢吼戰吹改。代邊華林軍廠度，眼條由後交素系，光露更業調它。證即受點容各例進入類，計有部無克實離管一解易，更複可並改後就統之，呆業貢性否算。江出兒圓低權，六交化都對特，接全豆。開縣指市格鐵熱起火導內命斯美，再選克體必先他屆我建鬥路林。然須象則礦電，行強華克參廠，海醫活利雪。月去住著照京是件指，強求識素勞決，型複角克驗扯。結這日府火其月果，日取濟入圖。>,
    <目隊段成細器了馬型，目機史無從種過圓，下式陝群茄賣了。構打政清帶技他標采然段音科，頭規南京總常越賣豆。題效大文管養，王路西全史，得認園。工族動做集驗現共轉我，交滿已意二長例置鐵，但氣動太論聽且。離關著備長求次勞圖開低，政確收傳間約著原連心，周切殲別霸董杏伸。七細北因料除料改華傳，般第連志常必省算，深查教辦況噸活。卻示增主了主習然，示度出區內也身，束扭己殲。空斯內因線將張活好群認包，華階至濟大居投秩但十。東第知線自非響書，林著門文半很叫常非，認集他勵土。最拉需族交心音影常速，市思體共別點片前從，片許刷部束業話畫五。縣礦建先教己或求很總轉，將色市離品孟拉東低況。與軍還般龍者三即複，幾運驗束水刺事。屬音下來科面式段教屬，響京出戰只場使。能原了府氣名周直造狀，確後號當由又軍也馬爭習，始這麗霸號更器。麼計教除利公十書，強委氣求分克，約眼打裝報。指面設達滿業究己現派當運卻著，卻飛照進大極更面可細圖又。>,
    <法熱低紅局指南江地，條後紅斷中加圓究，型往杯是軍男。集它老方正型領器，需她越外意第己觀件，住霸立林縣這農。向起還什院細離平，思已聯持地是縣廠，可文求無團新高。處等石較滿生見也，心技技代少起率，理即活才志。共保什間將保解進類，律前該往為戰正，求電型北能盯。己一務過角示直機毛合們鬥壓拉觀，展三相效變根器強難積如。利些采人京教幾屬正片，非科五區已提天業意，例引況伶列可松。維文狀選明何正法先由，式適及樣被交設身，向改領滿山均吵。九解信受命專務影許義下，總事觀為裡話各更，任列辰兩號住七思極。識出關習礦取又今，必過集音眼年，那到層放。但事約選維調參任，再生般展數量，明曆否況卻伶。據相間節准使等，則的人物著持便美，位數材該說五。完來約機辦向法和縣，成想照問沒展光社，滿中勵籮十價皂要。有劃省利車地它增發，越八親帶准南主目，過離鐮百置保苗。再地是聲率民二同團，學響西計六觀人影，斯除更放委族率克。>,
    <標你力石線戰價張回單子同立調，保青月重本反進區拋。她米東育組青二，裡認人以計往想情值，周板扯兩。速家命具層完把想七林思，次美濟回條准解再造社進，展美辰豆海江聯兵。土院我總學維光議看難，二表你壓叫屆求放卻全。證被間來許學卻後，處幹二該交求氣，引青還同斷。題共標術較屬准求例看出，設布分更石果識增則素，運類建礦事圖或茄資。高裡新參嚴張在數，氣做量養程裝壓自孟代元研。該口但部米住看決形相只，族八礦圖報治拉石除約土位否記從直將屆列。調層經導議道幾器到，增然更導關六空，樣奇維飛亂。式采縣派作原打系，十族他及本場，斷更經受該。戰正各傳上第二，要速極音商帶家以點，不蠢殼深述存由。正代打社明鬚子，家列八代式維，周格時克太。政麼當基幾張辦管形使領，度老麗辰吵賣。完往及業發老省定非相，看據合變知話觀法，在過李機但省素。知律也位張毛最況主，五再眾所老非經，象速村性苗來。觀等反公消委回切，元織增義物只象火，每建型豆你需。>,
    <前許屬電加合細，多開認此社育眾，般詢軍回束。性而該前油路及聲高計表馬人將，當屈反世詳。及府九階住日場山式根東，何養即而裝驗式務面，海米肅聲詳建裡勞特。個及後量幹空采或複市住，公間把對直研著科美但，和際直李告論聲。社非實務構她老，農易此日，離角重要。再件戰本值下工花引由，得放定等方頭們構帶，商連輛斷報。象織也社再更性看相維，求體新要量變特回，業專承見查調傑。題局那養算保真紅江階界照沒飛，觀處最題統隸些抓隸。觀適狀會法准圖量道給例海斯它兩，壓解高難習力點派親自步帶叫音稱內內書流幹道，照先親目際分然發因界，觀裝霸消系始海。親般如率高，音號難備深結，長足律。信主的聯極全己石八該到，律記新型回相為給府拉今，長組該算七和工眾建的。可增卻往格持織四無交各日周，格給這邊南方想土片月正類。論圖論構量處行統且下領見，包五所團戰傳，發毛杏秩輔算。織展流方約與濟規約，資己深但給值數制，農型隸只聲六前。>,
    <快濟計題基火花紅些老毛，程史太金外王開白指七許，究些屆相需收。頭學族花認增，南見議與小候，嚴太什。采交術戰們達建機海當展支義容住也他，示府求率曠聽籮。度直個格造解放斷，治具由對效今花，內治困板隊。手九兩多觀家記公，或大數起群別支學，李體崗際。馬兩八你劃少規，造無強難熱，利詢葛罐礦。段認者反段報，且做酸候。內兒角軍料山身設且具何影日，實之紅二家明力得前工應究，速省建展也信長隸克居。如西完些毛變社家由對，切設出兒門收滿是，有命手代軍員少。運傳器技志了王作資，分適明區界多采，七形而相等立林人，楊要金集村非規。證總學至家利車員八隊，許政布例物九圖制工結，采等杏名東采接把臥。在親最類觀打實，路天任程速分權，則弦伴董半。著證發直長鐵沒西，成圖集問設要，五豆杜近老。名新軍在部期采無認，目己細化切質者酸圖聯上門詳。看知文法記親算同形放定住領，又府義帶加中備備代花，這報期兩級與各識節杏化。問志長積義，調裡包響聲，詳醫勵。>,
    <快線石去時級六程們，支應她縣色基展這小，些隸此芳麗體而。最習低步中火族引，易流如都青況會文所，院弦難受照習什。子熱過或閘器決常正，身須種志爭識親設題，型轉連料詳內東。頭紅情般廣細備電，斯流活勞情八轉調向，海杏求始與聽。才個狀天進邊細些連叫樣步，才利提兩分出了具心導的，直與第陝蹦打保些求該塊際方老會火按況角派己觀，須結指西類松聯。二但樣認率兩但於加，且聽清回軍要值相，計外拋奔等層。事現相達現老壓該料了積，確組片圖驗花按滿具養格，也同號生程辰務叫。這意事麼表題教油，回根了也鬥命克，門再隸多批滿求。先水更在周利已象，局支才天的，查三孟也流克。狀二集律際光社法式，省你參造族著應日，展束王指你或。角治布認車聲年所，海龍面農形你下，麼府二證罐。相定容管於克革裡，物門低習交關，報萬兩力兒軍。回於做在維類規多規程三，火等書它選找嚴住。術七南活專養今如路，和問包階極，證入再西每步。想引想加已例養消再，克三滿始義放回，計為聽蘆貢。>,
    <量作務白無天走群地會已，幹主列部深步估個。向華所提聲如速律，院科於題學除石原了，情他京噸折科前。料車家進段最段線點業達些手接生何，省派兩思找屆。你區流線則真別，命利所空農根命均著群。邊果高離這點商身今正此意，把由聲它界周總做八把，它為業當滿周數成點，段色間豆段律醫村告。起到論石色群樣，口求會專主林，最本被界。稱即件效除情須複做回的，式關眼題著勵酸通。江標東許集質所面分們機，族指全身名線然即，究解相針件認員。除一們選口曆美克，快織導斷專場組應，較真就質織。引可義類會建手議走把風間點路，分濟生廠多點約公按呈那批。為地被原相積便思壓知越十業作，當作更回圖利肅參求志。才進特該內須精，才各點米查複縣，容心山除行運，複接路選村。色家及馬反道華高情，階後學指詢廁進發。當參團般積教程眼，民即勞業照明回採但楊領能。音他次王東導向還者業，此聯需嚴轉先調基，織形清照第。走一委理長流團，書議交林斯，內京需在。>,
    <度嚴何的會山，規識無化，文蠢能石。加容隊傳市府使象少須狀，觀油列型派先通後，革毛種邊投戰求們。查基它子量麼團屬義第必，走什林反養枝身素果。此展參場幾中委農油口，老記革斷隊變三，社動建式露該使院。會性按非中團口動，接海圖與達感組數，豆滿米。好受著聯裡位，報家造麼，萬主段。太元本意四值叫華，沒角象算張間，求鐮折殼書。律局經使書劃社期治質，土拉電給各鐵識，結明裡期查中勞。約幹准但正觀將群壓，二商世隊真件所團，劃隊僚杯吼。教帶明下任布大對都內，說算青省布全習們她根數細求點保兩霸花業。將角定再信該器還報，報深命百算屬資應，系品兒龍後。階委公名日規置織聲，近去只加戰間家務，也型合確布。結林習該計毛應持其持，反難得省應品親土極，使大楊報崗數難。樣七對氣階幹般林界轉完，律手斯思增包務它完力定，帶示屆個則裡大。本好按質想共西設轉但眾維工，相白果明見定論算該之只，紅元類兩究消時聲詢身出。千反置入積分內因水又件家出因，保持加利必蠢沒罐織三那。>,
    <來分各天類速經華界格，水光使住心效得原政置，天老束務惹府露。元團情他布合也濟如總西說，至強九系極錄敵農領。活指劃選選受少紅，先史經水上心又，題過錄勵村消礦。別果查果收著別，直意帶縣，然麗財更般。條老四京非化證號北幹，萬影看記流電其結，調族孤連孟報助秀。華質長在求細知說得，太紅回速接分律記收位霸戰金完集。林體起江形前而加，定王驗力決了，機交結就實。般廣目廠兩階聲置信叫原，理外家置備實也先區可，算期形員管素。流沒任又空史五相由與造個術沒，重如此都識路礦紅礦針。家導龍對邊裝求往約，不力離全業地工多，與型增期易西重。常曆以般況變書步基查，六風或中起萬南點麼水清，府織勵准霸造我時。技局礦非則細過節見聯目深心半車，反持做想查存帶即隸器辦。低低聯增今維華個還，性件義二度兩外滿，保證勵要步動。幾由能單法查從，所技理資指成，料軍杏向格男。受多加別月世原速包從話，曆林接照滿飛處廣驗設達，組取理把些改別空。>,
    <用拉流年熱精維許多共，整級就造素來示不此經，至所孟奮民兩貢。過米王最驗事了果得強，工氣階務張人采路，平美毛相蘇賣求經化我流住教屬以及科克，那色表效支老面中細，半要肅青質月拋天。其置決部體京完太習軍處然，的知及王細度氣資頭太並，米然被向醫始盯料他。區候色引平際鬥海效原專，那示給拉反導和主，經農克平把現。派論親地老收決半導，明運毛出己身工三報，科枕上例。太酸礦火確數他等院長，戰東否屈帶百。滿深級化做位確光世而己軍即運新，類看建嚴道節聯錄至斷收物寫。認證清屬事義際式，研海定位走幾反聲，效則孟接書私當。作感組有各表空流百縣例半出來改鬥向門，位條蠢利芽程麼政。個然樣用感清線兒她樣，南文問什廣下次織以，發設飛名文例一。件方於四主是或便，角她機太點花，素該吹議。六向傳習導照界，九車類備火爭，土承積自。傳非保受長親科六，但深度技合工廣部，須辰省旱花。爭工濟解後決細關，更龍爭極學電各器資，再才求五眾候。>,
    <根近家線嚴識行飛樣一，節片氣及議萬打打幾，業手否常氣多畫何親廠會少都水著了象花因，斷爭油名見今條裡，相馬楊葡相候及該。一滿始程都積濟同，多並風再制，程次石酸過。礦面將驗活期更，好又論據王為這，消會增聲得。先整眼斷段該等了法片，因育便眾術建先按，以相村扮板軍大。物照著每寫解麼算，能流走維建型，證傳拉抗芬酸。龍兒識變道問提解包，進候代與實各此流，子利據管崗。此養什好市局水空，性公律取法廣改，火屈最點及群。該聽消民直，品這命提傳派，長己呈。高向議自手青務觀會身，機或空量狀多白用業向，變單適命辦根響高。書機步進建商公意，率階從七識，列表隸身長群。要取知著更查次天，及變際度後所利，受露詢更。要少商來標證主段決需基水做名，稱觀西結幹眾弦輔率兩導。點民果更信位增例市就九作式，北專勞運元按地間效類外，走水記如幾該低露八。書那三傳變風積階規，步裝相放可專美，可弦示走在系。區大布進劃民率能美標帶，展美段究聽楊上才月。>,
    <經化心理眾術身精外驗地世設複，又我重專的間他實王現想金事，習影求總利圓本史委詳。層年求毛統八新意定，造狀展速開才幹科委幾求析經做析。查到們車幾道構市立少裝，按氣約內制指間改易，接全告帶喪惹扭交。經規解什民八值四會或，爭除存選並東設五，裡部兩須水意楊織。太曆適反工好使好時，認始月清上參政，內外先將導王露，立傭惹你料材。速導布省青單利三，心同每放律則，然省白多輛。方機正每利易格之例，空決造斯部得狀增才，軍但劫內根。斷九事水法路類性很，身及進新心至直七月，青算深通是容，音秤杯殲或受。集持增社研花改世，活身話員四因據，今收南。別身真時個斯共爭，內影濟集極江就開，業醫兵易熱。需老金低樣可商法立還切，現廣統驗還族其教算家，半育己杏磨作容批花。使觀布商次確際眾布，構總很你展。生列形特員縣入分低自先布轉更求組上手前適活京，新照秧裝紅八難秧。己品或象布利軍地低持，選公東聯完結際思飛劃，切華弦治員扯路下斯。>,
    <以線則廠來此，影色子消心它，熱李響業。快派周受金風更白確都，能拉派層電從把好者嚴，張建刷提棗過離隸學。基去流須值兩增生委，具氣據好表命基非或，它複也中格此色葡。支價細調維山根構非，真證素其兩無給習置照，至又即品本光商。傳領入必單火門外類度，將稱工滿打觀流帶放包打，法工幾通罐口子錄。力況數器縣爭快精值，八類市感完問活調電極，更地車響分帶束。現存但麼山識用段用電品，非道片格高如住化千處，帶已錄旱候中積完用類放圓土統從果備海精空道，沒管什即太是還此華格建，萬包辰其史技傳管。須原幾影在般展，有報束適。看變情農始至權少都，設但空四動狀，稱長杏估化達豆。系本料叫非因派全部，整受發越裝頭，素低極性克位給。回除隊易統切建資，劃類今些最入眾，器露越質折。門般革流團科場可不值務電，它和階關層山化強特美，質山所別廠到承更。標看立路農計能多書前物，場般車圓導步兩支作強南屆決象江並海聽。進況驗形要想至研然量，才省出展制出值北位，標取材呈束奮低公。>,
    <和種位天低委石色好，正等百海書在部所管，快屈聽時完噸轉。設選具解列九際，廣曆何江毛其，行影勵兩門針。圓熱由許音級己近，萬越華書很選下，話格調們機時者，圓礦蘆醫枕。易七半論完清，內術消主拉油，白詳相就象。動能團華史音代民速層質，裝運制院更土。只花本狀裝技辦決示合置書，場如北業好參新土日白眼期劃邊坑光翻飛然。流記層及辦結規委說反，便石象進但戰會這，全始少民葡助。兩勞達當你關千結集議，物生力查土許正用成人，色村理等勞深。特隊它部場題單關飛八建查，除曆收由器號李極取圖。術價行說地經少化代走算，法效流千都按是織形，目展很立備親。算調很基信與共性在，情口片存主號研持期，你經歷展王樣。最律清下口合斷又據，每照關果多外議確，全火弦話識代受習。外南老見織就之劃，平沒流原爭狀主個，些意織即芽楊。家格須選加統區才委得整上易，領親空中對該錄按運同農。酸引裝眼向科效該，也計熱五難上名加造，情海精造采。>,
    <片元水作飛白制開平，離准者增受象劃東見，現孤蒼及號針做。結當類該空況量需必包乾放細府，同增風引公軍勵陝給全在再。學細化別組，革之值軍提裝，道八消。水驗北共養二身經應離，有酸真心采張成，當廣錄吵工志集非。便曆中馬有或率分滿市開維，須它相圖麗呀器。自論通場階來決越至米話並，織專需為反觀走們機來，都格真勞軍聽能京扯。走廠我土稱並地收運狀報中有，從公效按美什殼。照主統區點點即變引派節口，什革器角志醫京造領只。起每住查，質人線紅究，吹。加根采正事張先開廠圖，究更安農著眾越，類同們于部這楊。識最油開精為且加元文長千方物求曆她，卻制難原影影決建經奇任近此。工裡件政口得西業從將經起真約加，些選地金正現反響萬好否軍。政區個變其就聯，至子持己其，或新合。是常織可廠議幾等經界，規有軍間點放何，東軍兩難電人向。卻我並包號狀縣律，開可基寫從質器，觀要葛蹦習。處通期同史次員斷，情政無轉商區成其，明世屈芽置觀高。>,
    <越使持兒出種記各十動及辦，名米變鬥位結取究必實往，角主錄過裡中務西其。月團據滿放政志去思段，實相總性理因人治，件技車經想見。勞細化紅明保向不解，主達往決了須感，教老蠢複奮雨聲今響族務強酸色和廠查年得大公勞最，最力過與向種李主斷伴身院。老處明質今段那礦規，多新門研群影或石，想戰向最即置。究院斯易適傳成路斯力，常邊的生型四作去空價，非記市陝該領證還。節立層西下熱狀學明，離鬥白報型山示報特，後村立雪照們。立屬理系些水用複離，保法每樣他隊確論，極整際那能斯識。報改兩育理小其代准，低七話放中入七非至，取造極特起秀現料。好屬制保型廠的位軍，部東住想動道口按向，者會此從表京連。向七打段感元實調，還時論至狀論近非，除目露思內才刷。識育作期元難集拉情入內體口，門世只驗步權入要行。又義開度層平務和任，按他自相下少複動，角求例凝三委定。分委卻技從場制群拉，院快議張結平但，決滿把私塊屆持。市稱重更多無思響，眼改軍便辦利線，片貢再罐為。>,
    <查因構美滿保規不術，音礦難卻體裡治片影，它利果科墳刺。期正打部單油類商分，得民軍革流日風眾定族，消裡標承呆樣。易精全北走部式東群通每則，一我織美給整品資困。義發安基才表鐵年裡究作連約三，太至上很不劃月觀美目門。節然著領積下工麼張就軍文層軍多常龍構格形主，大光張大族動克陝。物此等劃何示而計林區更織一和小想，去龍詢影業般書。毛高所常間米它，統白外驗電，真話釘該。路入支也帶養利反般任非重，光形率強類段和格運，觀他專美命家單屆生。除准收萬專寫解感養本，達共適情業府基，本道建教己習該。變且行王觀身複鐵理，西階圖肅霸茄。自說張格導適院布，大意則音八種你，我單更護學。算容面維器規處准定數，因采先群電調位查文拉，入廣麗報但最整克。組為林流越工下響眾，他想消階器族場是最度，百級材極當虛事抗。個名活由統他還解體，美易住資才眾應到親，政是村傑眼何抗秧。聲易究南代族，速知增界驗關據，而辰抓次敵。>,
    <標小何林性美，議空何力月走，許秧態。本回型毛可第斯本自，眼取見開身來心，消更村告次導。關用因按劃這類用質，礦江聲置容了直重，之碼總蘆子肅。著會邊她民重間經千，式張值及情平更率隊長，市點蹦此根只屆。打聲理始真史引七提給，型心己類提不織，太行細引當我品到。保曆活紅速更運報具果，往車布茅基提。分何命具民使發頭議使派沒，會劃自們思明極出當南給省，麼所她赤間坊雨共團。為統領量化較被准也辦道，議石區易況外範蒼。二計計根頭具，增其走書議，存己史親。王關達節選效大求委改則，安一同形上又設那題，連自該十果間和效原。以事生民可省中克眾才住造，導鐵想公定南可劃運和熱，利活省眼住苗流使定棗。教十器戰段廠快得連入然鬥質加，當表色此離時批呀導改蘆。隊將強收隊六你參術，的積然很員裝五鐵，史安束釘時詢在適。大次間相政類安何，面意兩究件包京，標速單之元松。要會命辦金兩指義期在回照織由走政可美至，走毛極更英專。>,
    <程天目性記它加，體部因個你，但肅告建美。將性親因決具共查，接一離帶研電，速克動芽內。義那度強打際級研，過與制型情難，眼豆吧音。進成過機今改被礦化，拉軍內大象而院，眾采辰西裝新。被給屬好它是線或，過給山相連以式，非弦音改可滿。要達數先派自卻新解具，用五院段什備研體與入氣，研入材求支他質調。門須王集提或化因，她些已長學。影農般命展離始音，複特金學。學山鐵年七斯離路，調化傳能拉對海統，常把村嚴立住鬥。此有不點用山拉一眼，飛廣小步約特七對，本合孤制半劃。濟高又情族同識，之聯議議麼構心活，不杏郵要折裡。器八目正廣民濟結北資，路先場示就切開四式，階聯材又位數表殲。使為成除看子明間空報物安公有部領斷意期馬，還根集世任軍建。眾變易具上放問走老，清現本為戰各聽，時次辰錄意槍扯。置消易水了軍京，也張完此別合，酸候呈率。權劃存較沒金如結勞老快，千屬滿設火所西因月物，對濟弦圍該查風心驗要。報工酸展長法接公，報導光特目什布中還當輔半。>,
    <壓才特變算准系意兩報長，空適三標形而條候千別，者分極法太何或。空裝圓法我積，計醫身。酸勞准局保又開市又，走鬥深適什並選，參強肅長定財卻。較須邊周度清體保織市，兒石元把相經運會，聲要平需曠應兒。總結兩卻南己場命，論或土難然運較五受書幹員使頭就隊。角及量過持裝圓強年布，北麼馬題西層如山般變，斯弦曆吼。參前約單來型化包整百，求克在西該私面五。生青市條爭清統例此向表每地，百革它後度群萬收芽態。段速眼說與對但並算樣，意斯受幹青本卻清。花從設間院完動社山，太院況便治名文打法段事外每完隸，刷聽就看聽。理元之必此圖並可制所家，沒維半為及形級九，後根詳聽雨頭治這然。外並題建體京增聯從格原，第給際難帶證進見，總改階能什須完。本知親都化美沒信老管種，標度而肅程規的。酸個義周實號廣容給沒火布，約頭也素其越縣就型，效置料承翻那攻動伯極。太時完曆美術水，作選都且確決到論本刷寫究間覆。積品很市火線的個，識寫深步龍都，質村約折果片。>,
    <率非關極照自九，名號細十根行革，委墳土。元使強石非來受該少，幹研鐵那響於式個，聲系蠢奇式更通覆。從所聯後後效話拉，身查天用體階王民，領建飛研自拉易。回地整沒確基響體將集，保複生力號米常土素，傳幹省細屆二級。達整活交觀命易教，象共卻義取到須給，清需多導葡如。辦白代使打水連存難算九器場，元過幹些主所葡。樣嚴斷據育住滿白條布斷界其容，速才空理民史九豆麗那。性置者無些維寫組先位場拉建身，老也軍很關肅否發打保。回六及裡成著話區解，列增點火織毛人屬，油運霸書它反習局。九發較打象組油江加，至馬基車把起快達，兩運詢基局設鬥時。火存果直從調研構方被，千況越積程法爭基各適音，更南近改更僚困型後再進速給來象東料，義資律聲團交軍文方，布縣秧驗苗曠。習達離斷拉點飛他，消張來直更強同礦強也，該該曠時沒劃爭。三樣參計片至感難科白權親算，深經華支價下報導采傳打。可油清式家滿家，如那酸龍現石工，即麗位型主軍。>,
    <上約保平體代周或起不，眾話大格層研裡江，單各肅莖式醫嚴辰。運了須實太權度麼，月關地保來科強技斯，幾支高聲秩第。色養細領號這內林山，面果機委開列元滿，世較豆麗邊壩苗。氣一群以料格此曆，定世至壓照利場是深候，種見辰極露越親籮。話難感證領辦稱，場會隊展格金白，西求是亂佈局。公物心被導團最影，安石廣較兒，直單鬥器革。觀外幹好不文究例，律生西多每時化，認建利皂李。斷離氣裝社准越前曆，起事關始加收多，消如材論吧傳查機八下用沒身表過間文，壓米義多員家爭嚴記道，集這詳極茄伴。適近才這相電型每無，些機單所與色們解量，始關對務任裝罐。改種解事對馬天具麼參育，原口辦放識屬金研外可，太馬對詢求提規板家。做縣都必條而開間速你，報他技和量其情主便，兩列屈置五直。列非達同原段一存什引直所還層，都被開法片酸子接強火物容，論群相隸論越手醫惹相能孟。著用區往何二提又提式，把定查軍林土方，聽內或肅兵近動。五報嚴調得滿月京被局交，率角車安屬不內濟正四，過層孟計楊起裡連身。>,
    <馬高類林什片深鐵根，白計命標持命專一，許小蠢是專做。者少親角文受格動，證際品業著千處卻，流也楊兵禿秀消。新格卻複例交級根，深前從安究更門，目工指業單。話我習置按存說所西格都議家務派下清選點並任組，約決術豆錄該分址賣吵。便角系觀命調些，原十重性總改聯土，分蠢困肅熱曠。明路研論感常進被先，礦級光日做市類，放石只始團已。手步算率色率思實法壓身運，治樣最鐵詳基在聽想。辦法馬業轉開現成口民向，同空文議將經切特眾該布勵件據點的酸。眼種問種車並流兒意，程代等線快把知嚴子，杏過者除養安。同代設他高備原直示約花，求觀者工來教好節己積可後弦縣圓對道喪雨。狀收器道布縣拉用活次候二，育段此形少便與被商，幾身後村電稱知題雨音。取文則中元帶越八權花，白住正織常性。算必和建建安樣時很進，深年專品子本式議，裝消詳心走連。細革多識稱易接具約長民南與，設非只少例之李參統市月。廠理說轉角段萬，具即明流壓實先，向鷹識刷。>,
    <議之使類價反團眾又包社改整統，響題見組群眼機整二水。路完科花精音做到東同，例子著眼消義去基規做，權向弦勵規常斯管。地青團和快物者，大世好文眼過光，機列電曠這。沒社種放發事可直要著半保管個，爭引先科酸。應領設由近十下明局後，青府火元京支持，號調刷寫見更實全。等民同親給示進記技開，石基去村保義統片高拉軍白專程邊市效算院，帶元適精近度支個樣質。往物廠關帶直米色政地周，加經收率每報強更外爭，月所屆光抖酸近赤我。命七易起日，裝話速過，行手聽。發那驗單合路采精，如及商任稱意，面霸告了個米。展人期族辦點青美經他動與，速育火權存象選爭片中人，且處往積個領局析。各以准院六土類確，內住打名青至，縣確呀或。積見業看放十次今張，京對置開前程放，質果該塊釘材。他和是百過王打速，幹須身況中萬類志，養親鷹本籮。說持成專省稱，嚴響斯把七，達孟性與凝。離除利被美帶任，平介面月少幹，和材何商在。式基能京定民都科，受去複品對等，之志蠢坑態。>,
    <部算麼紅越價始去車重打，辦曆府就卻路需原給，達數楊按界扭樣方。周接看積路易質利，件型壓出縣各共正，除最每包我。物花三提中備細除質中，安東片新證型度科點滿，北太規步租例住來。新增斯什科線要單中，第著金但合有酸它，整准該場出人醫嚴。月本調點斷界正上提辦應號，織同常價置孟覆葛容力。省飛裝身和工再格月，部准點候原他各段算展，必共兩算話曆林西。造兒氣口原則來，准具去造相布，引求告土聽奇。去象革因自提整把東商，而被重書頭也織，將該提議己清隸。量龍來為具其圓意切級利幹元型代，文權認馬力各呀估但取。萬即將集構造求變又到備度響，教格天候單幾這新。什隊行想又發方，領們完而麼公壓，不弦角你觀。律展分利專除統設，寫戰回查證還龍感，裝共雨約月進。出嚴很農知一示，成重必受傳五高命，候鐵心心廠門居，人露般做意。酸月例化縣中光克以年二，五織給半精棗建代。界辦回什組三分把土太極九從精極素少到，鬥常裝求礦求重。>,
    <深便做素極育在劃幾得嚴才，查按七教列居兩奇本然。門品我被千話表深，及近報以圖再上，府價者記雪呈。什相滿何資據間少傳，線根力接布多，程酸勵把臥百。聽大軍為對因此容問政鐵並東理，生金月你肅吼第造與豆。根工每業價想流主聲響，治體成算部計特地，上空麗最價八行點。照養極礦給不看速常治礦次集院電型，交爭線術開金難極輛劫收打十屈。領給現太平量連，口用得眾，三最石。社動為拉少太別體求意精把成部氣明，接不質對熱什李槍王律義。間切系有定心新土使存，天著間作打群基無始見，越公承派民三勞。各式直下子去與選發，定結團展書熱類，安于如管卻規。子專裝爭指應入個青，將樣離肅管給往。南型准省自議政成兒，酸象往最多感斷五，設材金陝義去辦。壓面礦小一世同說才算口，平對確提安長制科領時，種五堅七住種直滿。總節深八持住些段線重，鬥得話完現積存別，什拉錄串列做萬。京被這格條周百樣結習，並拉表拉少本總報，多多為特內村林。>,
    <建群而圖省必料備土海數價，本設團東全那般實低指礦選，程己建交消二承便兩。何接裝何紅能北們作複，們直加們象省便織具，頭方材老心。意半必支紅制百節高形，記為人際歷代青克，提白性值給單。太幾美老先能設千關體效給格工，沒文年爭級林來圖又音。界照必每許集步，決路民聽。太工易或計等滿拉，想種規府的越酸，個手話本體。則論受清她從卻式置，複准支特表派便，熱礦劫私則。術際代打華基論難物相，並間斷也院這曆已壓增，鬥無存帶京第。世這西據度它縣義，學自見廣下放電也，例觀蹦積曆。市日又新礦治流存廣現，樣市後任頭新史象全到，般段備方析員理。確族場點她人可，廠容極位具火問，積離傳西調往，楊陝性們加告。科萬當往南色引深起，格著多做京組據對酸，光清束抖飛積。從相業張真辦組頭治，收實制定反文議查除，辦形建第可僚呈嗚。北基行內標樣治狀土之，馬約稱影萬罐王抓。據際化地果具許，地查式細水，滿霸護料快。全型適參身只音做將者，著被據長著身見都，市承足助秩使赤。>,
    <是與油才認養聯出系號，北觀運市思裝別存高，非金林更連界農。金基話則華集，團加爭麼樣群市，律承狀軍取。廣四管間電期些習究，時能中平路打做酸，需數建材更豆兩新。府勞者頭規而滿同期，之容八了才東車，組弦第確知李度。人年民所任它可接，住料在選切較氣，千結加現發。酸廠中路存連基群拉或，利存路工採石先都，下米義以度土求。得酸標現料族往次精，要樣采節向斯集，多隸告果蒼。實第學回辦保由許且化，系龍近分提南果安采，至行只酸們。空通利時到之選叫記經加，采那風理帶幹集色們，鐵達將濟無助伴。圖難十位經府所裡做，期用發政名基育做，省他承一文。統思種速越老于，時例線廠式，心院聲均。取作等角提車是全際次，方石以見代越給按。老光水清龍來眾列平消，領力面稱說家改，轉農小金盛除維。家百那了近統領心科，寫小從區海般反滿，想入礦調。過深該聯感六算地員，克二已金處究信較，光然居相被。狀頭置親只沒集達周面，火號定受適意力須素嚴，決場辰眾板葡己。>
  >
+newzhlipsum < nanshanjing >
  <
    <南山經之首曰䧿山。其首曰招搖之山，臨于西海之上，多桂，多金玉。有草焉，其狀如韭而青花，其名曰祝餘，食之不飢。有木焉，其狀如穀而黑理，其花四照，其名曰迷穀，佩之不迷。有獸焉，其狀如禺而白耳，伏行人走，其名曰狌狌，食之善走。麗𪊨之水出焉，而西流注于海，其中多育沛，佩之無瘕疾。>,
    <又東三百里，曰堂庭之山，多棪木，多白猿，多水玉，多黃金。>,
    <又東三百八十里，曰猨翼之山，其中多怪獸，水多怪魚，多白玉，多腹虫，多怪蛇，多怪木，不可以上。>,
    <又東三百七十里，曰杻陽之山，其陽多赤金，其陰多白金。有獸焉，其狀如馬而白首，其文如虎而赤尾，其音如謠，其名曰鹿蜀，佩之宜子孫。怪水出焉，而東流注于憲翼之水。其中多玄龜，其狀如龜而鳥首虺尾，其名曰旋龜，其音如判木，佩之不聾，可以為底。>,
    <東三百里祗山，多水，無草木。有魚焉，其狀如牛，陵居，蛇尾有翼，其羽在魼下，其音如留牛，其名曰鯥，冬死而夏生，食之無腫疾。>,
    <又東四百里，曰亶爰之山，多水，無草木，不可以上。有獸焉，其狀如狸而有髦，其名曰類，自為牝牡，食者不妬。>,
    <又東三百里，曰基山，其陽多玉，其陰多怪木。有獸焉，其狀如羊，九尾四耳，其目在背，其名曰猼訑，佩之不畏。有鳥焉，其狀如雞而三首六目，六足三翼，其名曰𪁺𩿧，食之無臥。>,
    <又東三百里，曰青丘之山，其陽多玉，其陰多青䨼。有獸焉，其狀如狐而九尾，其音如嬰兒，能食人，食者不蠱。有鳥焉，其狀如鳩，其音若呵，名曰灌灌，佩之不惑。英水出焉，南流注于即翼之澤。其中多赤鱬，其狀如魚而人面，其音如鴛鴦，食之不疥>,
    <又東三百五十里，曰箕尾之山，其尾踆于東海，多沙石。汸水出焉，而南流注于淯，其中多白玉。>,
    <凡䧿山之首，自招搖之山，以至箕尾之山，凡十山，二千九百五十里。其神狀皆鳥身而龍首，其祠之禮：毛用一璋玉瘞，糈用稌米，一壁，稻米、白菅為席。>,
    <《南次二經》之首，曰柜山，西臨流黃，北望諸毗，東望長右。英水出焉，西南流注于赤水，其中多白玉，多丹粟。有獸焉，其狀如豚，有距，其音如狗吠，其名曰狸力，見則其縣多土功。有鳥焉，其狀如鴟而人手，其音如痺，其名曰鴸，其鳴自號也，見則其縣多放士。>,
    <東南四百五十里，曰長右之山，無草木，多水。有獸焉，其狀如禺而四耳，其名長右，其音如吟，見則郡縣大水。>,
    <又東三百四十里曰堯光之山，其陽多玉，其陰多金。有獸焉，其狀如人而彘鬣，穴居而冬蟄，其名曰猾褢，其音如斲木，見則縣有大繇。>,
    <又東三百五十里，曰羽山，其下多水，其上多雨，無草木，多蝮虫。>,
    <又東三百七十里，曰瞿父之山，無草木，多金玉。>,
    <又東四百里，曰句餘之山，無草木，多金玉。>,
    <又東五百里，曰浮玉之山，北望具區，東望諸毗。有獸焉，其狀如虎而牛尾，其音如吠犬，其名曰彘，是食人。苕水出于其陰，北流注于具區。其中多鮆魚。>,
    <又東五百里，曰成山，四方而三壇，其上多金玉，其下多青䨼。𨴯水出焉，而南流注于虖勺，其中多黃金。>,
    <又東五百里，曰會稽之山，四方，其上多金玉，其下多砆石。勺水出焉，而南流注于湨。>,
    <又東五百里，曰夷山，無草木，多沙石，湨水出焉，而南流注于列塗。>,
    <又東五百里，曰僕勾之山，其上多金玉，其下多草木，無鳥獸，無水。>,
    <又東五百里，曰咸陰之山，無草木，無水。>,
    <又東四百里，曰洵山，其陽多金，其陰多玉。有獸焉，其狀如羊而無口，不可殺也，其名曰䍺。洵水出焉，而南流注于閼之澤，其中多芘蠃。>,
    <又東四百里，曰虖勺之山，其上多梓柟，其下多荊杞。滂水出焉，而東流注于海。>,
    <又東五百里，曰區吳之山，無草木，多砂石。鹿水出焉，而南流注于滂水。>,
    <又東五百里，曰鹿吳之山，上無草木，多金石。澤更之水出焉，而南流注于滂水。水有獸焉，名曰蠱雕，其狀如雕而有角，其音如嬰兒之音，是食人。>,
    <東五百里，曰漆吳之山，無草木，多博石，無玉。處于海，東望丘山，其光載出載入，是惟日次。>,
    <凡《南次二經》之首，自柜山至于漆吳之山，凡十七山，七千二百里。其神狀皆龍身而鳥首。其祠：毛用一璧瘞，糈用稌。>,
    <《南次三經》之首，曰天虞之山，其下多水，不可以上。>,
    <東五百里，曰禱過之山，其上多金玉，其下多犀、兕，多象。有鳥焉，其狀如鵁，而白首、三足、人面，其名曰瞿如，其鳴自號也。泿水出焉，而南流注于海。其中有虎蛟，其狀魚身而蛇尾，其音如鴛鴦，食者不腫，可以已痔。>,
    <又東五百里，曰丹穴之山，其上多金玉。丹水出焉，而南流注于渤海。有鳥焉，其狀如雞，五采而文，名曰鳳皇，首文曰德，翼文曰義，背文曰禮，膺文曰仁，腹文曰信。是鳥也，飲食自然，自歌自舞，見則天下安寧。>,
    <又東五百里，曰發爽之山，無草木，多水，多白猿。汎水出焉，而南流注于渤海。>,
    <又東四百里，至于旄山之尾，其南有谷，曰育遺，多怪鳥，凱風自是出。>,
    <又東四百里，至于非山之首，其上多金玉，無水，其下多蝮虫。>,
    <又東五百里，曰陽夾之山，無草木，多水。>,
    <又東五百里，曰灌湘之山，上多木，無草；多怪鳥，無獸。>,
    <又東五百里，曰鷄山，其上多金，其下多丹雘。黑水出焉，而南流注于海。其中有鱄魚，其狀如鮒而彘毛，其音如豚，見則天下大旱。>,
    <又東四百里，曰令丘之山，無草木，多火。其南有谷焉，曰中谷，條風自是出。有鳥焉，其狀如梟，人面四目而有耳，其名曰顒，其鳴自號也，見則天下大旱。>,
    <又東三百七十里，曰侖者之山，其上多金玉，其下多青䨼。有木焉，其狀如穀而赤理，其汗如漆，其味如飴，食者不飢，可以釋勞，其名曰白䓘，可以血玉。>,
    <又東五百八十里，曰禺槀之山，多怪獸，多大蛇。>,
    <東五百八十里，曰南禺之山，其上多金玉，其下多水。有穴焉，水春輒入，夏乃出，冬則閉。佐水出焉，而東南流注于海，有鳳皇、鵷鶵。>,
    <凡《南次三經》之首，自天虞之山以至南禺之山，凡一十四山，六千五百三十里。其神皆龍身而人面。其祠皆一白狗祈，糈用稌。>,
    <右南經之山志，大小凡四十山，萬六千三百八十里。>
  >
+newzhlipsum < xiangyu >
  <
    <項籍者，下相人也，字羽。初起時，年二十四。其季父項梁，梁父即楚將項燕，為秦將王翦所戮者也。項氏世世為楚將，封於項，故姓項氏。>,
    <項籍少時，學書不成，去學劍，又不成。項梁怒之。籍曰：「書足以記名姓而已。劍一人敵，不足學，學萬人敵。」於是項梁乃教籍兵法，籍大喜，略知其意，又不肯竟學。項梁嘗有櫟陽逮，乃請蘄獄掾曹咎書抵櫟陽獄掾司馬欣，以故事得已。項梁殺人，與籍避仇於吳中。吳中賢士大夫皆出項梁下。每吳中有大繇役及喪，項梁常為主辦，陰以兵法部勒賓客及子弟，以是知其能。秦始皇帝游會稽，渡浙江，梁與籍俱觀。籍曰：「彼可取而代也。」梁掩其口，曰：「毋妄言，族矣！」梁以此奇籍。籍長八尺餘，力能扛鼎，才氣過人，雖吳中子弟皆已憚籍矣。>,
    <秦二世元年七月，陳涉等起大澤中。其九月，會稽守通謂梁曰：「江西皆反，此亦天亡秦之時也。吾聞先即制人，後則為人所制。吾欲發兵，使公及桓楚將。」是時桓楚亡在澤中。梁曰：「桓楚亡，人莫知其處，獨籍知之耳。」梁乃出，誡籍持劍居外待。梁復入，與守坐，曰：「請召籍，使受命召桓楚。」守曰：「諾。」梁召籍入。須臾，梁眴籍曰：「可行矣！」於是籍遂拔劍斬守頭。項梁持守頭，佩其印綬。門下大驚，擾亂，籍所擊殺數十百人。一府中皆慴伏，莫敢起。梁乃召故所知豪吏，諭以所為起大事，遂舉吳中兵。使人收下縣，得精兵八千人。梁部署吳中豪傑為校尉、候、司馬。有一人不得用，自言於梁。梁曰：「前時某喪使公主某事，不能辦，以此不任用公。」眾乃皆伏。於是梁為會稽守，籍為裨將，徇下縣。>,
    <廣陵人召平於是為陳王徇廣陵，未能下。聞陳王敗走，秦兵又且至，乃渡江矯陳王命，拜梁為楚王上柱國。曰：「江東已定，急引兵西擊秦。」項梁乃以八千人渡江而西。聞陳嬰已下東陽，使使欲與連和俱西。陳嬰者，故東陽令史，居縣中，素信謹，稱為長者。東陽少年殺其令，相聚數千人，欲置長，無適用，乃請陳嬰。嬰謝不能，遂彊立嬰為長，縣中從者得二萬人。少年欲立嬰便為王，異軍蒼頭特起。陳嬰母謂嬰曰：「自我為汝家婦，未嘗聞汝先古之有貴者。今暴得大名，不祥。不如有所屬，事成猶得封侯，事敗易以亡，非世所指名也。」嬰乃不敢為王。謂其軍吏曰：「項氏世世將家，有名於楚。今欲舉大事，將非其人，不可。我倚名族，亡秦必矣。」於是眾從其言，以兵屬項梁。項梁渡淮，黥布、蒲將軍亦以兵屬焉。凡六七萬人，軍下邳。>,
    <當是時，秦嘉已立景駒為楚王，軍彭城東，欲距項梁。項梁謂軍吏曰：「陳王先首事，戰不利，未聞所在。今秦嘉倍陳王而立景駒，逆無道。」乃進兵擊秦嘉。秦嘉軍敗走，追之至胡陵。嘉還戰一日，嘉死，軍降。景駒走死梁地。項梁已并秦嘉軍，軍胡陵，將引軍而西。章邯軍至栗，項梁使別將朱雞石、餘樊君與戰。餘樊君死。朱雞石軍敗，亡走胡陵。項梁乃引兵入薛，誅雞石。項梁前使項羽別攻襄城，襄城堅守不下。已拔，皆阬之。還報項梁。項梁聞陳王定死，召諸別將會薛計事。此時沛公亦起沛，往焉。>,
    <居鄛人范增，年七十，素居家，好奇計，往說項梁曰：「陳勝敗碧當。夫秦滅六國，楚最無罪。自懷王入秦不反，楚人憐之至今，故楚南公曰『楚雖三戶，亡秦必楚』也。今陳勝首事，不立楚後而自立，其勢不長。今君起江東，楚蜂午之將皆爭附君者，以君世世楚將，為能復立楚之後也。」於是項梁然其言，乃求楚懷王孫心民閒，為人牧羊，立以為楚懷王，從民所望也。陳嬰為楚上柱國，封五縣，與懷王都盱臺。項梁自號為武信君。>,
    <居數月，引兵攻亢父，與齊田榮、司馬龍且軍救東阿，大破秦軍於東阿。田榮即引兵歸，逐其王假。假亡走楚。假相田角亡走趙。角弟田閒故齊將，居趙不敢歸。田榮立田儋子市為齊王。項梁已破東阿下軍，遂追秦軍。數使使趣齊兵，欲與俱西。田榮曰：「楚殺田假，趙殺田角、田閒，乃發兵。」項梁曰：「田假為與國之王，窮來從我，不忍殺之。」趙亦不殺田角、田閒以市於齊。齊遂不肯發兵助楚。項梁使沛公及項羽別攻城陽，屠之。西破秦軍濮陽東，秦兵收入濮陽。沛公、項羽乃攻定陶。定陶未下，去，西略地至雝丘，大破秦軍，斬李由。還攻外黃，外黃未下。>,
    <項梁起東阿，西，（北）〔比〕至定陶，再破秦軍，項羽等又斬李由，益輕秦，有驕色。宋義乃諫項梁曰：「戰勝而將驕卒惰者敗。今卒少惰矣，秦兵日益，臣為君畏之。」項梁弗聽。乃使宋義使於齊。道遇齊使者高陵君顯，曰：「公將見武信君乎？」曰：「然。」曰：「臣論武信君軍必敗。公徐行即免死，疾行則及禍。」秦果悉起兵益章邯，擊楚軍，大破之定陶，項梁死。沛公、項羽去外黃攻陳留，陳留堅守不能下。沛公、項羽相與謀曰：「今項梁軍破，士卒恐。」乃與呂臣軍俱引兵而東。呂臣軍彭城東，項羽軍彭城西，沛公軍碭。>,
    <章邯已破項梁軍，則以為楚地兵不足憂，乃渡河擊趙，大破之。當此時，趙歇為王，陳餘為將，張耳為相，皆走入鉅鹿城。章邯令王離、涉閒圍鉅鹿，章邯軍其南，筑甬道而輸之粟。陳餘為將，將卒數萬人而軍鉅鹿之北，此所謂河北之軍也。>,
    <楚兵已破於定陶，懷王恐，從盱臺之彭城，并項羽、呂臣軍自將之。以呂臣為司徒，以其父呂青為令尹。以沛公為碭郡長，封為武安侯，將碭郡兵。>,
    <初，宋義所遇齊使者高陵君顯在楚軍，見楚王曰：「宋義論武信君之軍必敗，居數日，軍果敗。兵未戰而先見敗徵，此可謂知兵矣。」王召宋義與計事而大說之，因置以為上將軍，項羽為魯公，為次將，范增為末將，救趙。諸別將皆屬宋義，號為卿子冠軍。行至安陽，留四十六日不進。項羽曰：「吾聞秦軍圍趙王鉅鹿，疾引兵渡河，楚擊其外，趙應其內，破秦軍必矣。」宋義曰：「不然。夫搏牛之虻不可以破蟣虱。今秦攻趙，戰勝則兵罷，我承其敝；不勝，則我引兵鼓行而西，必舉秦矣。故不如先鬬秦趙。夫被堅執銳，義不如公；坐而運策，公不如義。」因下令軍中曰：「猛如虎，很如羊，貪如狼，彊不可使者，皆斬之。」乃遣其子宋襄相齊，身送之至無鹽，飲酒高會。天寒大雨，士卒凍饑。項羽曰：「將戮力而攻秦，久留不行。今歲饑民貧，士卒食芋菽，軍無見糧，乃飲酒高會，不引兵渡河因趙食，與趙并力攻秦，乃曰『承其敝』。夫以秦之彊，攻新造之趙，其勢必舉趙。趙舉而秦彊，何敝之承！且國兵新破，王坐不安席，埽境內而專屬於將軍，國家安危，在此一舉。今不恤士卒而徇其私，非社稷之臣。」項羽晨朝上將軍宋義，即其帳中斬宋義頭，出令軍中曰：「宋義與齊謀反楚，楚王陰令羽誅之。」當是時，諸將皆慴服，莫敢枝梧。皆曰：「首立楚者，將軍家也。今將軍誅亂。」乃相與共立羽為假上將軍。使人追宋義子，及之齊，殺之。使桓楚報命於懷王。懷王因使項羽為上將軍，當陽君、蒲將軍皆屬項羽。>,
    <項羽已殺卿子冠軍，威震楚國，名聞諸侯。乃遣當陽君、蒲將軍將卒二萬渡河，救鉅鹿。戰少利，陳餘復請兵。項羽乃悉引兵渡河，皆沈船，破釜甑，燒廬舍，持三日糧，以示士卒必死，無一還心。於是至則圍王離，與秦軍遇，九戰，絕其甬道，大破之，殺蘇角，虜王離。涉閒不降楚，自燒殺。當是時，楚兵冠諸侯。諸侯軍救鉅鹿下者十餘壁，莫敢縱兵。及楚擊秦，諸將皆從壁上觀。楚戰士無不一以當十，楚兵呼聲動天，諸侯軍無不人人惴恐。於是已破秦軍，項羽召見諸侯將，入轅門，無不膝行而前，莫敢仰視。項羽由是始為諸侯上將軍，諸侯皆屬焉。>,
    <章邯軍棘原，項羽軍漳南，相持未戰。秦軍數卻，二世使人讓章邯。章邯恐，使長史欣請事。至咸陽，留司馬門三日，趙高不見，有不信之心。長史欣恐，還走其軍，不敢出故道，趙高果使人追之，不及。欣至軍，報曰：「趙高用事於中，下無可為者。今戰能勝，高必疾妒吾功；戰不能勝，不免於死。願將軍孰計之。」陳餘亦遺章邯書曰：「白起為秦將，南征鄢郢，北阬馬服，攻城略地，不可勝計，而竟賜死。蒙恬為秦將，北逐戎人，開榆中地數千里，竟斬陽周。何者？功多，秦不能盡封，因以法誅之。今將軍為秦將三歲矣，所亡失以十萬數，而諸侯并起滋益多。彼趙高素諛日久，今事急，亦恐二世誅之，故欲以法誅將軍以塞責，使人更代將軍以脫其禍。夫將軍居外久，多內卻，有功亦誅，無功亦誅。且天之亡秦，無愚智皆知之。今將軍內不能直諫，外為亡國將，孤特獨立而欲常存，豈不哀哉！將軍何不還兵與諸侯為從，約共攻秦，分王其地，南面稱孤；此孰與身伏鈇質，妻子為僇乎？」章邯狐疑，陰使候始成使項羽，欲約。約未成，項羽使蒲將軍日夜引兵度三戶，軍漳南，與秦戰，再破之。項羽悉引兵擊秦軍汙水上，大破之。>,
    <章邯使人見項羽，欲約。項羽召軍吏謀曰：「糧少，欲聽其約。」軍吏皆曰：「善。」項羽乃與期洹水南殷虛上。已盟，章邯見項羽而流涕，為言趙高。項羽乃立章邯為雍王，置楚軍中。使長史欣為上將軍，將秦軍為前行。>,
    <到新安。諸侯吏卒異時故繇使屯戍過秦中，秦中吏卒遇之多無狀，及秦軍降諸侯，諸侯吏卒乘勝多奴虜使之，輕折辱秦吏卒。秦吏卒多竊言曰：「章將軍等詐吾屬降諸侯，今能入關破秦，大善；即不能，諸侯虜吾屬而東，秦必盡誅吾父母妻子。」諸侯微聞其計，以告項羽。項羽乃召黥布、蒲將軍計曰：「秦吏卒尚眾，其心不服，至關中不聽，事必危，不如擊殺之，而獨與章邯、長史欣、都尉翳入秦。」於是楚軍夜擊阬秦卒二十餘萬人新安城南。>,
    <行略定秦地。函谷關有兵守關，不得入。又聞沛公已破咸陽，項羽大怒，使當陽君等擊關。項羽遂入，至于戲西。沛公軍霸上，未得與項羽相見。沛公左司馬曹無傷使人言於項羽曰：「沛公欲王關中，使子嬰為相，珍寶盡有之。」項羽大怒，曰：「旦日饗士卒，為擊破沛公軍！」當是時，項羽兵四十萬，在新豐鴻門，沛公兵十萬，在霸上。范增說項羽曰：「沛公居山東時，貪於財貨，好美姬。今入關，財物無所取，婦女無所幸，此其志不在小。吾令人望其氣，皆為龍虎，成五采，此天子氣也。急擊勿失。」>,
    <楚左尹項伯者，項羽季父也，素善留侯張良。張良是時從沛公，項伯乃夜馳之沛公軍，私見張良，具告以事，欲呼張良與俱去。曰：「毋從俱死也。」張良曰：「臣為韓王送沛公，沛公今事有急，亡去不義，不可不語。」良乃入，具告沛公。沛公大驚，曰：「為之柰何？」張良曰：「誰為大王為此計者？」曰：「鯫生說我曰『距關，毋內諸侯，秦地可盡王也』。故聽之。」良曰：「料大王士卒足以當項王乎？」沛公默然，曰：「固不如也，且為之柰何？」張良曰：「請往謂項伯，言沛公不敢背項王也。」沛公曰：「君安與項伯有故？」張良曰：「秦時與臣游，項伯殺人，臣活之。今事有急，故幸來告良。」沛公曰「孰與君少長？」良曰：「長於臣。」沛公曰「君為我呼入，吾得兄事之。」張良出，要項伯。項伯即入見沛公。沛公奉卮酒為壽，約為婚姻，曰：「吾入關，秋豪不敢有所近，籍吏民，封府庫，而待將軍。所以遣將守關者，備他盜之出入與非常也。日夜望將軍至，豈敢反乎！願伯具言臣之不敢倍德也。」項伯許諾。謂沛公曰：「旦日不可不蚤自來謝項王。」沛公曰：「諾。」於是項伯復夜去，至軍中，具以沛公言報項王。因言曰：「沛公不先破關中，公豈敢入乎？今人有大功而擊之，不義也，不如因善遇之。」項王許諾。>,
    <沛公旦日從百餘騎來見項王，至鴻門，謝曰：「臣與將軍戮力而攻秦，將軍戰河北，臣戰河南，然不自意能先入關破秦，得復見將軍於此。今者有小人之言，令將軍與臣有郤。」項王曰：「此沛公左司馬曹無傷言之；不然，籍何以至此。」項王即日因留沛公與飲。項王、項伯東向坐。亞父南向坐。亞父者，范增也。沛公北向坐，張良西向侍。范增數目項王，舉所佩玉珪以示之者三，項王默然不應。范增起，出召項莊，謂曰：「君王為人不忍，若入前為壽，壽畢，請以劍舞，因擊沛公於坐，殺之。不者，若屬皆且為所虜。」莊則入為壽，壽畢，曰：「君王與沛公飲，軍中無以為樂，請以劍舞。」項王曰：「諾。」項莊拔劍起舞，項伯亦拔劍起舞，常以身翼蔽沛公，莊不得擊。於是張良至軍門，見樊噲。樊噲曰：「今日之事何如？」良曰：「甚急。今者項莊拔劍舞，其意常在沛公也。」噲曰：「此迫矣，臣請入，與之同命。」噲即帶劍擁盾入軍門。交戟之衛士欲止不內，樊噲側其盾以撞，衛士仆地，噲遂入，披帷西向立，瞋目視項王，頭髮上指，目眥盡裂。項王按劍而跽曰：「客何為者？」張良曰：「沛公之參乘樊噲者也。」項王曰：「壯士，賜之卮酒。」則與斗卮酒。噲拜謝，起，立而飲之。項王曰：「賜之彘肩。」則與一生彘肩。樊噲覆其盾於地，加彘肩上，拔劍切而啗之。項王曰：「壯士，能復飲乎？」樊噲曰：「臣死且不避，卮酒安足辭！夫秦王有虎狼之心，殺人如不能舉，刑人如恐不勝，天下皆叛之。懷王與諸將約曰『先破秦入咸陽者王之』。今沛公先破秦入咸陽，豪毛不敢有所近，封閉宮室，還軍霸上，以待大王來。故遣將守關者，備他盜出入與非常也。勞苦而功高如此，未有封侯之賞，而聽細說，欲誅有功之人。此亡秦之續耳，竊為大王不取也。」項王未有以應，曰：「坐。」樊噲從良坐。坐須臾，沛公起如廁，因招樊噲出。>,
    <沛公已出，項王使都尉陳平召沛公。沛公曰：「今者出，未辭也，為之柰何？」樊噲曰：「大行不顧細謹，大禮不辭小讓。如今人方為刀俎，我為魚肉，何辭為。」於是遂去。乃令張良留謝。良問曰：「大王來何操？」曰：「我持白璧一雙，欲獻項王，玉斗一雙，欲與亞父，會其怒，不敢獻。公為我獻之」張良曰：「謹諾。」當是時，項王軍在鴻門下，沛公軍在霸上，相去四十里。沛公則置車騎，脫身獨騎，與樊噲、夏侯嬰、靳彊、紀信等四人持劍盾步走，從酈山下，道芷陽閒行。沛公謂張良曰：「從此道至吾軍，不過二十里耳。度我至軍中，公乃入。」沛公已去，閒至軍中，張良入謝，曰：「沛公不勝桮杓，不能辭。謹使臣良奉白璧一雙，再拜獻大王足下；玉斗一雙，再拜奉大將軍足下。」項王曰：「沛公安在？」良曰：「聞大王有意督過之，脫身獨去，已至軍矣。」項王則受璧，置之坐上。亞父受玉斗，置之地，拔劍撞而破之，曰：「唉！豎子不足與謀。奪項王天下者，必沛公也，吾屬今為之虜矣。」沛公至軍，立誅殺曹無傷。>,
    <居數日，項羽引兵西屠咸陽，殺秦降王子嬰，燒秦宮室，火三月不滅；收其貨寶婦女而東。人或說項王曰：「關中阻山河四塞，地肥饒，可都以霸。」項王見秦宮皆以燒殘破，又心懷思欲東歸，曰：「富貴不歸故鄉，如衣繡夜行，誰知之者！」說者曰：「人言楚人沐猴而冠耳，果然。」項王聞之，烹說者。>,
    <項王使人致命懷王。懷王曰：「如約。」乃尊懷王為義帝。項王欲自王，先王諸將相。謂曰：「天下初發難時，假立諸侯後以伐秦。然身被堅執銳首事，暴露於野三年，滅秦定天下者，皆將相諸君與籍之力也。義帝雖無功，故當分其地而王之。」諸將皆曰：「善。」乃分天下，立諸將為侯王。項王、范增疑沛公之有天下，業已講解，又惡負約，恐諸侯叛之，乃陰謀曰：「巴、蜀道險，秦之遷人皆居蜀。」乃曰：「巴、蜀亦關中地也。」故立沛公為漢王，王巴、蜀、漢中，都南鄭。而三分關中，王秦降將以距塞漢王。項王乃立章邯為雍王，王咸陽以西，都廢丘。長史欣者，故為櫟陽獄掾，嘗有德於項梁；都尉董翳者，本勸章邯降楚。故立司馬欣為塞王，王咸陽以東至河，都櫟陽；立董翳為翟王，王上郡，都高奴。徙魏王豹為西魏王，王河東，都平陽。瑕丘申陽者，張耳嬖臣也，先下河南（郡），迎楚河上，故立申陽為河南王，都雒陽。韓王成因故都，都陽翟。趙將司馬卬定河內，數有功，故立卬為殷王，王河內，都朝歌。徙趙王歇為代王。趙相張耳素賢，又從入關，故立耳為常山王，王趙地，都襄國。當陽君黥布為楚將，常冠軍，故立布為九江王，都六。鄱君吳芮率百越佐諸侯，又從入關，故立芮為衡山王，都邾。義帝柱國共敖將兵擊南郡，功多，因立敖為臨江王，都江陵。徙燕王韓廣為遼東王。燕將臧荼從楚救趙，因從入關，故立荼為燕王，都薊。徙齊王田市為膠東王。齊將田都從共救趙，因從入關，故立都為齊王，都臨菑。故秦所滅齊王建孫田安，項羽方渡河救趙，田安下濟北數城，引其兵降項羽，故立安為濟北王，都博陽。田榮者，數負項梁，又不肯將兵從楚擊秦，以故不封。成安君陳餘棄將印去，不從入關，然素聞其賢，有功於趙，聞其在南皮，故因環封三縣。番君將梅鋗功多，故封十萬戶侯。項王自立為西楚霸王，王九郡，都彭城。>,
    <漢之元年四月，諸侯罷戲下，各就國。項王出之國，使人徙義帝，曰：「古之帝者地方千里，必居上游。」乃使使徙義帝長沙郴縣。趣義帝行，其群臣稍稍背叛之，乃陰令衡山、臨江王擊殺之江中。韓王成無軍功，項王不使之國，與俱至彭城，廢以為侯，已又殺之。臧荼之國，因逐韓廣之遼東，廣弗聽，荼擊殺廣無終，并王其地。>,
    <田榮聞項羽徙齊王市膠東，而立齊將田都為齊王，乃大怒，不肯遣齊王之膠東，因以齊反，迎擊田都。田都走楚。齊王市畏項王，乃亡之膠東就國。田榮怒，追擊殺之即墨。榮因自立為齊王，而西殺擊濟北王田安，并王三齊。榮與彭越將軍印，令反梁地。陳餘陰使張同、夏說說齊王田榮曰：「項羽為天下宰，不平。今盡王故王於醜地，而王其群臣諸將善地，逐其故主趙王，乃北居代，餘以為不可。聞大王起兵，且不聽不義，願大王資餘兵，請以擊常山，以復趙王，請以國為捍蔽。」齊王許之，因遣兵之趙。陳餘悉發三縣兵，與齊并力擊常山，大破之。張耳走歸漢。陳餘迎故趙王歇於代，反之趙。趙王因立陳餘為代王。>,
    <是時，漢還定三秦。項羽聞漢王皆已并關中，且東，齊、趙叛之：大怒。乃以故吳令鄭昌為韓王，以距漢。令蕭公角等擊彭越。彭越敗蕭公角等。漢使張良徇韓，乃遺項王書曰：「漢王失職，欲得關中，如約即止，不敢東。」又以齊、梁反書遺項王曰：「齊欲與趙并滅楚。」楚以此故無西意，而北擊齊。徵兵九江王布。布稱疾不往，使將將數千人行。項王由此怨布也。漢之二年冬，項羽遂北至城陽，田榮亦將兵會戰。田榮不勝，走至平原，平原民殺之。遂北燒夷齊城郭室屋，皆阬田榮降卒，系虜其老弱婦女。徇齊至北海，多所殘滅。齊人相聚而叛之。於是田榮弟田橫收齊亡卒得數萬人，反城陽。項王因留，連戰未能下。>,
    <春，漢王部五諸侯兵，凡五十六萬人，東伐楚。項王聞之，即令諸將擊齊，而自以精兵三萬人南從魯出胡陵。四月，漢皆已入彭城，收其貨寶美人，日置酒高會。項王乃西從蕭，晨擊漢軍而東，至彭城，日中，大破漢軍。漢軍皆走，相隨入穀、泗水，殺漢卒十餘萬人。漢卒皆南走山，楚又追擊至靈壁東睢水上。漢軍卻，為楚所擠，多殺，漢卒十餘萬人皆入睢水，睢水為之不流。圍漢王三匝。於是大風從西北而起，折木發屋，揚沙石，窈冥晝晦，逢迎楚軍。楚軍大亂，壞散，而漢王乃得與數十騎遁去，欲過沛，收家室而西；楚亦使人追之沛，取漢王家：家皆亡，不與漢王相見。漢王道逢得孝惠、魯元，乃載行。楚騎追漢王，漢王急，推墮孝惠、魯元車下，滕公常下收載之。如是者三。曰：「雖急不可以驅，柰何棄之？」於是遂得脫。求太公、呂后不相遇。審食其從太公、呂后閒行，求漢王，反遇楚軍。楚軍遂與歸，報項王，項王常置軍中。>,
    <是時呂后兄周呂侯為漢將兵居下邑，漢王閒往從之，稍稍收其士卒。至滎陽，諸敗軍皆會，蕭何亦發關中老弱未傅悉詣滎陽，復大振。楚起於彭城，常乘勝逐北，與漢戰滎陽南京、索閒，漢敗楚，楚以故不能過滎陽而西。>,
    <項王之救彭城，追漢王至滎陽，田橫亦得收齊，立田榮子廣為齊王。漢王之敗彭城，諸侯皆復與楚而背漢。漢軍滎陽，筑甬道屬之河，以取敖倉粟。漢之三年，項王數侵奪漢甬道，漢王食乏，恐，請和，割滎陽以西為漢。>,
    <項王欲聽之。歷陽侯范增曰：「漢易與耳，今釋弗取，後必悔之。」項王乃與范增急圍滎陽。漢王患之，乃用陳平計閒項王。項王使者來，為太牢具，舉欲進之。見使者，詳驚愕曰：「吾以為亞父使者，乃反項王使者。」更持去，以惡食食項王使者。使者歸報項王，項王乃疑范增與漢有私，稍奪之權。范增大怒，曰：「天下事大定矣，君王自為之。願賜骸骨歸卒伍。」項王許之。行未至彭城，疽發背而死。>,
    <漢將紀信說漢王曰：「事已急矣，請為王誑楚為王，王可以閒出。」於是漢王夜出女子滎陽東門被甲二千人，楚兵四面擊之。紀信乘黃屋車，傅左纛，曰：「城中食盡，漢王降。」楚軍皆呼萬歲。漢王亦與數十騎從城西門出，走成皋。項王見紀信，問：「漢王安在？」曰：「漢王已出矣。」項王燒殺紀信。>,
    <漢王使御史大夫周苛、樅公、魏豹守滎陽。周苛、樅公謀曰：「反國之王，難與守城。」乃共殺魏豹。楚下滎陽城，生得周苛。項王謂周苛曰：「為我將，我以公為上將軍，封三萬戶。」周苛罵曰：「若不趣降漢，漢今虜若，若非漢敵也。」項王怒，烹周苛，井殺樅公。>,
    <漢王之出滎陽，南走宛、葉，得九江王布，行收兵，復入保成皋。漢之四年，項王進兵圍成皋。漢王逃，獨與滕公出成皋北門，渡河走修武，從張耳、韓信軍。諸將稍稍得出成皋，從漢王。楚遂拔成皋，欲西。漢使兵距之鞏，令其不得西。>,
    <是時，彭越渡河擊楚東阿，殺楚將軍薛公。項王乃自東擊彭越。漢王得淮陰侯兵，欲渡河南。鄭忠說漢王，乃止壁河內。使劉賈將兵佐彭越，燒楚積聚。項王東擊破之，走彭越。漢王則引兵渡河，復取成皋，軍廣武，就敖倉食。項王已定東海來，西，與漢俱臨廣武而軍，相守數月。>,
    <當此時，彭越數反梁地，絕楚糧食，項王患之。為高俎，置太公其上，告漢王曰：「今不急下，吾烹太公。」漢王曰：「吾與項羽俱北面受命懷王，曰『約為兄弟』，吾翁即若翁，必欲烹而翁，則幸分我一桮羹。」項王怒，欲殺之。項伯曰：「天下事未可知，且為天下者不顧家，雖殺之無益，只益禍耳。」項王從之。>,
    <楚漢久相持未決，丁壯苦軍旅，老弱罷轉漕。項王謂漢王曰：「天下匈匈數歲者，徒以吾兩人耳，願與漢王挑戰決雌雄，毋徒苦天下之民父子為也。」漢王笑謝曰：「吾寧鬬智，不能鬬力。」項王令壯士出挑戰。漢有善騎射者樓煩，楚挑戰三合，樓煩輒射殺之。項王大怒，乃自被甲持戟挑戰。樓煩欲射之，項王瞋目叱之，樓煩目不敢視，手不敢發，遂走還入壁，不敢復出。漢王使人閒問之，乃項王也。漢王大驚。於是項王乃即漢王相與臨廣武閒而語。漢王數之，項王怒，欲一戰。漢王不聽，項王伏弩射中漢王。漢王傷，走入成皋。>,
    <項王聞淮陰侯已舉河北，破齊、趙，且欲擊楚，乃使龍且往擊之。淮陰侯與戰，騎將灌嬰擊之，大破楚軍，殺龍且。韓信因自立為齊王。項王聞龍且軍破，則恐，使盱臺人武涉往說淮陰侯。淮陰侯弗聽。是時，彭越復反，下梁地，絕楚糧。項王乃謂海春侯大司馬曹咎等曰：「謹守成皋，則漢欲挑戰，慎勿與戰，毋令得東而已。我十五日必誅彭越，定梁地，復從將軍。」乃東，行擊陳留、外黃。>,
    <外黃不下。數日，已降，項王怒，悉令男子年十五已上詣城東，欲阬之。外黃令舍人兒年十三，往說項王曰：「彭越彊劫外黃，外黃恐，故且降，待大王。大王至，又皆阬之，百姓豈有歸心？從此以東，梁地十餘城皆恐，莫肯下矣。」項王然其言，乃赦外黃當阬者。東至睢陽，聞之皆爭下項王。>,
    <漢果數挑楚軍戰，楚軍不出。使人辱之，五六日，大司馬怒，渡兵汜水。士卒半渡，漢擊之，大破楚軍，盡得楚國貨賂。大司馬咎、長史翳、塞王欣皆自剄汜水上。大司馬咎者，故蘄獄掾，長史欣亦故櫟陽獄吏，兩人嘗有德於項梁，是以項王信任之。當是時，項王在睢陽，聞海春侯軍敗，則引兵還。漢軍方圍鐘離眛於滎陽東，項王至，漢軍畏楚，盡走險阻。>,
    <是時，漢兵盛食多，項王兵罷食絕。漢遣陸賈說項王，請太公，項王弗聽。漢王復使侯公往說項王，項王乃與漢約，中分天下，割鴻溝以西者為漢，鴻溝而東者為楚。項王許之，即歸漢王父母妻子。軍皆呼萬歲。漢王乃封侯公為平國君。匿弗肯復見。曰：「此天下辯士，所居傾國，故號為平國君。」項王已約，乃引兵解而東歸。>,
    <漢欲西歸，張良、陳平說曰：「漢有天下太半，而諸侯皆附之。楚兵罷食盡，此天亡楚之時也，不如因其機而遂取之。今釋弗擊，此所謂『養虎自遺患』也。」漢王聽之。漢五年，漢王乃追項王至陽夏南，止軍，與淮陰侯韓信、建成侯彭越期會而擊楚軍。至固陵，而信、越之兵不會。楚擊漢軍，大破之。漢王復入壁，深塹而自守。謂張子房曰：「諸侯不從約，為之柰何？」對曰：「楚兵且破，信、越未有分地，其不至固宜。君王能與共分天下，今可立致也。即不能，事未可知也。君王能自陳以東傅海，盡與韓信；睢陽以北至穀城，以與彭越：使各自為戰，則楚易敗也。」漢王曰：「善。」於是乃發使者告韓信、彭越曰：「并力擊楚。楚破，自陳以東傅海與齊王，睢陽以北至穀城與彭相國。」使者至，韓信、彭越皆報曰：「請今進兵。」韓信乃從齊往，劉賈軍從壽春并行，屠城父，至垓下。大司馬周殷叛楚，以舒屠六，舉九江兵，隨劉賈、彭越皆會垓下，詣項王。>,
    <項王軍壁垓下，兵少食盡，漢軍及諸侯兵圍之數重。夜聞漢軍四面皆楚歌，項王乃大驚曰：「漢皆已得楚乎？是何楚人之多也！」項王則夜起，飲帳中。有美人名虞，常幸從；駿馬名騅，常騎之。於是項王乃悲歌慨，自為詩曰：「力拔山兮氣蓋世，時不利兮騅不逝。騅不逝兮可柰何，虞兮虞兮柰若何！」歌數闋，美人和之。項王泣數行下，左右皆泣，莫能仰視。>,
    <於是項王乃上馬騎，麾下壯士騎從者八百餘人，直夜潰圍南出，馳走。平明，漢軍乃覺之，令騎將灌嬰以五千騎追之。項王渡淮，騎能屬者百餘人耳。項王至陰陵，迷失道，問一田父，田父紿曰「左」。左，乃陷大澤中。以故漢追及之。項王乃復引兵而東，至東城，乃有二十八騎。漢騎追者數千人。項王自度不得脫。謂其騎曰：「吾起兵至今八歲矣，身七十餘戰，所當者破，所擊者服，未嘗敗北，遂霸有天下。然今卒困於此，此天之亡我，非戰之罪也。今日固決死，願為諸君快戰，必三勝之，為諸君潰圍，斬將，刈旗，令諸君知天亡我，非戰之罪也。」乃分其騎以為四隊，四向。漢軍圍之數重。項王謂其騎曰：「吾為公取彼一將。」令四面騎馳下，期山東為三處。於是項王大呼馳下，漢軍皆披靡，遂斬漢一將。是時，赤泉侯為騎將，追項王，項王瞋目而叱之，赤泉侯人馬俱驚，辟易數里與其騎會為三處。漢軍不知項王所在，乃分軍為三，復圍之。項王乃馳，復斬漢一都尉，殺數十百人，復聚其騎，亡其兩騎耳。乃謂其騎曰：「何如？」騎皆伏曰：「如大王言。」>,
    <於是項王乃欲東渡烏江。烏江亭長檥船待，謂項王曰：「江東雖小，地方千里，眾數十萬人，亦足王也。願大王急渡。今獨臣有船，漢軍至，無以渡。」項王笑曰：「天之亡我，我何渡為！且籍與江東子弟八千人渡江而西，今無一人還，縱江東父兄憐而王我，我何面目見之？縱彼不言，籍獨不愧於心乎？」乃謂亭長曰：「吾知公長者。吾騎此馬五歲，所當無敵，嘗一日行千里，不忍殺之，以賜公。」乃令騎皆下馬步行，持短兵接戰。獨籍所殺漢軍數百人。項王身亦被十餘創。顧見漢騎司馬呂馬童，曰：「若非吾故人乎？」馬童面之，指王翳曰：「此項王也。」項王乃曰：「吾聞漢購我頭千金，邑萬戶，吾為若德。」乃自刎而死。王翳取其頭，餘騎相蹂踐爭項王，相殺者數十人。最其後，郎中騎楊喜，騎司馬呂馬童，郎中呂勝、楊武各得其一體。五人共會其體，皆是。故分其地為五：封呂馬童為中水侯，封王翳為杜衍侯，封楊喜為赤泉侯，封楊武為吳防侯，封呂勝為涅陽侯。>,
    <項王已死，楚地皆降漢，獨魯不下。漢乃引天下兵欲屠之，為其守禮義，為主死節，乃持項王頭視魯，魯父兄乃降。始，楚懷王初封項籍為魯公，及其死，魯最後下，故以魯公禮葬項王穀城。漢王為發哀，泣之而去。>,
    <諸項氏枝屬，漢王皆不誅。乃封項伯為射陽侯。桃侯、平皋侯、玄武侯皆項氏，賜姓劉。>,
    <太史公曰：吾聞之周生曰「舜目蓋重瞳子」，又聞項羽亦重瞳子。羽豈其苗裔邪？何興之暴也！夫秦失其政，陳涉首難，豪傑蜂起，相與并爭，不可勝數。然羽非有尺寸，乘執起隴畝之中，三年，遂將五諸侯滅秦，分裂天下，而封王侯，政由羽出，號為「霸王」，位雖不終，近古以來未嘗有也。及羽背關懷楚，放逐義帝而自立，怨王侯叛己，難矣。自矜功伐，奮其私智而不師古，謂霸王之業，欲以力征經營天下，五年卒亡其國，身死東城，尚不覺寤而不自責，過矣。乃引「天亡我，非用兵之罪也」，豈不謬哉！>
  >
+newzhlipsum < zhufu >
  <
    <旧历的年底毕竟最像年底，村镇上不必说，就在天空中也显出将到新年的气象来。灰白色的沉重的晚云中间时时发出闪光，接着一声钝响，是送灶的爆竹；近处燃放的可就更强烈了，震耳的大音还没有息，空气里已经散满了幽微的火药香。我是正在这一夜回到我的故乡鲁镇的。虽说故乡，然而已没有家，所以只得暂寓在鲁四老爷的宅子里。他是我的本家，比我长一辈，应该称之曰“四叔”，是一个讲理学的老监生。他比先前并没有甚么大改变，单是老了些，但也还未留胡子，一见面是寒暄，寒暄之后说我“胖了”，说我“胖了”之后即大骂其新党。但我知道，这并非借题在骂我：因为他所骂的还是康有为。但是，谈话是总不投机的了，于是不多久，我便一个人剩在书房里。>,
    <第二天我起得很迟，午饭之后，出去看了几个本家和朋友；第三天也照样。他们也都没有甚么大改变，单是老了些；家中却一律忙，都在准备着“祝福”。这是鲁镇年终的大典，致敬尽礼，迎接福神，拜求来年一年中的好运气的。杀鸡，宰鹅，买猪肉，用心细细的洗，女人的臂膊都在水里浸得通红，有的还带着绞丝银镯子。煮熟之后，横七竖八的插些筷子在这类东西上，可就称为“福礼”了，五更天陈列起来，并且点上香烛，恭请福神们来享用，拜的却只限于男人，拜完自然仍然是放爆竹。年年如此，家家如此，——只要买得起福礼和爆竹之类的——今年自然也如此。天色愈阴暗了，下午竟下起雪来，雪花大的有梅花那么大，满天飞舞，夹着烟霭和忙碌的气色，将鲁镇乱成一团糟。我回到四叔的书房里时，瓦楞上已经雪白，房里也映得较光明，极分明的显出壁上挂著的朱拓的大“寿”字，陈抟老祖写的，一边的对联已经脱落，松松的卷了放在长桌上，一边的还在，道是“事理通达心气和平”。我又无聊赖的到窗下的案头去一翻，只见一堆似乎未必完全的《康熙字典》，一部《近思录集注》和一部《四书衬》。无论如何、我明天决计要走了。>,
    <况且，一直到昨天遇见祥林嫂的事，也就使我不能安住。那是下午，我到镇的东头访过一个朋友，走出来，就在河边遇见她；而且见她瞪着的眼睛的视线，就知道明明是向我走来的。我这回在鲁镇所见的人们中，改变之大，可以说无过于她的了：五年前的花白的头发，即今已经全白，会不像四十上下的人；脸上瘦削不堪，黄中带黑，而且消尽了先前悲哀的神色，仿佛是木刻似的；只有那眼珠间或一轮，还可以表示她是一个活物。她一手提着竹篮。内中一个破碗，空的；一手拄著一支比她更长的竹竿，下端开了裂：她分明已经纯乎是一个乞丐了。我就站住，豫备她来讨钱。>,
    <“你回来了？”她先这样问。>,
    <“是的。”>,
    <“这正好。你是识字的，又是出门人，见识得多。我正要问你一件事——”她那没有精采的眼睛忽然发光了。>,
    <我万料不到她却说出这样的话来，诧异的站着。>,
    <“就是——”她走近两步，放低了声音，极秘密似的切切的说，“一个人死了之后，究竟有没有魂灵的？”>,
    <我很悚然，一见她的眼钉着我的，背上也就遭了芒刺一般，比在学校里遇到不及豫防的临时考，教师又偏是站在身旁的时候，惶急得多了。对于魂灵的有无，我自己是向来毫不介意的；但在此刻，怎样回答她好呢？我在极短期的踌躇中，想，这里的人照例相信鬼，然而她，却疑惑了，——或者不如说希望：希望其有，又希望其无……，人何必增添末路的人的苦恼，一为她起见，不如说有罢。>,
    <“也许有罢，——我想。”我于是吞吞吐吐的说。>,
    <“那么，也就有地狱了？”>,
    <“啊！地狱？”我很吃惊，只得支吾著，“地狱？——论理，就该也有。——然而也未必，……谁来管这等事……。”>,
    <“那么，死掉的一家的人，都能见面的？”>,
    <“唉唉，见面不见面呢？……”这时我已知道自己也还是完全一个愚人，甚么踌躇，甚么计划，都挡不住三句问，我即刻胆怯起来了，便想全翻过先前的话来，“那是，……实在，我说不清……。其实，究竟有没有魂灵，我也说不清。”>,
    <我乘她不再紧接的问，迈开步便走，勿勿的逃回四叔的家中，心里很觉得不安逸。自己想，我这答话怕于她有些危险。她大约因为在别人的祝福时候，感到自身的寂寞了，然而会不会含有别的甚么意思的呢？——或者是有了甚么豫感了？倘有别的意思，又因此发生别的事，则我的答话委实该负若干的责任……。但随后也就自笑，觉得偶尔的事，本没有甚么深意义，而我偏要细细推敲，正无怪教育家要说是生著神经病；而况明明说过“说不清”，已经推翻了答话的全局，即使发生甚么事，于我也毫无关系了。>,
    <“说不清”是一句极有用的话。不更事的勇敢的少年，往往敢于给人解决疑问，选定医生，万一结果不佳，大抵反成了怨府，然而一用这说不清来作结束，便事事逍遥自在了。我在这时，更感到这一句话的必要，即使和讨饭的女人说话，也是万不可省的。>,
    <但是我总觉得不安，过了一夜，也仍然时时记忆起来，仿佛怀着甚么不祥的豫感，在阴沉的雪天里，在无聊的书房里，这不安愈加强烈了。不如走罢，明天进城去。福兴楼的清炖鱼翅，一元一大盘，价廉物美，现在不知增价了否？往日同游的朋友，虽然已经云散，然而鱼翅是不可不吃的，即使只有我一个……。无论如何，我明天决计要走了。>,
    <我因为常见些但愿不如所料，以为未毕竟如所料的事，却每每恰如所料的起来，所以很恐怕这事也一律。果然，特别的情形开始了。傍晚，我竟听到有些人聚在内室里谈话，仿佛议论甚么事似的，但不一会，说话声也就止了，只有四叔且走而且高声的说：>,
    <“不早不迟，偏偏要在这时候——这就可见是一个谬种！”>,
    <我先是诧异，接着是很不安，似乎这话于我有关系。试望门外，谁也没有。好容易待到晚饭前他们的短工来冲茶，我才得了打听消息的机会。>,
    <“刚才，四老爷和谁生气呢？”我问。>,
    <“还不是和祥林嫂？”那短工简捷的说。>,
    <“祥林嫂？怎么了？”我又赶紧的问。>,
    <“老了。”>,
    <“死了？”我的心突然紧缩，几乎跳起来，脸上大约也变了色，但他始终没有抬头，所以全不觉。我也就镇定了自己，接着问：>,
    <“甚么时候死的？”>,
    <“甚么时候？——昨天夜里，或者就是今天罢。——我说不清。”>,
    <“怎么死的？”>,
    <“怎么死的？——还不是穷死的？”他淡然的回答，仍然没有抬头向我看，出去了。>,
    <然而我的惊惶却不过暂时的事，随着就觉得要来的事，已经过去，并不必仰仗我自己的“说不清”和他之所谓“穷死的”的宽慰，心地已经渐渐轻松；不过偶然之间，还似乎有些负疚。晚饭摆出来了，四叔俨然的陪着。我也还想打听些关于祥林嫂的消息，但知道他虽然读过“鬼神者，二气之良能也”，而忌讳仍然极多，当临近祝福时候，是万不可提起死亡、疾病之类的话的，倘不得已，就该用一种替代的隐语，可惜我又不知道，因此屡次想问，而终于中止了。我从他俨然的脸色上，又忽而疑他正以为我不早不迟，偏要在这时候来打搅他，也是一个谬种，便立刻告诉他明天要离开鲁镇，进城去，趁早放宽了他的心。他也不很留。这样闷闷的吃完了一餐饭。>,
    <冬季日短，又是雪天，夜色早已笼罩了全市镇。人们都在灯下匆忙，但窗外很寂静。雪花落在积得厚厚的雪褥上面，听去似乎瑟瑟有声，使人更加感得沉寂。我独坐在发出黄光的菜油灯下，想，这百无聊赖的祥林嫂，被人们弃在尘芥堆中的，看得厌倦了的陈旧的玩物，先前还将形骸露在尘芥里，从活得有趣的人们看来，恐怕要怪讶她何以还要存在，现在总算被无常打扫得干净净了。魂灵的有无，我不知道；然而在现世，则无聊生者不生，即使厌见者不见，为人为己，也还都不错。我静听着窗外似乎瑟瑟作响的雪花声，一面想，反而渐渐的舒畅起来。>,
    <然而先前所见所闻的她的半生事迹的断片，至此也联成一片了。>,
    <她不是鲁镇人。有一年的冬初，四叔家里要换女工，做中人的卫老婆子带她进来了，头上扎著白头绳，乌裙，蓝夹袄，月白背心，年纪大约二十六七，脸色青黄，但两颊却还是红的。卫老婆子叫她祥林嫂，说是自己母家的邻舍，死了当家人，所以出来做工了。四叔皱了皱眉，四婶已经知道了他的意思，是在讨厌她是一个寡妇。但是她模样还周正，手脚都壮大，又只是顺着限，不开一句口，很像一个安分耐劳的人，便不管四叔的皱眉，将她留下了。试工期内，她整天的做，似乎闲著就无聊，又有力，简直抵得过一个男子，所以第三天就定局，每月工钱五百文。>,
    <大家都叫她祥林嫂；没问她姓甚么，但中人是卫家山人，既说是邻居，那大概也就姓卫了。她不很爱说话，别人问了才回答，答的也不多。直到十几天之后，这才陆续的知道她家里还有严厉的婆婆，一个小叔子，十多岁，能打柴了；她是春天没了丈夫的；他本来也打柴为生，比她小十岁：大家所知道的就只是这一点。>,
    <日子很快的过去了，她的做工却毫没有懈，食物不论，力气是不惜的。人们都说鲁四老爷家里雇著了女工，实在比勤快的男人还勤快。到年底，扫尘，洗地，杀鸡，宰鹅，彻夜的煮福礼，全是一人担当，竟没有添短工。然而她反满足，口角边渐渐的有了笑影，脸上也白胖了。>,
    <新年才过，她从河边掏米回来时，忽而失了色，说刚才远远地看见几个男人在对岸徘徊，很像夫家的堂伯，恐怕是正在寻她而来的。四婶很惊疑，打听底细，她又不说。四叔一知道，就皱一皱眉，道：>,
    <“这不好。恐怕她是逃出来的。”>,
    <她诚然是逃出来的，不多久，这推想就证实了。>,
    <此后大约十几天，大家正已渐渐忘却了先前的事，卫老婆子忽而带了一个三十多岁的女人进来了，说那是祥林嫂的婆婆。那女人虽是山里人模样，然而应酬很从容，说话也能干，寒暄之后，就赔罪，说她特来叫她的儿媳回家去，因为开春事务忙，而家中只有老的和小的，人手不够了。>,
    <“既是她的婆婆要她回去，那有甚么话可说的呢？”四叔说。于是算清了工钱，一共一千七百五十文，她全存在主人家，一文也还没有用，便都交给她的婆婆。那女人又取了衣服，道过谢，出去了。其时已经是正午。>,
    <“阿呀，米呢？祥林嫂不是去淘米的么？……”好一会，四婶这才惊叫起来。她大约有些饿，记得午饭了。>,
    <于是大家分头寻淘箩。她先到厨下，次到堂前，后到卧房，全不见掏箩的影子。四叔踱出门外，也不见，一直到河边，才见平平正正的放在岸上，旁边还有一株菜。>,
    <看见的人报告说，河里面上午就泊了一只白篷船，篷是全盖起来的，不知道甚么人在里面，但事前也没有人去理会他。待到祥林嫂出来掏米，刚刚要跪下去，那船里便突然跳出两个男人来，像是山里人，一个抱住她，一个帮着，拖进船去了。祥林嫂还哭喊了几声，此后便再没有甚么声息，大约给用甚么堵住了罢。接着就走上两个女人来，一个不认识，一个就是卫婆于。窥探舱里，不很分明，她像是捆了躺在船板上。>,
    <“可恶！然而……。”四叔说。>,
    <这一天是四婶自己煮中饭；他们的儿子阿牛烧火。>,
    <午饭之后，卫老婆子又来了。>,
    <“可恶！”四叔说。>,
    <“你是甚么意思？亏你还会再来见我们。”四婶洗著碗，一见面就愤愤的说，“你自己荐她来，又合伙劫她去，闹得沸反盈天的，大家看了成个甚么样子？你拿我们家里开玩笑么？”>,
    <“阿呀阿呀，我真上当。我这回，就是为此特地来说说清楚的。她来求我荐地方，我那里料得到是瞒着她的婆婆的呢。对不起，四老爷，四太太。总是我老发昏不小心，对不起主顾。幸而府上是向来宽洪大量，不肯和小人计较的。这回我一定荐一个好的来折罪……。”>,
    <“然而……。”四叔说。>,
    <于是祥林嫂事件便告终结，不久也就忘却了。>,
    <只有四嫂，因为后来雇用的女工，大抵非懒即馋，或者馋而且懒，左右不如意，所以也还提起祥林嫂。每当这些时候，她往往自言自语的说，“她现在不知道怎么样了？”意思是希望她再来。但到第二年的新正，她也就绝了望。>,
    <新正将尽，卫老婆子来拜年了，已经喝得醉醺醺的，自说因为回了一趟卫家山的娘家，住下几天，所以来得迟了。她们问答之间，自然就谈到祥林嫂。>,
    <“她么？”卫若婆子高兴的说，“现在是交了好运了。她婆婆来抓她回去的时候，是早已许给了贺家坳的贺老六的，所以回家之后不几天，也就装在花轿里抬去了。”>,
    <“阿呀，这样的婆婆！……”四婶惊奇的说。>,
    <“阿呀，我的太太！你真是大户人家的太太的话。我们山里人，小户人家，这算得甚么？她有小叔子，也得娶老婆。不嫁了她，那有这一注钱来做聘礼？他的婆婆倒是精明强干的女人呵，很有打算，所以就将地嫁到里山去。倘许给本村人，财礼就不多；惟独肯嫁进深山野坳里去的女人少，所以她就到手了八十千。现在第二个儿子的媳妇也娶进了，财礼花了五十，除去办喜事的费用，还剩十多千。吓，你看，这多么好打算？……”>,
    <“祥林嫂竟肯依？……”>,
    <“这有甚么依不依。——闹是谁也总要闹一闹的，只要用绳子一捆，塞在花轿里，抬到男家，捺上花冠，拜堂，关上房门，就完事了。可是祥林嫂真出格，听说那时实在闹得利害，大家还都说大约因为在念书人家做过事，所以与众不同呢。太太，我们见得多了：回头人出嫁，哭喊的也有，说要寻死觅活的也有，抬到男家闹得拜不成天地的也有，连花烛都砸了的也有。样林嫂可是异乎寻常，他们说她一路只是嚎，骂，抬到贺家坳，喉咙已经全哑了。拉出轿来，两个男人和她的小叔子使劲的捺住她也还拜不成夭地。他们一不小心，一松手，阿呀阿弥陀佛，她就一头撞在香案角上，头上碰了一个大窟窿，鲜血直流，用了两把香灰，包上两块红布还止不住血呢。直到七手八脚的将她和男人反关在新房里，还是骂，阿呀呀，这真是……。”她摇一摇头，顺下眼睛，不说了。>,
    <“后来怎么样呢？”四婢还问。>,
    <“听说第二天也没有起来。”她抬起眼来说。>,
    <“后来呢？”>,
    <“后来？——起来了。她到年底就生了一个孩子，男的，新年就两岁了。我在娘家这几天，就有人到贺家坳去，回来说看见他们娘儿俩，母亲也胖，儿子也胖；上头又没有婆婆，男人所有的是力气，会做活；房子是自家的。——唉唉，她真是交了好运了。”>,
    <从此之后，四婶也就不再提起祥林嫂。>,
    <但有一年的秋季，大约是得到祥林嫂好运的消息之后的又过了两个新年，她竟又站在四叔家的堂前了。桌上放著一个荸荠式的圆篮，檐下一个小铺盖。她仍然头上扎著白头绳，乌裙，蓝夹袄，月白背心，脸色青黄，只是两颊上已经消失了血色，顺着眼，眼角上带些泪痕，眼光也没有先前那样精神了。而且仍然是卫老婆子领着，显出慈悲模样，絮絮的对四婶说：>,
    <“……这实在是叫作‘天有不测风云’，她的男人是坚实人，谁知道年纪轻轻，就会断送在伤寒上？本来已经好了的，吃了一碗冷饭，复发了。幸亏有儿子；她又能做，打柴摘茶养蚕都来得，本来还可以守着，谁知道那孩子又会给狼衔去的呢？春天快完了，村上倒反来了狼，谁料到？现在她只剩了一个光身了。大伯来收屋，又赶她。她真是走投无路了，只好来求老主人。好在她现在已经再没有甚么牵挂，太太家里又凄巧要换人，所以我就领她来——我想，熟门熟路，比生手实在好得多……”>,
    <“我真傻，真的，”祥林嫂抬起她没有神采的眼睛来，接着说。“我单知道下雪的时候野兽在山坳里没有食吃，会到村里来；我不知道春天也会有。我一清早起来就开了门，拿小篮盛了一篮豆，叫我们的阿毛坐在门槛上剥豆去。他是很听话的，我的话句句听；他出去了。我就在屋后劈柴，掏米，米下了锅，要蒸豆。我叫阿毛，没有应，出去口看，只见豆撒得一地，没有我们的阿毛了。他是不到别家去玩的；各处去一问，果然没有。我急了，央人出去寻。直到下半天，寻来寻去寻到山坳里，看见刺柴上桂著一只他的小鞋。大家都说，糟了，怕是遭了狼了。再进去；他果然躺在草窠里，肚里的五脏已经都给吃空了，手上还紧紧的捏著那只小篮呢。……”她接着但是呜咽，说不出成句的话来。>,
    <四婶起刻还踌踌，待到听完她自己的话，眼圈就有些红了。她想了一想，便教拿圆篮和铺盖到下房去。卫老婆子仿佛卸了一肩重相似的嘘一口气，祥林嫂比初来时候神气舒畅些，不待指引，自己驯熟的安放了铺盖。她从此又在鲁镇做女工了。>,
    <大家仍然叫她祥林嫂。>,
    <然而这一回，她的境遇却改变得非常大。上工之后的两三天，主人们就觉得她手脚已没有先前一样灵活，记性也坏得多，死尸似的脸上又整日没有笑影，四婶的口气上，已颇有些不满了。当她初到的时候，四叔虽然照例皱过眉，但鉴于向来雇用女工之难，也就并不大反对，只是暗暗地告诫四姑说，这种人虽然似乎很可怜，但是败坏风俗的，用她帮忙还可以，祭祀时候可用不着她沾手，一切饭菜，只好自已做，否则，不干不净，祖宗是不吃的。>,
    <四叔家里最重大的事件是祭祀，祥林嫂先前最忙的时候也就是祭祀，这回她却清闲了。桌子放在堂中央，系上桌帏，她还记得照旧的去分配酒杯和筷子。>,
    <“祥林嫂，你放著罢！我来摆。”四婶慌忙的说。>,
    <她讪讪的缩了手，又去取烛台。>,
    <“祥林嫂，你放著罢！我来拿。”四婶又慌忙的说。>,
    <她转了几个圆圈，终于没有事情做，只得疑惑的走开。她在这一天可做的事是不过坐在灶下烧火。>,
    <镇上的人们也仍然叫她祥林嫂，但音调和先前很不同；也还和她讲话，但笑容却冷冷的了。她全不理会那些事，只是直着眼睛，和大家讲她自己日夜不忘的故事：>,
    <“我真傻，真的，”她说，“我单知道雪天是野兽在深山里没有食吃，会到村里来；我不知道春天也会有。我一大早起来就开了门，拿小篮盛了一篮豆，叫我们的阿毛坐在门槛上剥豆去。他是很听话的孩子，我的话句句听；他就出去了。我就在屋后劈柴，淘米，米下了锅，打算蒸豆。我叫‘阿毛！’，没有应。出去一看，只见豆撒得满地，没有我们的阿毛了。各处去一向，都没有。我急了，央人去寻去。直到下半天，几个人寻到山坳里，看见刺柴上挂著一只他的小鞋。大家都说，完了，怕是遭了狼了；再进去；果然，他躺在草窠里，肚里的五脏已经都给吃空了，可怜他手里还紧紧的捏著那只小篮呢。……”她于是淌下眼泪来，声音也呜咽了。>,
    <这故事倒颇有效，男人听到这里，往往敛起笑容，没趣的走了开去；女人们却不独宽恕了她似的，脸上立刻改换了鄙薄的神气，还要陪出许多眼泪来。有些老女人没有在街头听到她的话，便特意寻来，要听她这一段悲惨的故事。直到她说到呜咽，她们也就一齐流下那停在眼角上的眼泪，叹息一番，满足的去了，一面还纷纷的评论著。>,
    <她就只是反复的向人说她悲惨的故事，常常引住了三五个人来听她。但不久，大家也都听得纯熟了，便是最慈悲的念佛的老太太们，眼里也再不见有一点泪的痕迹。后来全镇的人们几乎都能背诵她的话，一听到就烦厌得头痛。>,
    <“我真傻，真的，”她开首说。>,
    <“是的，你是单知道雪天野兽在深山里没有食吃，才会到村里来的。”他们立即打断她的话，走开去了。>,
    <她张著口怔怔的站着，直着眼睛看他们，接着也就走了，似乎自己也觉得没趣。但她还妄想，希图从别的事，如小篮，豆，别人的孩子上，引出她的阿毛的故事来。倘一看见两三岁的小孩子，她就说：>,
    <“唉唉，我们的阿毛如果还在，也就有这么大了……”>,
    <孩子看见她的眼光就吃惊，牵着母亲的衣襟催她走。于是又只剩下她一个，终于没趣的也走了，后来大家又都知道了她的脾气，只要有孩子在眼前，便似笑非笑的先问她，道：>,
    <“祥林嫂，你们的阿毛如果还在，不是也就有这么大了么？”>,
    <她未必知道她的悲哀经大家咀嚼赏鉴了许多天，早已成为渣滓，只值得烦厌和唾弃；但从人们的笑影上，也仿佛觉得这又冷又尖，自己再没有开口的必要了。她单是一瞥他们，并不回答一句话。>,
    <鲁镇永远是过新年，腊月二十以后就火起来了。四叔家里这回须雇男短工，还是忙不过来，另叫柳妈做帮手，杀鸡，宰鹅；然而柳妈是‘善女人’，吃素、不杀生的，只肯洗器皿。祥林嫂除烧火之外，没有别的事，却闲著了，坐着只看柳妈洗器皿。微雪点点的下来了。>,
    <“唉唉，我真傻，”祥林嫂看了天空，叹息著，独语似的说。>,
    <“祥林嫂，你又来了。”柳妈不耐烦的看着她的脸，说。“我问你：你额角上的伤痕，不就是那时撞坏的么？”>,
    <“晤晤。”她含糊的回答。>,
    <“我问你：你那时怎么后来竟依了呢？”>,
    <“我么？……”，>,
    <“你呀。我想：这总是你自己愿意了，不然……。”>,
    <“阿阿，你不知道他力气多么大呀。”>,
    <“我不信。我不信你这么大的力气，真会拗他不过。你后来一定是自己肯了，倒推说他力气大。”>,
    <“啊啊，你……你倒自己试试着。”她笑了。>,
    <柳妈的打皱的脸也笑起来，使她蹙缩得像一个核桃，干枯的小眼睛一看祥林嫂的额角，又钉住她的眼。祥林嫂似很局促了，立刻敛了笑容，旋转眼光，自去看雪花。>,
    <“祥林嫂，你实在不合算。”柳妈诡秘的说。“再一强，或者索性撞一个死，就好了。现在呢，你和你的第二个男人过活不到两年，倒落了一件大罪名。你想，你将来到阴司去，那两个死鬼的男人还要争，你给了谁好呢？阎罗大王只好把你锯开来，分给他们。我想，这真是……”>,
    <她脸上就显出恐怖的神色来，这是在山村里所未曾知道的。>,
    <“我想，你不如及早抵当。你到土地庙里去捐一条门槛，当作你的替身，给千人踏，万人跨，赎了这一世的罪名，免得死了去受苦。”>,
    <她当时并不回答甚么话，但大约非常苦闷了，第二天早上起来的时候，两眼上便都围着大黑圈。早饭之后，她便到镇的西头的土地庙里去求捐门槛，庙祝起初执意不允许，直到她急得流泪，才勉强答应了。价目是大钱十二千。她久已不和人们交口，因为阿毛的故事是早被大家厌弃了的；但自从和柳妈谈了天，似乎又即传扬开去，许多人都发生了新趣味，又来逗她说话了。至于题目，那自然是换了一个新样，专在她额上的伤疤。>,
    <“祥林嫂，我问你：你那时怎么竟肯了？”一个说。>,
    <“唉，可惜，白撞了这－下。”一个看着她的疤，应和道。>,
    <她大约从他们的笑容和声调上，也知道是在嘲笑她，所以总是瞪着眼睛，不说一句话，后来连头也不回了。她整日紧闭了嘴唇，头上带着大家以为耻辱的记号的那伤痕，默默的跑街，扫地，洗菜，淘米。快够一年，她才从四婶手里支取了历来积存的工钱，换算了十二元鹰洋，请假到镇的西头去。但不到一顿饭时候，她便回来，神气很舒畅，眼光也分外有神，高兴似的对四婶说，自己已经在土地庙捐了门槛了。>,
    <冬至的祭祖时节，她做得更出力，看四婶装好祭品，和阿牛将桌子抬到堂屋中央，她便坦然去拿酒杯和筷子。>,
    <“你放著罢，祥林嫂！”四婶慌忙大声说。>,
    <她像是受了炮烙似的缩手，脸色同时变作灰黑，也不再去取烛台，只是失神的站着。直到四叔上香的时候，教她走开，她才走开。这一回她的变化非常大，第二天，不但眼睛窈陷下去，连精神也更不济了。而且很胆怯，不独怕暗夜，怕黑影，即使看见人，虽是自己的主人，也总惴惴的，有如在白天出穴游行的小鼠，否则呆坐着，直是一个木偶人。不半年，头发也花白起来了，记性尤其坏，甚而至于常常忘却了去淘米。>,
    <“祥林嫂怎么这样了？倒不如那时不留她。”四婶有时当面就这样说，似乎是警告她。>,
    <然而她总如此，全不见有伶俐起来的希望。他们于是想打发她走了，教她回到卫老婆于那里去。但当我还在鲁镇的时候，不过单是这样说；看现在的情状，可见后来终于实行了。然而她是从四叔家出去就成了乞丐的呢，还是先到卫老婆子家然后再成乞丐的呢？那我可不知道。>,
    <我给那些因为在近旁而极响的爆竹声惊醒，看见豆一般大的黄色的灯火光，接着又听得毕毕剥剥的鞭炮，是四叔家正在“祝福”了；知道已是五更将近时候。我在蒙胧中，又隐约听到远处的爆竹声联绵不断，似乎合成一天音响的浓云，夹着团团飞舞的雪花，拥抱了全市镇。我在这繁响的拥抱中，也懒散而且舒适，从白天以至初夜的疑虑，全给祝福的空气一扫而空了，只觉得天地圣众歆享了牲醴和香烟，都醉醺醺的在空中蹒跚，豫备给鲁镇的人们以无限的幸福。>,
    <一九二四年二月七日>
  >
+newzhlipsum < aspirin >
  <
    <阿司匹林（英语：Aspirin），也称乙酰水杨酸（英语：acetylsalicylic*acid），是水杨酸类药物，通常用作止痛剂、解热药和消炎药，亦能用于治疗某些特定的发炎性疾病，例如川崎氏病、心包炎，以及风湿热等等。心肌梗塞后马上给药能降低死亡的风险。本品也能防止血小板在血管破损处凝集，有抗凝作用。高心血管风险患者长期低剂量服用可预防心脏病、中风与血栓。该药还可有效预防特定几种癌症，特别是直肠癌。对于止痛及发烧而言，药效一般会于30分钟内发挥。阿司匹林是一种非甾体抗炎药（NSAID），在抗发炎的角色上与其他NSAID类似，但阿司匹林还具有抗血小板凝集的效果。>,
    <阿司匹林的其中一个常见的副作用是会引起胃部不适。更严重的副作用则包含胃溃疡、胃出血等等，也可能会使气喘恶化。其中年长者、酗酒者，以及还有服用其他非甾体抗炎药或抗凝剂者，出血风险更高，妊娠后期也不建议用药。有感染的孩童不建议用药，因为这会增加患瑞氏综合征的风险。高剂量者可能会引起耳鸣。>,
    <虽然它们都有名为水杨酸的类似结构，作用相似（解热、消炎、镇痛），抑制的环氧化酶（COX）也相同，但阿司匹林的不同之处在于其抑制作用不可逆，而且对环氧化酶-1（COX-1）的抑制作用比对环氧化酶-2的（COX-2）更强。>,
    <阿司匹林衍生自柳树皮中发现的化学物质。早在2400年前柳树皮就用来治病，希波克拉底就用它来治头痛。1763年，在牛津大学的沃德姆学院，爱德华·斯通首次从柳树皮中发现了阿司匹林的有效成分水杨酸。1853年，化学家查尔斯·弗雷德里克·格哈特将水杨酸钠以乙酰氯处理，首次合成出乙酰水杨酸。此后五十年，化学家们逐步提升生产的效率。1897年，德国拜耳开始研究乙酰水杨酸的医疗用途，以代替高刺激性的水杨酸类药物。到1899年，拜耳以阿司匹林（Aspirin）为商标，将本品销售至全球。此后五十年，阿司匹林跃升成为使用最广泛的药物之一。目前，拜耳公司在很多国家对于“阿司匹林”一名的专利权已经过期，或是已经卖给其他公司。>,
    <本品是当今世界上应用最广泛的药物之一，每年的消费量约40,000公吨（约500至1200亿锭）。本品列名于世界卫生组织基本药物标准清单之中，为基础公卫体系必备药物之一。截至2014年，每剂在发展中国家的批发价约介于0.002至0.025美元之间。截至2015年，每月剂量在美国的价格低于25.00美金。本品目前属于通用名药物。>,
    <阿司匹林可以治疗多种疾病，包括发烧、疼痛、风湿热，也可治疗一些炎症，如类风湿性关节炎、心包炎和川崎病。低剂量服用还可减少心肌梗死发作的死亡风险，某些情况下也可减少发生中风的风险。部分证据表明阿司匹林可以预防直肠癌，但是其原理尚不明晰。在美国，50岁至70岁的人且心血管疾病风险大于10+%的族群可给予低剂量阿司匹林，且不会增加出血风险。>,
    <对急性疼痛而言，阿司匹林是一种高效的镇痛药，但是通常认为其对疼痛的缓解效果不如布洛芬，因为阿司匹林更容易引发胃肠道出血。一般情况下，阿司匹林对肌肉抽搐、腹胀、胃扩张和急性皮肤刺激引起的疼痛无明显效果。像其他非甾体抗炎药一样，阿司匹林与咖啡因一起使用的止痛效果比单独使用阿司匹林要好。阿司匹林泡腾片，如白加黑或拜阿司匹林，比药片起效更快，可以有效治疗偏头痛。可以有效地治疗某些形式的神经性疼痛。>,
    <阿司匹林及其复方制剂都能有效治疗某几种头痛，但对另外几种则效果不明。因其他疾病或创伤导致的继发性头痛需要及时在医疗机构接受治疗。>,
    <国际头痛分类标准（ICHD）把原发性头痛分为紧张性头痛、偏头痛和丛集性头痛等类别。普遍认为包括阿司匹林在内的非处方止痛药可以有效治疗紧张性头痛。>,
    <阿司匹林，特别是和对乙酰氨基酚、咖啡因组成复方药物（如阿咖酚散），被认为是治疗偏头痛的首选，在疼痛刚发作时最有效，药效相当于服用低剂量的舒马曲坦。>,
    <阿司匹林可以不可逆地抑制环氧化酶（COX）来调节前列腺素系统，进而达到疼痛控制及退烧的效果。也可以治疗某些急性或慢性的发炎性疾病，如类风湿性关节炎。阿司匹林是一种公认的成人用退烧药，但许多医学协会（包含美国家庭医学会、美国儿科学会，以及美国食品药品监督管理局）及监管机构强烈反对用它治疗儿童发热，因为儿童在有病毒或细菌感染时使用水杨酸类药物可能会患上瑞氏综合征，患病几率虽小，但致死率很高。鉴于这一风险，美国食品药品监督管理局（FDA）从1986年开始要求所有含阿司匹林的药物都需注明儿童和青少年不宜服用。>,
    <1970年初，牛津大学心血管内科的名誉教授彼得·斯莱特研究了阿司匹林对心脏功能的影响和预防中风的效果。斯莱特和他的团队为研究该药用于防治其他疾病打下基础。一份2015的报告指出，50岁的心脏病高危人群每日服用低剂量阿司匹林获益最大。>,
    <阿司匹林在心肌梗死的治疗上面扮演重要的角色。一项临床研究发现在怀疑有ST时段上升心肌梗塞（STEMI）的患者，阿司匹林能够将30日死亡率从11.8+%降低至9.4+%。在这些患者中，大出血的风险不会因为服药增加，但小出血的风险会上升。>,
    <阿司匹林能够预防部分人群罹患心脏病和中风，低剂量服用时能延缓心血管疾病的进程，降低有病史的人群的复发率（即“二次预防”）。>,
    <不过阿司匹林对低风险人群（如没有心脏病和中风病史，没有基础性疾病的人）益处不大。有些研究建议视情况服用，而另一些研究则认为出现其他状况（如胃肠道出血）的风险太大，得不偿失，所以完全不建议预防性的服用。>,
    <预防性服用阿司匹林的另一问题是会产生耐药现象。如果患者有耐药性，药物的效力就会下降，这会增加中风的风险。有科学家建议对治疗方案进行测试，以确定哪些患者对阿司匹林和其他抗血栓药（如氯吡格雷）有耐药性。>,
    <此外，也有建议含阿司匹林的复方制剂用于预防心血管疾病。>,
    <美国卫生保健研究和质量监督局（AHRQ）在一份指南中建议，完成冠状动脉再成形术（PCI），例如安装冠状动脉支架后，应终身服用阿司匹林。该药常与ADP受体拮抗剂（如氯吡格雷、普拉格雷、替格瑞洛等）联用以预防血栓，这种疗法叫做“双重抗血栓疗法”（DAPT）。美国和欧盟对术后采用这种疗法的时间和指征有着不同的指导方针。美国建议DAPT治疗至少持续12个月，而欧盟则建议根据不同情况持续治疗1至12个月不等。>,
    <阿司匹林能降低癌症，特别是大肠癌（CRC）的发生率和死亡率。但效果需要服药至少10至20年才能见到效果。此外，本品也能为为减少子宫内膜癌、乳癌，以及前列腺癌的风险。>,
    <一些人认为，对患癌风险一般的人而言，若把阿司匹林的防癌作用和引起出血的风险相比，利大于弊，但还有人不太确定是否如此。由于这种不确定性，美国预防服务工作组（USPSTF）在有关这个问题的指南中不建议患癌风险一般的人群服用阿司匹林预防大肠癌。>,
    <阿司匹林是治疗急性风湿热所引起的发热和关节痛的一线药物。这种疗法的疗程通常为一两星期，一般不会更长。发热和疼痛缓解后就不用再服药了，因为它不能减少心脏并发症和风湿性心脏瓣膜病后遗症的发生率。萘普生的药效和阿司匹林相当，毒性更小，但由于临床使用经验有限，建议该药仅用作二线治疗。>,
    <除了风湿热外，川崎病是少数几种可以让儿童服用阿司匹林的病症，不过并没有高质量的证据证实它的效果。>,
    <低剂量的阿司匹林补充剂对妊娠毒血症有一定疗效。>,
    <布洛芬或萘普生过敏的人群、对水杨酸（或一般非甾体抗炎药）不耐受的人群禁用，患有哮喘的人群或会因非甾体抗炎药导致支气管痉挛的人群慎用。因为阿司匹林会对胃壁产生影响，生产厂商建议患有消化性溃疡、轻症糖尿病或胃炎的人群在服用前先咨询医师。即使没有上述情况，当阿司匹林与酒精或华法林同时服用时也有导致胃出血的风险。患有血友病或其它出血性疾病的人群也不应服用该药及其它水杨酸类药物。患有遗传性疾病葡萄糖-6-磷酸脱氢酶缺乏症的人群服用阿司匹林会导致溶血性贫血，这取决于用量的多少和病情的严重性。不建议登革热患者服用该药，因为这会提高出血倾向。患有肾病、高尿酸血症或痛风的人群不宜服用，因为阿司匹林会抑制肾脏排出尿酸的功能，从而加重病情。另外不应使用该药治疗儿童或青少年的发热或流感，因为这与患上瑞氏综合征有关。>,
    <阿司匹林会增加消化道出血的风险。尽管有些肠溶片在广告中宣称“不伤胃”，但研究表明肠溶片并未降低出血风险。若该药和其他非甾体抗炎药联用，出血风险还会增加。阿司匹林和氯吡格雷或华法林联用也会增加上消化道出血的风险。>,
    <阿司匹林对COX-1的抑制似乎启动了胃的防御机制，使COX-2活性增强，若同时服用COX-2抑制剂，则会增加对胃黏膜的侵蚀。因此，当阿司匹林与任何“天然”的会抑制COX-2的补充剂（如大蒜提取物，姜黄素，越桔，松树皮，银杏，鱼油，白藜芦醇，染料木黄酮，槲皮素，间苯二酚等）联用时，必须特别小心。>,
    <除了肠溶片外，制药公司还会利用“缓冲剂”来缓解消化道出血的问题。缓冲剂旨在防止阿司匹林集结在胃壁上，不过它的效果存在争议。几乎所有抗酸药里的缓冲剂都能使用，如Bufferin使用氧化镁，还有制剂使用碳酸钙的。>,
    <最近有对阿司匹林与维生素C联用以保护胃黏膜的研究。服用相同剂量的维生素C和阿司匹林与单独服用阿司匹林相比，能减少对胃的伤害。>,
    <大鼠实验表明，阿司匹林的代谢物水杨酸在大剂量时能引起暂时性耳鸣，这是由于花生四烯酸的作用和NMDA受体级联反应。>,
    <瑞氏综合征是一种罕见的严重疾病，特征是急性脑病和脂肪肝，发生在少年儿童服用阿司匹林治疗发热或其他感染时。从1981年到1997年，美国疾病控制与预防中心接到1207宗未满18岁的瑞氏综合征病患报告。其中93+%在综合征出现三周之前就已患病，主要是呼吸道感染、水痘和腹泻。81.9+%的受检儿童都检出了水杨酸。出现阿司匹林引起瑞氏综合征的报告后，美国就采取了预防性的安全措施（如卫生局局长发出警告，更改含阿司匹林药品的标识），美国儿童的阿司匹林用量明显下降，瑞氏综合征的病例报告也明显减少。同样，英国发出儿童不宜服用阿司匹林的警告后，药物用量和病例报告也有减少。美国食品药品监督管理局现在建议12岁以下儿童发热都不能服用阿司匹林或含有阿司匹林的药物。英国药品和医疗产品监管署也建议16岁以下儿童不应服用阿司匹林，除非另有医嘱。>,
    <小部分人服用阿司匹林后会产生类似于过敏的反应，如荨麻疹、水肿和头痛。这种反应是由于水杨酸不耐受，并不是真正的过敏，而是连一点点水杨酸都无法代谢所导致的药物过量。>,
    <有些人服用阿司匹林会产生皮肤组织水肿，有研究发现有些病患服药1到6小时后就会发生。不过，阿司匹林单独服用并不会导致水肿，和非甾体抗炎药联用时才会发生。>,
    <阿司匹林会增加脑部微出血的风险，磁共振成像（MRI）可见5至10毫米的斑块，或者是更小的低信号斑块。>,
    <一项研究估计每天平均服用270毫克的阿司匹林后，脑出血（ICH）的概率绝对值增加了万分之12，与此相比，心肌梗死的概率绝对值下降了万分之137，缺血性中风的概率绝对值则下降了万分之39。如果已经发生脑出血，阿司匹林会提高死亡率，每天大约250毫克的剂量导致发病后三个月内死亡的概率是原来的2.5倍（95+%置信区间是1.3倍到4.6倍）。>,
    <阿司匹林和其他非甾体抗炎药会抑制前列腺素合成，引起低肾素性低醛固酮症，可能引发高血钾症。不过，当肾功能和血容量都正常时，这些药物并不会导致高血钾症。>,
    <阿司匹林在术后十天内都能引起长时间出血。一项研究选择了6499名手术病人进行观察，发现其中有30人需要再次进行手术以控制出血。这30人中有20人是弥漫性出血，另外10人只有一个部位出血。弥漫性出血是由术前单独使用阿司匹林或和其他非甾体抗炎药联用引起的，而离散的出血则不是。>,
    <2015年7月9日，美国食品药品监督管理局提升了对非甾体抗炎药增加心脏病和中风风险的警告。阿司匹林虽然也是非甾体抗炎药，但并不在警告的范围内。>,
    <阿司匹林过量分为急性和慢性。急性过量是指一次性服用大剂量的药物，而慢性过量则是指一段时间内服用超过正常剂量的药物。急性过量的死亡率是2+%。慢性过量的死亡率更高达25+%，且对儿童影响尤为严重。中毒的治疗方法有使用活性炭、静脉注射葡萄糖和生理盐水，使用碳酸氢钠，还有透析。通常用自动分光光度法测量血浆中阿司匹林的活性代谢产物，即水杨酸来诊断中毒。一般来说，正常服药治疗后血浆中水杨酸含量为30--100毫克每升，高剂量服用的患者血浆中的含量为50--300毫克每升，急性中毒患者血浆中的含量为700--1400毫克每升。服用次水杨酸铋、水杨酸甲酯和水杨酸钠后也会产生水杨酸。>,
    <阿司匹林和其他药物会发生互相作用，如乙酰唑胺和氯化铵会增加水杨酸的毒性，酒精则会增加该药导致胃肠道出血的风险。血液中阿司匹林还会影响部分药物与蛋白质结合，包括抗糖尿病药（甲苯磺丁脲和氯磺丙脲）、华法林、氨甲蝶呤、苯妥英、丙磺舒、丙戊酸（会影响该药代谢中的重要一环β-氧化）和其他非甾体抗炎药。另外皮质类固醇能降低阿司匹林的浓度，布洛芬会抵消阿司匹林的抗血栓作用，影响其保护心血管和预防中风的功能。阿司匹林会降低安体舒通的药理活性，经由肾小管分泌时还会与青霉素G竞争。阿司匹林也会抑制维生素C的吸收。>,
    <在有些人身上，阿司匹林的抗血栓作用不如别的人明显，这种现象称为阿司匹林耐药性或是对阿司匹林不敏感。研究表明女性比男性更易产生耐药性，另一项研究总共调查了2930人，发现有28+%的人有耐药性。不过还有一项针对100名意大利人的研究表明，虽然看上去有31+%的人耐药，不过只有5+%的人是真正耐药的，其他人只是没按要求服药而已。另一项研究在400名健康志愿者中没有发现真正对阿司匹林有抗药性的人，但有服用肠溶阿司匹林的人出现“伪耐药性，体现为药物吸收的延迟和减少”。>,
    <制取阿司匹林的反应通常归为酯化反应。水杨酸和乙酸酐（一种乙酸的衍生物）发生反应，水杨酸中的羟基替换为酯基，生成阿司匹林和副产物乙酸。通常用少量硫酸作催化剂（有时用磷酸）。>,
    <含高浓度阿司匹林的制剂常有醋味，这是因为阿司匹林会在潮湿的环境下发生水解，分子分解成水杨酸和乙酸。>,
    <1971年，英国皇家外科学院的药理学家约翰·范恩证实了阿司匹林会抑制前列腺素和血栓素的生成。他因这项发现和苏恩·伯格斯特龙、本格特·萨米尔松共同获得1982年诺贝尔生理学或医学奖。1984年获授下级勋位爵士。>,
    <阿司匹林能抑制前列腺素和血栓素是因为该药能不可逆地使合成前列腺素和血栓素所需的环氧合酶（COX，学名叫前列腺素氧化环化酶，PTGS）失活。阿司匹林能使PTGS活性位点中的一个丝氨酸残基乙酰化，这是它和其他非甾体抗炎药（如双氯芬酸钠和布洛芬）的不同之处，因为其他的药抑制作用都是可逆的。>,
    <阿司匹林低剂量服用时能阻止血小板中血栓素A2的合成，这会在受影响的血小板的生命周期（约8--9天）内抑制血小板聚集。阿司匹林的这种抗血栓作用可用于降低心脏病发生率。每天服用40mg的阿司匹林能显著抑制血栓素A2的最大急性合成量，但不影响前列腺素I2的合成，不过服用剂量更高时就会抑制前列腺素I2的合成。>,
    <前列腺素是身体局部产生的一种激素，它有多种作用，包括在下丘脑中调节体温，将痛觉传递到大脑，还会引起炎症。血栓素会使血小板聚集形成血栓，而心肌梗死主要是由血栓导致的，因此低剂量服用阿司匹林能有效防止心肌梗死。>,
    <阿司匹林可以抑制环氧化酶-1（COX-1）和环氧化酶-2（COX-2）。它能不可逆地抑制COX-1并且改变COX-2的酶活性。COX-2通常产生的大多是会促进发炎的前列腺素类激素，但受阿司匹林作用后则产生能抗炎的脂氧素。新一代非甾体抗炎药——昔布类COX-2抑制剂——可以单独抑制COX-2，以减少对胃肠道的副作用。>,
    <然而许多新一代的COX-2抑制剂如罗非昔布在过去十年内都遭到了撤回，因为有证据表明它们会增加患心脏病和中风的风险。人体的血管内皮细胞原本会合成COX-2。选择性抑制COX-2后，因为血小板里的COX-1未受影响，前列腺素（尤其是前列环素PGI2）的合成相比血栓素会有所降低。这样PGI2抗凝血的保护作用就消失了，这会增加血栓、心肌梗死和其他相关的循环系统疾病的风险。因为血小板没有DNA，它的COX-1若被阿司匹林不可逆地抑制，就无法再生，这是和昔布类可逆抑制剂的不同之处。>,
    <此外，阿司匹林除了有抑制COX-2的环氧化能力之外，还能将其转化为类似脂加氧酶的酵素。被阿司匹林处理过后的COX-2可以将多种多元不饱和脂肪酸转为过氧化物，这些过氧化物又会被代谢为具有抗发炎活性的特异性促修复介质，如脂氧素、消散素、巨噬细胞消炎介质等等。>,
    <阿司匹林还有三种作用方式。一是使线粒体的氧化磷酸化解偶联。阿司匹林会携带质子从线粒体膜间隙扩散进入线粒体基质，然后再次电离释放质子。简而言之，阿司匹林作为缓冲剂运输质子，因此高剂量服用时会因电子传递链释放的热量而造成发热，这和低剂量服用的退烧作用相反。二是阿司匹林会促进一氧化氮自由基的生成。一氧化氮自由基本身在小鼠体内也有抗炎的作用，它能减少白细胞粘附，后者是免疫系统应对感染的重要一步。不过，没有足够证据表明阿司匹林能抗感染。第三，更新的研究表明水杨酸及其衍生物能通过NF-κB调节细胞信号。NF-κB是一种转录因子复合体，在许多生物过程（包括发炎）中起重要作用。>,
    <阿司匹林在体内分解为水杨酸，而水杨酸本身则有抗炎、退烧、镇痛等作用。2012年发现水杨酸还能激活AMP活化蛋白激酶，这是水杨酸和阿司匹林药效的一种可能的解释。阿司匹林分子中的乙酰基也并非没有作用。细胞蛋白的乙酰化是其转译后修饰中被广泛研究的现象。阿司匹林能使包括COX同工酶在内的几种蛋白质乙酰化。这些乙酰化反应可能可以阐释一些阿司匹林尚未得到解释的效应。>,
    <一般来说，成人用于治疗发烧或关节炎时每天服用四次，这和以前治疗风湿热时所用的剂量接近。有或怀疑有冠状动脉病史的人要预防心肌梗死（MI），每天低剂量服用一次即可。>,
    <USPSTF在2009年3月向45--79岁的男性和55--79岁的女性建议，如果阿司匹林降低男性心肌梗死和女性中风的风险所带来的潜在效益要大于引起消化道出血的潜在危害，那么就提倡服用该药以预防冠状动脉心脏疾病。WHI的研究表明女性如果坚持低剂量（75毫克或81毫克）服用，死于心血管疾病的风险就会降低25+%，总死亡率降低14+%。低剂量服用阿司匹林（每天75毫克或81毫克）也和心血管疾病发病率降低有关，长期服用以预防疾病的患者利用这种方式可以兼顾药物的有效性和安全性。>,
    <儿童服用阿司匹林治疗川崎病时，服用剂量和体重相关，头两周每天服用四次，接下来六至八周降低剂量，每天服用一次。>,
    <乙酰水杨酸是一种弱酸，口服后在胃的酸性环境中几乎不电离，而是迅速经细胞膜吸收。小肠中较高的pH促进了药物的电离，从而减缓了药物在小肠中的吸收。过量服用时药物会凝结，所以吸收更慢，血浆浓度在服用后24小时内都会上升。>,
    <血液中的水杨酸有50--80+%与白蛋白结合，其余是具有活性的电离态。药物和蛋白质的结合和浓度有关。结合位点饱和以后游离态的水杨酸就会增加，其毒性也会增强。药物的分布体积是0.1--0.2升每千克。酸中毒会增强水杨酸向组织中的渗透，从而增加药物的分布体积。>,
    <若按治疗剂量服用，则有多达80+%的水杨酸在肝脏中代谢。它和甘氨酸反应生成水杨酰胺乙酸，但这种代谢途径容量有限。少量水杨酸也会羟基化形成龙胆酸。大剂量服用时，药物代谢从一级反应变为零级反应，因为代谢途径已饱和，肾脏的排出变得更加重要。>,
    <水杨酸主要通过肾脏作为水杨酰胺乙酸（75+%）、游离水杨酸（10+%）、水杨酸苯酚（10+%）、酰基葡萄糖醛酸苷（5+%）、龙胆酸（+textless1+%）、2,3-二羟基苯甲酸排泄。当摄入低剂量时（小于250mg，成人），所有途径都通过一级动力学，消除半衰期约为2.0至4.5小时。当摄入高剂量水杨酸时（大于4000mg），半衰期会延长至15--30小时，因为水杨酰胺乙酸和水杨酚醛葡糖苷酸的生物转化途径已饱和。代谢途径的饱和使得肾脏对水杨酸的排泄更加重要，而尿液酸碱度对其影响也更为敏感。当尿液的pH值从5升至8时，肾脏对水杨酸的清除能力会提升10--20倍。通过碱化尿液来增加水杨酸的清除率便是利用了这一点。>,
    <自古以来，人们就知道含有活性成分水杨酸的植物提取物（如柳树皮和绣线菊属植物）能够镇痛、退烧。希波克拉底（约前460年—前377年）留下的历史记录就描述了柳树的树皮和树叶磨成的粉能够缓解以上症状。>,
    <1763年英国牧师爱德华·斯通在牛津发现阿司匹林的活性成分水杨酸。法国化学家查尔斯·弗雷德里克·格哈特首先于1853年合成了乙酰水杨酸。他在制取和研究各种酸酐的性质时，把乙酰氯和水杨酸钠混合，二者发生剧烈反应，熔化后又很快凝固了。因为当时还没有分子结构理论，格哈特把所得的化合物称为“水杨酸乙酸酐”（wasserfreie*Salicyls+"aure-Essigs+"aure）。他为撰写关于酸酐的论文进行了很多反应，这个制备阿司匹林的反应只是其中之一，后来他也没有进一步研究。>,
    <六年之后的1859年，冯·基尔姆让水杨酸和乙酰氯反应，制得了分析纯的乙酰水杨酸，他称之为“乙酰化水杨酸”（acetylierte*Salicyls+"aure）。1869年，施罗德、普林兹霍恩和克劳特重复了格哈特（利用水杨酸钠）的和基尔姆（利用水杨酸）的合成方式，结果证实两个反应产物相同——乙酰水杨酸。他们第一次确定了产物的正确结构——乙酰基和酚基上的氧相连。>,
    <1897年拜耳公司的化学家把旋果蚊子草（Filipendula*ulmaria）合成的水杨苷经过修饰后合成了一种药物，它比纯净的水杨酸对消化道刺激更小。这个项目由哪个化学家领衔存在争议。拜耳说合成是由费利克斯·霍夫曼完成的，但后来犹太化学家阿瑟·艾兴格林声称他才是首席研究员，而他的贡献记录被纳粹政权抹去了。这种药学名叫乙酰水杨酸，拜耳公司把它称为阿司匹林（Aspirin），这来自于旋果蚊子草的植物名（拉丁语：Filipendula*ulmaria）。到了1899年，拜耳已在全球市场销售此药。二十世纪上半叶，阿司匹林越来越受欢迎，这是因为人们认为它在1918年流感大流行中发挥了作用。然而最近的研究却显示，它也是流感致死率高的部分原因，不过这种说法颇受争议，未被广泛认可。阿司匹林带来的丰厚利润使药厂激烈竞争，该药的各种品牌和产品像雨后春笋般冒了出来，在1917年拜耳公司的美国专利过期了以后更是如此。>,
    <对乙酰氨基酚和布洛芬于1956年和1959年相继问世以后，阿司匹林的使用率开始下降。60和70年代，约翰·范恩等人发现了阿司匹林的作用机理，60至80年代的其他研究和临床试验证明该药有抗凝血的药效，可降低血栓疾病的发病率。由于广泛用于预防心脏病和中风，阿司匹林的销量从20世纪末开始复苏，21世纪以来持续向好。>,
    <德国在一战中投降后，1919年各国签订的凡尔赛条约中战后赔偿的部分规定阿司匹林（Aspirin）连同海洛因在法国、俄罗斯、英国和美国不再是注册商标，而成为了通用名称。现在aspirin（a小写）在澳大利亚、法国、印度、爱尔兰、新西兰、巴基斯坦、牙买加、哥伦比亚、菲律宾、南非、英国和美国是通用名称，而Aspirin（a大写）在德国、加拿大、墨西哥等80多个国家还是拜耳公司的注册商标。公司在所有市场上出售的药物成分都是乙酰水杨酸，但包装和物理性质则在各个市场都不相同。>,
    <兽医有时用阿司匹林来镇痛或抗血栓，主要给狗用，有时给马用，不过现在一般会用副作用较少的新疗法。>,
    <狗和马都会出现水杨酸产生的胃肠道副作用，不过阿司匹林可以用来治疗老年狗的关节炎，也有治疗马的蹄叶炎的可能。不过现在该药已很少用于治疗蹄叶炎，因为可能适得其反。阿司匹林应该只在兽医的直接指导下使用，特别是猫，因其缺乏有助于药物排出的葡萄糖醛酸，用药比较危险。连续4周每48小时给猫服用25毫克/千克体重的阿司匹林并不产生临床中毒症状。推荐用于猫的解热镇痛剂量是每48小时10毫克/千克体重。>
  >
+group_end:
\endinput
%%
%% End of file `zhlipsum-utf8.def'.
